{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "Script do join of prepared uniref90 DB and Diamond annotations",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "alpine:3.7",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "diamond_post_run_join.sh"
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#diamond_join.cwl/filename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "separate": true,
                        "prefix": "-d"
                    },
                    "id": "#diamond_join.cwl/input_db"
                },
                {
                    "format": "http://edamontology.org/format_2333",
                    "type": "File",
                    "inputBinding": {
                        "separate": true,
                        "prefix": "-i"
                    },
                    "id": "#diamond_join.cwl/input_diamond"
                }
            ],
            "stdout": "$(inputs.filename)_summary.diamond.without_header",
            "id": "#diamond_join.cwl",
            "http://schema.org/author": "Ekaterina Sakharova, Maxim Scheremetjew",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2333",
                    "id": "#diamond_join.cwl/output_join",
                    "outputBinding": {
                        "glob": "$(inputs.filename)_summary.diamond.without_header"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "alpine:3.7",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "sort",
                "-k2,2"
            ],
            "inputs": [
                {
                    "format": "http://edamontology.org/format_2333",
                    "type": "File",
                    "inputBinding": {
                        "separate": true,
                        "position": 2
                    },
                    "id": "#diamond_sorting.cwl/input_table"
                }
            ],
            "stdout": "$(inputs.input_table.nameroot).sorted",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2333",
                    "id": "#diamond_sorting.cwl/output_sorted",
                    "outputBinding": {
                        "glob": "$(inputs.input_table.nameroot).sorted"
                    }
                }
            ],
            "id": "#diamond_sorting.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2019",
            "http://schema.org/author": "Ekaterina Sakharova, Maxim Scheremetjew"
        },
        {
            "class": "Workflow",
            "doc": "Represents a 2 step workflow which retrieves the top hits from a Diamond tabular output file and maps those hits to\na few UniRef90 annotations, like NCBI tax id or RepID.\n",
            "label": "Represents a post processing step of the Diamond results.",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#postprocessing_subwf.cwl/filename"
                },
                {
                    "type": "string",
                    "id": "#postprocessing_subwf.cwl/input_db"
                },
                {
                    "type": "File",
                    "id": "#postprocessing_subwf.cwl/input_diamond"
                }
            ],
            "outputs": [
                {
                    "outputSource": "#postprocessing_subwf.cwl/join/output_join",
                    "type": "File",
                    "id": "#postprocessing_subwf.cwl/join_out"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#postprocessing_subwf.cwl/filename",
                            "id": "#postprocessing_subwf.cwl/join/filename"
                        },
                        {
                            "source": "#postprocessing_subwf.cwl/input_db",
                            "id": "#postprocessing_subwf.cwl/join/input_db"
                        },
                        {
                            "source": "#postprocessing_subwf.cwl/sorting/output_sorted",
                            "id": "#postprocessing_subwf.cwl/join/input_diamond"
                        }
                    ],
                    "out": [
                        "#postprocessing_subwf.cwl/join/output_join"
                    ],
                    "run": "#diamond_join.cwl",
                    "id": "#postprocessing_subwf.cwl/join"
                },
                {
                    "in": [
                        {
                            "source": "#postprocessing_subwf.cwl/input_diamond",
                            "id": "#postprocessing_subwf.cwl/sorting/input_table"
                        }
                    ],
                    "out": [
                        "#postprocessing_subwf.cwl/sorting/output_sorted"
                    ],
                    "run": "#diamond_sorting.cwl",
                    "id": "#postprocessing_subwf.cwl/sorting"
                }
            ],
            "id": "#postprocessing_subwf.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2019",
            "http://schema.org/author": "Ekaterina Sakharova, Maxim Scheremetjew",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "diamond",
                "blastp"
            ],
            "inputs": [
                {
                    "id": "#Diamond.blastp-v0.9.21.cwl/blockSize",
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--block-size"
                    },
                    "label": "sequence block size in billions of letters (default=2.0)"
                },
                {
                    "id": "#Diamond.blastp-v0.9.21.cwl/databaseFile",
                    "type": "string",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--db"
                    },
                    "label": "DIAMOND database input file",
                    "doc": "Path to the DIAMOND database file."
                },
                {
                    "id": "#Diamond.blastp-v0.9.21.cwl/outputFormat",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--outfmt"
                    },
                    "label": "Format of the output file",
                    "doc": "0   = BLAST pairwise\n5   = BLAST XML\n6   = BLAST tabular\n100 = DIAMOND alignment archive (DAA)\n101 = SAM\n\nValue 6 may be followed by a space-separated list of these keywords"
                },
                {
                    "id": "#Diamond.blastp-v0.9.21.cwl/queryGeneticCode",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--min-orf"
                    },
                    "label": "Genetic code used for the translation of the query sequences",
                    "doc": "Ignore translated sequences that do not contain an open reading frame of at least this length.\nBy default this feature is disabled for sequences of length below 30, set to 20 for sequences of length below 100, and set to 40 otherwise. Setting this option to 1 will disable this feature.\n"
                },
                {
                    "id": "#Diamond.blastp-v0.9.21.cwl/queryInputFile",
                    "format": "http://edamontology.org/format_1929",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--query"
                    },
                    "label": "Query input file in FASTA",
                    "doc": "Path to the query input file in FASTA or FASTQ format (may be gzip compressed). If this parameter is omitted, the input will be read from stdin\n"
                },
                {
                    "id": "#Diamond.blastp-v0.9.21.cwl/strand",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": -3,
                        "prefix": "--strand"
                    },
                    "label": "Set strand of query to align for translated searches",
                    "doc": "Set strand of query to align for translated searches. By default both strands are searched. Valid values are {both, plus, minus}"
                },
                {
                    "id": "#Diamond.blastp-v0.9.21.cwl/taxonList",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--taxonlist"
                    },
                    "label": "Protein accession to taxon identifier NCBI mapping file",
                    "doc": "Comma-separated list of NCBI taxonomic IDs to filter the database by. Any taxonomic rank can be used, and only reference sequences matching one of the specified taxon ids will be searched against. Using this option requires setting the --taxonmap and --taxonnodes parameters for makedb.\n"
                },
                {
                    "id": "#Diamond.blastp-v0.9.21.cwl/threads",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--threads"
                    },
                    "label": "Number of CPU threads",
                    "doc": "Number of CPU threads. By default, the program will auto-detect and use all available virtual cores on the machine.\n"
                },
                {
                    "id": "#Diamond.blastp-v0.9.21.cwl/maxTargetSeqs",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--max-target-seqs"
                    },
                    "label": "Max number of target sequences per query",
                    "doc": "The maximum number of target sequences per query to report alignments for (default=25). Setting this to 0 will report all alignments that were found.\n"
                },
                {
                    "id": "#Diamond.blastp-v0.9.21.cwl/top",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--top"
                    },
                    "label": "Percentage range of the top alignment score",
                    "doc": "Report alignments within the given percentage range of the top alignment score for a query (overrides --max-target-seqs option). For example, setting this to 10 will report all align- ments whose score is at most 10% lower than the best alignment score for a query.\n"
                }
            ],
            "outputs": [
                {
                    "id": "#Diamond.blastp-v0.9.21.cwl/matches",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.queryInputFile.basename).diamond_matches"
                    },
                    "format": "http://edamontology.org/format_2333"
                }
            ],
            "doc": "DIAMOND is a sequence aligner for protein and translated DNA searches,\ndesigned for high performance analysis of big sequence data.\n\nThe key features are:\n      + Pairwise alignment of proteins and translated DNA at 500x-20,000x speed of BLAST.\n      + Frameshift alignments for long read analysis.\n      + Low resource requirements and suitable for running on standard desktops or laptops.\n      + Various output formats, including BLAST pairwise, tabular and XML, as well as taxonomic classification.\n\nPlease visit https://github.com/bbuchfink/diamond for full documentation.\n\nReleases can be downloaded from https://github.com/bbuchfink/diamond/releases\n",
            "label": "Aligns DNA query sequences against a protein reference database",
            "arguments": [
                {
                    "position": 0,
                    "prefix": "--out",
                    "valueFrom": "$(inputs.queryInputFile.basename).diamond_matches"
                }
            ],
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "enum",
                            "name": "#Diamond-strand_values.yaml/strand",
                            "symbols": [
                                "#Diamond-strand_values.yaml/strand/both",
                                "#Diamond-strand_values.yaml/strand/plus",
                                "#Diamond-strand_values.yaml/strand/minus"
                            ]
                        },
                        {
                            "type": "enum",
                            "name": "#Diamond-output_formats.yaml/output_formats",
                            "symbols": [
                                "#Diamond-output_formats.yaml/output_formats/0",
                                "#Diamond-output_formats.yaml/output_formats/5",
                                "#Diamond-output_formats.yaml/output_formats/6",
                                "#Diamond-output_formats.yaml/output_formats/100",
                                "#Diamond-output_formats.yaml/output_formats/101",
                                "#Diamond-output_formats.yaml/output_formats/102"
                            ]
                        }
                    ]
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 15000,
                    "tmpdirMin": 20000,
                    "coresMin": 16
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "buchfink/diamond:version0.9.21"
                }
            ],
            "id": "#Diamond.blastp-v0.9.21.cwl",
            "http://schema.org/author": "Maxim Scheremetjews",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0"
        },
        {
            "class": "Workflow",
            "label": "Subworkflow unites Diamond and Diamond post-processing",
            "requirements": [
                {
                    "ramMin": 30000,
                    "coresMin": 32,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#diamond-subwf.cwl/Uniref90_db_txt"
                },
                {
                    "type": "string",
                    "id": "#diamond-subwf.cwl/databaseFile"
                },
                {
                    "type": "string",
                    "id": "#diamond-subwf.cwl/filename"
                },
                {
                    "type": "int",
                    "id": "#diamond-subwf.cwl/maxTargetSeqs"
                },
                {
                    "type": "string",
                    "id": "#diamond-subwf.cwl/outputFormat"
                },
                {
                    "type": "File",
                    "id": "#diamond-subwf.cwl/queryInputFile"
                },
                {
                    "type": "string",
                    "id": "#diamond-subwf.cwl/strand"
                },
                {
                    "type": "int",
                    "id": "#diamond-subwf.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#diamond-subwf.cwl/diamond_run/matches",
                    "id": "#diamond-subwf.cwl/diamond_output"
                },
                {
                    "type": "File",
                    "outputSource": "#diamond-subwf.cwl/post_processing_uniref90/join_out",
                    "id": "#diamond-subwf.cwl/post-processing_output"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#diamond-subwf.cwl/databaseFile",
                            "id": "#diamond-subwf.cwl/diamond_run/databaseFile"
                        },
                        {
                            "source": "#diamond-subwf.cwl/maxTargetSeqs",
                            "id": "#diamond-subwf.cwl/diamond_run/maxTargetSeqs"
                        },
                        {
                            "source": "#diamond-subwf.cwl/outputFormat",
                            "id": "#diamond-subwf.cwl/diamond_run/outputFormat"
                        },
                        {
                            "source": "#diamond-subwf.cwl/queryInputFile",
                            "id": "#diamond-subwf.cwl/diamond_run/queryInputFile"
                        },
                        {
                            "source": "#diamond-subwf.cwl/strand",
                            "id": "#diamond-subwf.cwl/diamond_run/strand"
                        },
                        {
                            "source": "#diamond-subwf.cwl/threads",
                            "id": "#diamond-subwf.cwl/diamond_run/threads"
                        }
                    ],
                    "out": [
                        "#diamond-subwf.cwl/diamond_run/matches"
                    ],
                    "run": "#Diamond.blastp-v0.9.21.cwl",
                    "id": "#diamond-subwf.cwl/diamond_run"
                },
                {
                    "in": [
                        {
                            "source": "#diamond-subwf.cwl/filename",
                            "id": "#diamond-subwf.cwl/post_processing_uniref90/filename"
                        },
                        {
                            "source": "#diamond-subwf.cwl/Uniref90_db_txt",
                            "id": "#diamond-subwf.cwl/post_processing_uniref90/input_db"
                        },
                        {
                            "source": "#diamond-subwf.cwl/diamond_run/matches",
                            "id": "#diamond-subwf.cwl/post_processing_uniref90/input_diamond"
                        }
                    ],
                    "out": [
                        "#diamond-subwf.cwl/post_processing_uniref90/join_out"
                    ],
                    "run": "#postprocessing_subwf.cwl",
                    "id": "#diamond-subwf.cwl/post_processing_uniref90"
                }
            ],
            "id": "#diamond-subwf.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2019",
            "http://schema.org/author": "Ekaterina Sakharova",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "eggNOG",
            "doc": "eggNOG is a public resource that provides Orthologous Groups (OGs)\nof proteins at different taxonomic levels, each with integrated and summarized functional annotations.\n",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "eggnog_pipeline:latest",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "ramMin": 10000,
                    "coresMin": 16,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "emapper_wrapper.sh"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--annotate_hits_table"
                    },
                    "label": "Annotatate TSV formatted table of query->hits",
                    "id": "#eggnog.cwl/annotate_hits_table"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--cpu"
                    },
                    "id": "#eggnog.cwl/cpu"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--data_dir"
                    },
                    "label": "Directory to use for DATA_PATH",
                    "id": "#eggnog.cwl/data_dir"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--database"
                    },
                    "label": "specify the target database for sequence searches (euk,bact,arch, host:port, local hmmpressed database)",
                    "id": "#eggnog.cwl/db"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--dmnd_db"
                    },
                    "label": "Path to DIAMOND-compatible database",
                    "id": "#eggnog.cwl/db_diamond"
                },
                {
                    "format": "http://edamontology.org/format_1929",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "separate": true,
                        "prefix": "-i"
                    },
                    "label": "Input FASTA file containing query sequences",
                    "id": "#eggnog.cwl/fasta_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "label": "hmmer or diamond",
                    "id": "#eggnog.cwl/mode"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--no_annot"
                    },
                    "label": "Skip functional annotation, reporting only hits",
                    "id": "#eggnog.cwl/no_annot"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--no_file_comments"
                    },
                    "label": "No header lines nor stats are included in the output files",
                    "id": "#eggnog.cwl/no_file_comments"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#eggnog.cwl/output"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3475",
                    "outputBinding": {
                        "glob": "$(inputs.output)*annotations*"
                    },
                    "id": "#eggnog.cwl/output_annotations"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3475",
                    "outputBinding": {
                        "glob": "$(inputs.output)*orthologs*"
                    },
                    "id": "#eggnog.cwl/output_orthologs"
                }
            ],
            "id": "#eggnog.cwl",
            "http://schema.org/author": "Ekaterina Sakharova",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0"
        },
        {
            "class": "Workflow",
            "label": "First scatter to find seed orthologs, unite them, find annotations",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#eggnog-subwf.cwl/cpu"
                },
                {
                    "type": "string",
                    "id": "#eggnog-subwf.cwl/data_dir"
                },
                {
                    "type": "string",
                    "id": "#eggnog-subwf.cwl/db"
                },
                {
                    "type": "string",
                    "id": "#eggnog-subwf.cwl/db_diamond"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#eggnog-subwf.cwl/fasta_file"
                },
                {
                    "type": "string",
                    "id": "#eggnog-subwf.cwl/file_acc"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#eggnog-subwf.cwl/eggnog_annotation/output_annotations",
                    "id": "#eggnog-subwf.cwl/annotations"
                },
                {
                    "type": "File",
                    "outputSource": "#eggnog-subwf.cwl/unite_seed_orthologs/result",
                    "id": "#eggnog-subwf.cwl/orthologs"
                }
            ],
            "steps": [
                {
                    "run": "#eggnog.cwl",
                    "in": [
                        {
                            "source": "#eggnog-subwf.cwl/unite_seed_orthologs/result",
                            "id": "#eggnog-subwf.cwl/eggnog_annotation/annotate_hits_table"
                        },
                        {
                            "source": "#eggnog-subwf.cwl/cpu",
                            "id": "#eggnog-subwf.cwl/eggnog_annotation/cpu"
                        },
                        {
                            "source": "#eggnog-subwf.cwl/data_dir",
                            "id": "#eggnog-subwf.cwl/eggnog_annotation/data_dir"
                        },
                        {
                            "default": true,
                            "id": "#eggnog-subwf.cwl/eggnog_annotation/no_file_comments"
                        },
                        {
                            "source": "#eggnog-subwf.cwl/file_acc",
                            "valueFrom": "$(self.split('_CDS')[0])",
                            "id": "#eggnog-subwf.cwl/eggnog_annotation/output"
                        }
                    ],
                    "out": [
                        "#eggnog-subwf.cwl/eggnog_annotation/output_annotations"
                    ],
                    "id": "#eggnog-subwf.cwl/eggnog_annotation"
                },
                {
                    "scatter": "#eggnog-subwf.cwl/eggnog_homology_searches/fasta_file",
                    "run": "#eggnog.cwl",
                    "in": [
                        {
                            "source": "#eggnog-subwf.cwl/cpu",
                            "id": "#eggnog-subwf.cwl/eggnog_homology_searches/cpu"
                        },
                        {
                            "source": "#eggnog-subwf.cwl/db_diamond",
                            "id": "#eggnog-subwf.cwl/eggnog_homology_searches/db_diamond"
                        },
                        {
                            "source": "#eggnog-subwf.cwl/fasta_file",
                            "id": "#eggnog-subwf.cwl/eggnog_homology_searches/fasta_file"
                        },
                        {
                            "default": "diamond",
                            "id": "#eggnog-subwf.cwl/eggnog_homology_searches/mode"
                        },
                        {
                            "default": true,
                            "id": "#eggnog-subwf.cwl/eggnog_homology_searches/no_annot"
                        },
                        {
                            "default": true,
                            "id": "#eggnog-subwf.cwl/eggnog_homology_searches/no_file_comments"
                        },
                        {
                            "source": "#eggnog-subwf.cwl/file_acc",
                            "id": "#eggnog-subwf.cwl/eggnog_homology_searches/output"
                        }
                    ],
                    "out": [
                        "#eggnog-subwf.cwl/eggnog_homology_searches/output_orthologs"
                    ],
                    "id": "#eggnog-subwf.cwl/eggnog_homology_searches"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#eggnog-subwf.cwl/eggnog_homology_searches/output_orthologs",
                            "id": "#eggnog-subwf.cwl/unite_seed_orthologs/files"
                        },
                        {
                            "source": "#eggnog-subwf.cwl/file_acc",
                            "valueFrom": "$(self.split('_CDS')[0])",
                            "id": "#eggnog-subwf.cwl/unite_seed_orthologs/outputFileName"
                        },
                        {
                            "default": ".emapper.seed_orthologs",
                            "id": "#eggnog-subwf.cwl/unite_seed_orthologs/postfix"
                        }
                    ],
                    "out": [
                        "#eggnog-subwf.cwl/unite_seed_orthologs/result"
                    ],
                    "id": "#eggnog-subwf.cwl/unite_seed_orthologs"
                }
            ],
            "id": "#eggnog-subwf.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/author": "Ekaterina Sakharova",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "Script builds GFF-file based on IPS and EggNOG results",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 2500,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "alpine:3.9.4",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "build_assembly_gff.py"
            ],
            "inputs": [
                {
                    "format": "http://edamontology.org/format_3475",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-e"
                    },
                    "id": "#gff_generation.cwl/eggnog_results"
                },
                {
                    "format": "http://edamontology.org/format_1929",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-f"
                    },
                    "id": "#gff_generation.cwl/input_faa"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#gff_generation.cwl/ips_results"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#gff_generation.cwl/output_name"
                }
            ],
            "stdout": "stdout.txt",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2306",
                    "outputBinding": {
                        "glob": "$(inputs.output_name).bgz"
                    },
                    "id": "#gff_generation.cwl/output_gff_gz"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name).bgz.tbi"
                    },
                    "id": "#gff_generation.cwl/output_gff_index"
                },
                {
                    "type": "File",
                    "id": "#gff_generation.cwl/stdout",
                    "outputBinding": {
                        "glob": "stdout.txt"
                    }
                }
            ],
            "id": "#gff_generation.cwl",
            "http://schema.org/author": "Martin Beracochea, Ekaterina Sakharova, Varsha Kale",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0"
        },
        {
            "class": "CommandLineTool",
            "label": "Genome properties https://genome-properties.readthedocs.io",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 2000,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "genome_properties:latest",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "assign_genome_properties.pl"
            ],
            "arguments": [
                {
                    "position": 1,
                    "valueFrom": "-all"
                },
                {
                    "position": 2,
                    "valueFrom": "table",
                    "prefix": "-outfiles"
                },
                {
                    "position": 4,
                    "valueFrom": "summary",
                    "prefix": "-outfiles"
                },
                {
                    "position": 3,
                    "valueFrom": "web_json",
                    "prefix": "-outfiles"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-gpff"
                    },
                    "id": "#genome_properties.cwl/GP_txt"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-gpdir"
                    },
                    "id": "#genome_properties.cwl/flatfiles_path"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "inputBinding": {
                        "separate": true,
                        "prefix": "-matches"
                    },
                    "id": "#genome_properties.cwl/input_tsv_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-name"
                    },
                    "id": "#genome_properties.cwl/name"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-outdir"
                    },
                    "id": "#genome_properties.cwl/out_dir"
                }
            ],
            "stdout": "stdout.txt",
            "stderr": "stderr.txt",
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3464",
                    "outputBinding": {
                        "glob": "JSON*$(inputs.name)"
                    },
                    "id": "#genome_properties.cwl/json"
                },
                {
                    "type": "File",
                    "id": "#genome_properties.cwl/stderr",
                    "outputBinding": {
                        "glob": "stderr.txt"
                    }
                },
                {
                    "type": "File",
                    "id": "#genome_properties.cwl/stdout",
                    "outputBinding": {
                        "glob": "stdout.txt"
                    }
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "outputBinding": {
                        "glob": "SUMMARY*$(inputs.name)"
                    },
                    "id": "#genome_properties.cwl/summary"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3475",
                    "outputBinding": {
                        "glob": "TABLE*$(inputs.name)"
                    },
                    "id": "#genome_properties.cwl/table"
                }
            ],
            "id": "#genome_properties.cwl",
            "http://schema.org/author": "Ekaterina Sakharova",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0"
        },
        {
            "class": "CommandLineTool",
            "label": "Calculate completeness of all KEGG pathways",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 300,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "kegg_pathways:latest",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "give_pathways.py"
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-g"
                    },
                    "id": "#kegg_pathways.cwl/graphs"
                },
                {
                    "format": "http://edamontology.org/format_3475",
                    "type": "File",
                    "inputBinding": {
                        "separate": true,
                        "prefix": "-i"
                    },
                    "id": "#kegg_pathways.cwl/input_table"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#kegg_pathways.cwl/outputname"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-c"
                    },
                    "id": "#kegg_pathways.cwl/pathways_classes"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-n"
                    },
                    "id": "#kegg_pathways.cwl/pathways_names"
                }
            ],
            "stdout": "stdout.txt",
            "outputs": [
                {
                    "type": "File",
                    "id": "#kegg_pathways.cwl/stdout",
                    "outputBinding": {
                        "glob": "stdout.txt"
                    }
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "outputBinding": {
                        "glob": "*summary.kegg_contigs*"
                    },
                    "id": "#kegg_pathways.cwl/summary_contigs"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "outputBinding": {
                        "glob": "*summary.kegg_pathways*"
                    },
                    "id": "#kegg_pathways.cwl/summary_pathways"
                }
            ],
            "id": "#kegg_pathways.cwl",
            "http://schema.org/author": "Ekaterina Sakharova",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0"
        },
        {
            "class": "CommandLineTool",
            "label": "Change random number of whitespaces between columns to tab",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "alpine:3.9.4",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "sed",
                "/^#/d; s/ \\+/\\t/g"
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "inputBinding": {
                        "separate": true,
                        "position": 2
                    },
                    "id": "#modification_table.cwl/input_table"
                }
            ],
            "stdout": "$(inputs.input_table.nameroot)_tab.tbl",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "id": "#modification_table.cwl/output_with_tabs",
                    "outputBinding": {
                        "glob": "$(inputs.input_table.nameroot)_tab.tbl"
                    }
                }
            ],
            "id": "#modification_table.cwl",
            "http://schema.org/author": "Ekaterina Sakharova",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0"
        },
        {
            "class": "CommandLineTool",
            "label": "Taking KOs corresponding contigs from hmmscan result",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "kegg_analysis:latest",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "parsing_hmmscan.py"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "separate": true,
                        "prefix": "-f"
                    },
                    "id": "#parsing_hmmscan.cwl/fasta"
                },
                {
                    "format": "http://edamontology.org/format_3475",
                    "type": "File",
                    "inputBinding": {
                        "separate": true,
                        "prefix": "-i"
                    },
                    "id": "#parsing_hmmscan.cwl/table"
                }
            ],
            "stdout": "stdout.txt",
            "stderr": "stderr.txt",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "outputBinding": {
                        "glob": "*_parsed*"
                    },
                    "id": "#parsing_hmmscan.cwl/output_table"
                }
            ],
            "id": "#parsing_hmmscan.cwl",
            "http://schema.org/author": "Ekaterina Sakharova",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0"
        },
        {
            "class": "CommandLineTool",
            "label": "antiSMASH",
            "doc": "antiSMASH allows the rapid genome-wide identification, annotation and analysis\nof secondary metabolite biosynthesis gene clusters in bacterial and fungal genomes.\nIt integrates and cross-links with a large number of in silico secondary metabolite analysis tools\n",
            "requirements": [
                {
                    "listing": [
                        {
                            "entry": "$(inputs.input_fasta)",
                            "entryname": "$(inputs.input_fasta.basename).fasta"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 20000,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "alpine:3.7",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#antismash_v4.cwl/accession"
                },
                {
                    "type": "string",
                    "id": "#antismash_v4.cwl/chunk_num"
                },
                {
                    "format": "http://edamontology.org/format_1929",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#antismash_v4.cwl/input_fasta"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#antismash_v4.cwl/outdirname"
                }
            ],
            "baseCommand": [
                "run_antismash_short.sh"
            ],
            "stdout": "stdout.txt",
            "stderr": "stderr.txt",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outdirname)/*final.embl"
                    },
                    "id": "#antismash_v4.cwl/embl_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outdirname)/*final.gbk"
                    },
                    "id": "#antismash_v4.cwl/gbk_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outdirname)/geneclusters.js",
                        "outputEval": "${\n  self[0].basename = inputs.accession + '.' + inputs.chunk_num + '.geneclusters.js';\n  return self[0]\n}\n"
                    },
                    "id": "#antismash_v4.cwl/geneclusters_js"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outdirname)/geneclusters.txt",
                        "outputEval": "${\n  self[0].basename = inputs.accession + '.' + inputs.chunk_num + '.geneclusters.txt';\n  return self[0]\n}\n"
                    },
                    "id": "#antismash_v4.cwl/geneclusters_txt"
                }
            ],
            "id": "#antismash_v4.cwl",
            "http://schema.org/author": "Ekaterina Sakharova",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0"
        },
        {
            "class": "Workflow",
            "label": "WF leaves sequences that length is more than 1000bp, run antismash + gene clusters post-processing, GFF generation",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 5000
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#antismash_chunking_subwf.cwl/clusters_glossary"
                },
                {
                    "type": "File",
                    "id": "#antismash_chunking_subwf.cwl/filtered_fasta"
                },
                {
                    "type": "string",
                    "id": "#antismash_chunking_subwf.cwl/final_folder_name"
                },
                {
                    "type": "int",
                    "id": "#antismash_chunking_subwf.cwl/split_size"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#antismash_chunking_subwf.cwl/rename_geneclusters/renamed_file",
                    "id": "#antismash_chunking_subwf.cwl/antismash_clusters"
                },
                {
                    "type": "Directory",
                    "outputSource": "#antismash_chunking_subwf.cwl/return_antismash_in_folder/out",
                    "id": "#antismash_chunking_subwf.cwl/antismash_folder_chunking"
                }
            ],
            "steps": [
                {
                    "run": "#antismash_to_gff.cwl",
                    "doc": "Build a .gff file with the antiSMASH annotations\n",
                    "in": [
                        {
                            "source": "#antismash_chunking_subwf.cwl/unite_embl/result",
                            "id": "#antismash_chunking_subwf.cwl/antismash_gff/antismash_embl"
                        },
                        {
                            "source": "#antismash_chunking_subwf.cwl/antismash_summary/reformatted_clusters",
                            "id": "#antismash_chunking_subwf.cwl/antismash_gff/antismash_geneclus"
                        },
                        {
                            "source": "#antismash_chunking_subwf.cwl/filtered_fasta",
                            "valueFrom": "$(self.nameroot).antismash.gff",
                            "id": "#antismash_chunking_subwf.cwl/antismash_gff/output_name"
                        }
                    ],
                    "out": [
                        "#antismash_chunking_subwf.cwl/antismash_gff/output_gff_bgz",
                        "#antismash_chunking_subwf.cwl/antismash_gff/output_gff_index"
                    ],
                    "id": "#antismash_chunking_subwf.cwl/antismash_gff"
                },
                {
                    "run": "#reformat_antismash.cwl",
                    "doc": "Combine the information from the glossary with the united\nantiSMASH geneclusters.txt files.\n",
                    "in": [
                        {
                            "source": "#antismash_chunking_subwf.cwl/unite_geneclusters_txt/result",
                            "id": "#antismash_chunking_subwf.cwl/antismash_summary/geneclusters"
                        },
                        {
                            "source": "#antismash_chunking_subwf.cwl/clusters_glossary",
                            "id": "#antismash_chunking_subwf.cwl/antismash_summary/glossary"
                        }
                    ],
                    "out": [
                        "#antismash_chunking_subwf.cwl/antismash_summary/reformatted_clusters"
                    ],
                    "id": "#antismash_chunking_subwf.cwl/antismash_summary"
                },
                {
                    "run": "#count_fasta.cwl",
                    "in": [
                        {
                            "source": "#antismash_chunking_subwf.cwl/split_size",
                            "id": "#antismash_chunking_subwf.cwl/calc_chunking_number/number"
                        },
                        {
                            "source": "#antismash_chunking_subwf.cwl/filtered_fasta",
                            "id": "#antismash_chunking_subwf.cwl/calc_chunking_number/sequences"
                        }
                    ],
                    "out": [
                        "#antismash_chunking_subwf.cwl/calc_chunking_number/count"
                    ],
                    "id": "#antismash_chunking_subwf.cwl/calc_chunking_number"
                },
                {
                    "run": "#check_value.cwl",
                    "in": [
                        {
                            "source": "#antismash_chunking_subwf.cwl/calc_chunking_number/count",
                            "id": "#antismash_chunking_subwf.cwl/check_value/number"
                        }
                    ],
                    "out": [
                        "#antismash_chunking_subwf.cwl/check_value/out"
                    ],
                    "id": "#antismash_chunking_subwf.cwl/check_value"
                },
                {
                    "run": "#fasta_chunker.cwl",
                    "in": [
                        {
                            "source": "#antismash_chunking_subwf.cwl/check_value/out",
                            "id": "#antismash_chunking_subwf.cwl/chunking_fasta/chunk_size"
                        },
                        {
                            "default": "True",
                            "id": "#antismash_chunking_subwf.cwl/chunking_fasta/number_of_output_files"
                        },
                        {
                            "default": "True",
                            "id": "#antismash_chunking_subwf.cwl/chunking_fasta/same_number_of_residues"
                        },
                        {
                            "source": "#antismash_chunking_subwf.cwl/filtered_fasta",
                            "id": "#antismash_chunking_subwf.cwl/chunking_fasta/seqs"
                        }
                    ],
                    "out": [
                        "#antismash_chunking_subwf.cwl/chunking_fasta/chunks"
                    ],
                    "id": "#antismash_chunking_subwf.cwl/chunking_fasta"
                },
                {
                    "run": "#gzip.cwl",
                    "in": [
                        {
                            "source": "#antismash_chunking_subwf.cwl/unite_embl/result",
                            "id": "#antismash_chunking_subwf.cwl/gzipped_embl/uncompressed_file"
                        }
                    ],
                    "out": [
                        "#antismash_chunking_subwf.cwl/gzipped_embl/compressed_file"
                    ],
                    "id": "#antismash_chunking_subwf.cwl/gzipped_embl"
                },
                {
                    "run": "#gzip.cwl",
                    "in": [
                        {
                            "source": "#antismash_chunking_subwf.cwl/unite_gbk/result",
                            "id": "#antismash_chunking_subwf.cwl/gzipped_gbk/uncompressed_file"
                        }
                    ],
                    "out": [
                        "#antismash_chunking_subwf.cwl/gzipped_gbk/compressed_file"
                    ],
                    "id": "#antismash_chunking_subwf.cwl/gzipped_gbk"
                },
                {
                    "run": "#rename_contigs.cwl",
                    "scatter": "#antismash_chunking_subwf.cwl/rename_contigs/chunks",
                    "in": [
                        {
                            "source": "#antismash_chunking_subwf.cwl/filtered_fasta",
                            "valueFrom": "$(self.nameroot)",
                            "id": "#antismash_chunking_subwf.cwl/rename_contigs/accession"
                        },
                        {
                            "source": "#antismash_chunking_subwf.cwl/chunking_fasta/chunks",
                            "id": "#antismash_chunking_subwf.cwl/rename_contigs/chunks"
                        },
                        {
                            "source": "#antismash_chunking_subwf.cwl/filtered_fasta",
                            "id": "#antismash_chunking_subwf.cwl/rename_contigs/full_fasta"
                        }
                    ],
                    "out": [
                        "#antismash_chunking_subwf.cwl/rename_contigs/renamed_contigs_in_chunks",
                        "#antismash_chunking_subwf.cwl/rename_contigs/names_table"
                    ],
                    "id": "#antismash_chunking_subwf.cwl/rename_contigs"
                },
                {
                    "run": "#move.cwl",
                    "in": [
                        {
                            "source": "#antismash_chunking_subwf.cwl/antismash_summary/reformatted_clusters",
                            "id": "#antismash_chunking_subwf.cwl/rename_geneclusters/initial_file"
                        },
                        {
                            "source": "#antismash_chunking_subwf.cwl/filtered_fasta",
                            "valueFrom": "$(self.nameroot)_antismash_geneclusters.txt",
                            "id": "#antismash_chunking_subwf.cwl/rename_geneclusters/out_file_name"
                        }
                    ],
                    "out": [
                        "#antismash_chunking_subwf.cwl/rename_geneclusters/renamed_file"
                    ],
                    "id": "#antismash_chunking_subwf.cwl/rename_geneclusters"
                },
                {
                    "run": "#return_directory.cwl",
                    "in": [
                        {
                            "source": "#antismash_chunking_subwf.cwl/final_folder_name",
                            "id": "#antismash_chunking_subwf.cwl/return_antismash_in_folder/dir_name"
                        },
                        {
                            "source": [
                                "#antismash_chunking_subwf.cwl/antismash_gff/output_gff_bgz",
                                "#antismash_chunking_subwf.cwl/antismash_gff/output_gff_index",
                                "#antismash_chunking_subwf.cwl/rename_geneclusters/renamed_file",
                                "#antismash_chunking_subwf.cwl/gzipped_embl/compressed_file",
                                "#antismash_chunking_subwf.cwl/gzipped_gbk/compressed_file"
                            ],
                            "id": "#antismash_chunking_subwf.cwl/return_antismash_in_folder/file_list"
                        }
                    ],
                    "out": [
                        "#antismash_chunking_subwf.cwl/return_antismash_in_folder/out"
                    ],
                    "id": "#antismash_chunking_subwf.cwl/return_antismash_in_folder"
                },
                {
                    "run": "#antismash_subwf.cwl",
                    "scatter": [
                        "#antismash_chunking_subwf.cwl/run_antismash/fasta_file",
                        "#antismash_chunking_subwf.cwl/run_antismash/input_names_table"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#antismash_chunking_subwf.cwl/filtered_fasta",
                            "valueFrom": "$(self.nameroot)",
                            "id": "#antismash_chunking_subwf.cwl/run_antismash/accession"
                        },
                        {
                            "source": "#antismash_chunking_subwf.cwl/rename_contigs/renamed_contigs_in_chunks",
                            "id": "#antismash_chunking_subwf.cwl/run_antismash/fasta_file"
                        },
                        {
                            "source": "#antismash_chunking_subwf.cwl/rename_contigs/names_table",
                            "id": "#antismash_chunking_subwf.cwl/run_antismash/input_names_table"
                        }
                    ],
                    "out": [
                        "#antismash_chunking_subwf.cwl/run_antismash/antismash_txt",
                        "#antismash_chunking_subwf.cwl/run_antismash/antismash_gbk",
                        "#antismash_chunking_subwf.cwl/run_antismash/antismash_embl"
                    ],
                    "id": "#antismash_chunking_subwf.cwl/run_antismash"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#antismash_chunking_subwf.cwl/run_antismash/antismash_embl",
                            "id": "#antismash_chunking_subwf.cwl/unite_embl/files"
                        },
                        {
                            "source": "#antismash_chunking_subwf.cwl/filtered_fasta",
                            "valueFrom": "$(self.nameroot)",
                            "id": "#antismash_chunking_subwf.cwl/unite_embl/outputFileName"
                        },
                        {
                            "default": "_antismash_final.embl",
                            "id": "#antismash_chunking_subwf.cwl/unite_embl/postfix"
                        }
                    ],
                    "out": [
                        "#antismash_chunking_subwf.cwl/unite_embl/result"
                    ],
                    "id": "#antismash_chunking_subwf.cwl/unite_embl"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#antismash_chunking_subwf.cwl/run_antismash/antismash_gbk",
                            "id": "#antismash_chunking_subwf.cwl/unite_gbk/files"
                        },
                        {
                            "source": "#antismash_chunking_subwf.cwl/filtered_fasta",
                            "valueFrom": "$(self.nameroot)",
                            "id": "#antismash_chunking_subwf.cwl/unite_gbk/outputFileName"
                        },
                        {
                            "default": "_antismash_final.gbk",
                            "id": "#antismash_chunking_subwf.cwl/unite_gbk/postfix"
                        }
                    ],
                    "out": [
                        "#antismash_chunking_subwf.cwl/unite_gbk/result"
                    ],
                    "id": "#antismash_chunking_subwf.cwl/unite_gbk"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#antismash_chunking_subwf.cwl/run_antismash/antismash_txt",
                            "id": "#antismash_chunking_subwf.cwl/unite_geneclusters_txt/files"
                        },
                        {
                            "default": "geneclusters.txt",
                            "id": "#antismash_chunking_subwf.cwl/unite_geneclusters_txt/outputFileName"
                        }
                    ],
                    "out": [
                        "#antismash_chunking_subwf.cwl/unite_geneclusters_txt/result"
                    ],
                    "id": "#antismash_chunking_subwf.cwl/unite_geneclusters_txt"
                }
            ],
            "id": "#antismash_chunking_subwf.cwl"
        },
        {
            "class": "Workflow",
            "label": "antismash + change locus tag ",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 5000
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#antismash_subwf.cwl/accession"
                },
                {
                    "type": "File",
                    "id": "#antismash_subwf.cwl/fasta_file"
                },
                {
                    "type": "File",
                    "id": "#antismash_subwf.cwl/input_names_table"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#antismash_subwf.cwl/fix_embl_and_gbk/fixed_embl",
                    "id": "#antismash_subwf.cwl/antismash_embl"
                },
                {
                    "type": "File",
                    "outputSource": "#antismash_subwf.cwl/fix_embl_and_gbk/fixed_gbk",
                    "id": "#antismash_subwf.cwl/antismash_gbk"
                },
                {
                    "type": "File",
                    "outputSource": "#antismash_subwf.cwl/fix_geneclusters_txt/fixed_txt",
                    "id": "#antismash_subwf.cwl/antismash_txt"
                }
            ],
            "steps": [
                {
                    "run": "#change_output.cwl",
                    "in": [
                        {
                            "source": "#antismash_subwf.cwl/run_antismash/embl_file",
                            "id": "#antismash_subwf.cwl/fix_embl_and_gbk/embl_file"
                        },
                        {
                            "source": "#antismash_subwf.cwl/fasta_file",
                            "valueFrom": "$(self.basename).embl",
                            "id": "#antismash_subwf.cwl/fix_embl_and_gbk/embl_filename"
                        },
                        {
                            "source": "#antismash_subwf.cwl/fasta_file",
                            "valueFrom": "$(self.basename).gbk",
                            "id": "#antismash_subwf.cwl/fix_embl_and_gbk/gbk_filename"
                        },
                        {
                            "source": "#antismash_subwf.cwl/input_names_table",
                            "id": "#antismash_subwf.cwl/fix_embl_and_gbk/names_table"
                        }
                    ],
                    "out": [
                        "#antismash_subwf.cwl/fix_embl_and_gbk/fixed_embl",
                        "#antismash_subwf.cwl/fix_embl_and_gbk/fixed_gbk"
                    ],
                    "id": "#antismash_subwf.cwl/fix_embl_and_gbk"
                },
                {
                    "run": "#change_geneclusters_txt.cwl",
                    "in": [
                        {
                            "source": "#antismash_subwf.cwl/run_antismash/geneclusters_txt",
                            "id": "#antismash_subwf.cwl/fix_geneclusters_txt/input_geneclusters_txt"
                        },
                        {
                            "source": "#antismash_subwf.cwl/fasta_file",
                            "valueFrom": "$(self.basename).gncl.txt",
                            "id": "#antismash_subwf.cwl/fix_geneclusters_txt/output_filename"
                        }
                    ],
                    "out": [
                        "#antismash_subwf.cwl/fix_geneclusters_txt/fixed_txt"
                    ],
                    "id": "#antismash_subwf.cwl/fix_geneclusters_txt"
                },
                {
                    "run": "#antismash_v4.cwl",
                    "in": [
                        {
                            "source": "#antismash_subwf.cwl/accession",
                            "id": "#antismash_subwf.cwl/run_antismash/accession"
                        },
                        {
                            "source": "#antismash_subwf.cwl/fasta_file",
                            "valueFrom": "$(self.nameext)",
                            "id": "#antismash_subwf.cwl/run_antismash/chunk_num"
                        },
                        {
                            "source": "#antismash_subwf.cwl/fasta_file",
                            "id": "#antismash_subwf.cwl/run_antismash/input_fasta"
                        },
                        {
                            "default": "antismash_result",
                            "id": "#antismash_subwf.cwl/run_antismash/outdirname"
                        }
                    ],
                    "out": [
                        "#antismash_subwf.cwl/run_antismash/geneclusters_txt",
                        "#antismash_subwf.cwl/run_antismash/embl_file",
                        "#antismash_subwf.cwl/run_antismash/gbk_file"
                    ],
                    "id": "#antismash_subwf.cwl/run_antismash"
                }
            ],
            "id": "#antismash_subwf.cwl"
        },
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#check_value.cwl/number"
                }
            ],
            "outputs": [
                {
                    "type": "int",
                    "id": "#check_value.cwl/out"
                }
            ],
            "expression": "${\n  var value = 0;\n  if (inputs.number == 0 || inputs.number == 1) {\n    value = 2;\n  }\n  else {\n    value = inputs.number;\n  }\n  return {\"out\": value\n  }; }",
            "id": "#check_value.cwl",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "WF leaves sequences that length is more than 1000bp, run antismash + gene clusters post-processing, GFF generation",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 5000
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#filtering_fasta_for_antismash.cwl/contig_min_limit"
                },
                {
                    "type": "File",
                    "id": "#filtering_fasta_for_antismash.cwl/fasta"
                }
            ],
            "outputs": [
                {
                    "type": "int",
                    "outputSource": "#filtering_fasta_for_antismash.cwl/count_reads_after_filtering/count",
                    "id": "#filtering_fasta_for_antismash.cwl/count_after_filtering"
                },
                {
                    "type": "File",
                    "outputSource": "#filtering_fasta_for_antismash.cwl/filter_contigs_antismash/filtered_file",
                    "id": "#filtering_fasta_for_antismash.cwl/filtered_fasta_for_antismash"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "default": 1,
                            "id": "#filtering_fasta_for_antismash.cwl/count_reads/number"
                        },
                        {
                            "source": "#filtering_fasta_for_antismash.cwl/fasta",
                            "id": "#filtering_fasta_for_antismash.cwl/count_reads/sequences"
                        }
                    ],
                    "out": [
                        "#filtering_fasta_for_antismash.cwl/count_reads/count"
                    ],
                    "run": "#count_fasta.cwl",
                    "id": "#filtering_fasta_for_antismash.cwl/count_reads"
                },
                {
                    "in": [
                        {
                            "default": 1,
                            "id": "#filtering_fasta_for_antismash.cwl/count_reads_after_filtering/number"
                        },
                        {
                            "source": "#filtering_fasta_for_antismash.cwl/filter_contigs_antismash/filtered_file",
                            "id": "#filtering_fasta_for_antismash.cwl/count_reads_after_filtering/sequences"
                        }
                    ],
                    "out": [
                        "#filtering_fasta_for_antismash.cwl/count_reads_after_filtering/count"
                    ],
                    "run": "#count_fasta.cwl",
                    "id": "#filtering_fasta_for_antismash.cwl/count_reads_after_filtering"
                },
                {
                    "run": "#qc-filtering.cwl",
                    "in": [
                        {
                            "default": "fasta",
                            "id": "#filtering_fasta_for_antismash.cwl/filter_contigs_antismash/input_file_format"
                        },
                        {
                            "source": "#filtering_fasta_for_antismash.cwl/contig_min_limit",
                            "id": "#filtering_fasta_for_antismash.cwl/filter_contigs_antismash/min_length"
                        },
                        {
                            "source": "#filtering_fasta_for_antismash.cwl/fasta",
                            "id": "#filtering_fasta_for_antismash.cwl/filter_contigs_antismash/seq_file"
                        },
                        {
                            "default": "qc_summary_antismash",
                            "id": "#filtering_fasta_for_antismash.cwl/filter_contigs_antismash/stats_file_name"
                        },
                        {
                            "source": "#filtering_fasta_for_antismash.cwl/count_reads/count",
                            "id": "#filtering_fasta_for_antismash.cwl/filter_contigs_antismash/submitted_seq_count"
                        }
                    ],
                    "out": [
                        "#filtering_fasta_for_antismash.cwl/filter_contigs_antismash/filtered_file"
                    ],
                    "id": "#filtering_fasta_for_antismash.cwl/filter_contigs_antismash"
                }
            ],
            "id": "#filtering_fasta_for_antismash.cwl"
        },
        {
            "class": "Workflow",
            "label": "If filtered file is empty -> return file-flag no_antismash",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 5000
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#no_antismash_subwf.cwl/filtered_fasta"
                },
                {
                    "type": "string",
                    "id": "#no_antismash_subwf.cwl/final_folder_name"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputSource": "#no_antismash_subwf.cwl/return_antismash_in_folder/out",
                    "id": "#no_antismash_subwf.cwl/antismash_result_folder"
                }
            ],
            "steps": [
                {
                    "run": "#return_directory.cwl",
                    "in": [
                        {
                            "source": "#no_antismash_subwf.cwl/final_folder_name",
                            "id": "#no_antismash_subwf.cwl/return_antismash_in_folder/dir_name"
                        },
                        {
                            "source": [
                                "#no_antismash_subwf.cwl/touch_no_antismash_flag/created_file"
                            ],
                            "linkMerge": "merge_nested",
                            "id": "#no_antismash_subwf.cwl/return_antismash_in_folder/file_list"
                        }
                    ],
                    "out": [
                        "#no_antismash_subwf.cwl/return_antismash_in_folder/out"
                    ],
                    "id": "#no_antismash_subwf.cwl/return_antismash_in_folder"
                },
                {
                    "run": "#touch_file.cwl",
                    "in": [
                        {
                            "default": "no_antismash",
                            "id": "#no_antismash_subwf.cwl/touch_no_antismash_flag/filename"
                        }
                    ],
                    "out": [
                        "#no_antismash_subwf.cwl/touch_no_antismash_flag/created_file"
                    ],
                    "id": "#no_antismash_subwf.cwl/touch_no_antismash_flag"
                }
            ],
            "id": "#no_antismash_subwf.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "change EMBL and GBK files",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 1000,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "mgnify/pipeline-v5.python3:latest",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#change_output.cwl/embl_file"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-e"
                    },
                    "id": "#change_output.cwl/embl_filename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-g"
                    },
                    "id": "#change_output.cwl/gbk_filename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-t"
                    },
                    "id": "#change_output.cwl/names_table"
                }
            ],
            "baseCommand": [
                "change_antismash_output.py"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.embl_filename)"
                    },
                    "id": "#change_output.cwl/fixed_embl"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.gbk_filename)"
                    },
                    "id": "#change_output.cwl/fixed_gbk"
                }
            ],
            "id": "#change_output.cwl",
            "http://schema.org/author": "Ekaterina Sakharova",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0"
        },
        {
            "class": "CommandLineTool",
            "label": "change EMBL and GBK files",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 1000,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "mgnify/pipeline-v5.python3:latest",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#change_geneclusters_txt.cwl/input_geneclusters_txt"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#change_geneclusters_txt.cwl/output_filename"
                }
            ],
            "baseCommand": [
                "change_geneclusters_ctg.py"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#change_geneclusters_txt.cwl/fixed_txt"
                }
            ],
            "id": "#change_geneclusters_txt.cwl",
            "http://schema.org/author": "Ekaterina Sakharova",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0"
        },
        {
            "class": "CommandLineTool",
            "label": "Script builds GFF-file based on antiSMASH results",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "alpine:3.9.4",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "antismash_to_gff.py"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-e"
                    },
                    "id": "#antismash_to_gff.cwl/antismash_embl"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-g"
                    },
                    "id": "#antismash_to_gff.cwl/antismash_geneclus"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#antismash_to_gff.cwl/output_name"
                }
            ],
            "stdout": "stdout.txt",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2306",
                    "outputBinding": {
                        "glob": "$(inputs.output_name).bgz"
                    },
                    "id": "#antismash_to_gff.cwl/output_gff_bgz"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name).bgz.tbi"
                    },
                    "id": "#antismash_to_gff.cwl/output_gff_index"
                },
                {
                    "type": "File",
                    "id": "#antismash_to_gff.cwl/stdout",
                    "outputBinding": {
                        "glob": "stdout.txt"
                    }
                }
            ],
            "id": "#antismash_to_gff.cwl",
            "http://schema.org/author": "Martin Beracochea, Ekaterina Sakharova, Varsha Kale",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0"
        },
        {
            "class": "CommandLineTool",
            "label": "reformat antiSMASH",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "reformat_antismash.py"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-a"
                    },
                    "id": "#reformat_antismash.cwl/geneclusters"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-g"
                    },
                    "id": "#reformat_antismash.cwl/glossary"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "geneclusters-summary.txt"
                    },
                    "id": "#reformat_antismash.cwl/reformatted_clusters"
                }
            ],
            "id": "#reformat_antismash.cwl",
            "http://schema.org/copyrightHolder": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/name": "EMBL - European Bioinformatics Institute",
                    "http://schema.org/url": "https://www.ebi.ac.uk"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "rename contigs for chunk fastas",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 1000,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "mgnify/pipeline-v5.python3:latest",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-a"
                    },
                    "id": "#rename_contigs.cwl/accession"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-c"
                    },
                    "id": "#rename_contigs.cwl/chunks"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#rename_contigs.cwl/full_fasta"
                }
            ],
            "baseCommand": [
                "antismash_rename_contigs.py"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.chunks.basename).tbl"
                    },
                    "id": "#rename_contigs.cwl/names_table"
                },
                {
                    "format": "http://edamontology.org/format_1929",
                    "type": "File",
                    "outputBinding": {
                        "glob": "antismash.*"
                    },
                    "id": "#rename_contigs.cwl/renamed_contigs_in_chunks"
                }
            ],
            "id": "#rename_contigs.cwl",
            "http://schema.org/author": "Ekaterina Sakharova",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0"
        },
        {
            "class": "Workflow",
            "label": "WF leaves sequences that length is more than 1000bp, run antismash + gene clusters post-processing, GFF generation",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 5000
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#wf_antismash.cwl/clusters_glossary"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 5000,
                    "id": "#wf_antismash.cwl/contig_min_limit"
                },
                {
                    "type": "string",
                    "id": "#wf_antismash.cwl/final_folder_name"
                },
                {
                    "type": "File",
                    "id": "#wf_antismash.cwl/input_filtered_fasta"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#wf_antismash.cwl/chunking/antismash_clusters",
                    "id": "#wf_antismash.cwl/antismash_clusters"
                },
                {
                    "type": "Directory",
                    "outputSource": [
                        "#wf_antismash.cwl/no_antismash_subwf/antismash_result_folder",
                        "#wf_antismash.cwl/chunking/antismash_folder_chunking"
                    ],
                    "pickValue": "first_non_null",
                    "id": "#wf_antismash.cwl/antismash_folder"
                }
            ],
            "steps": [
                {
                    "when": "$(inputs.value > 0)",
                    "run": "#antismash_chunking_subwf.cwl",
                    "in": [
                        {
                            "source": "#wf_antismash.cwl/clusters_glossary",
                            "id": "#wf_antismash.cwl/chunking/clusters_glossary"
                        },
                        {
                            "source": "#wf_antismash.cwl/filtering/filtered_fasta_for_antismash",
                            "id": "#wf_antismash.cwl/chunking/filtered_fasta"
                        },
                        {
                            "source": "#wf_antismash.cwl/final_folder_name",
                            "id": "#wf_antismash.cwl/chunking/final_folder_name"
                        },
                        {
                            "default": 1000,
                            "id": "#wf_antismash.cwl/chunking/split_size"
                        },
                        {
                            "source": "#wf_antismash.cwl/filtering/count_after_filtering",
                            "id": "#wf_antismash.cwl/chunking/value"
                        }
                    ],
                    "out": [
                        "#wf_antismash.cwl/chunking/antismash_folder_chunking",
                        "#wf_antismash.cwl/chunking/antismash_clusters"
                    ],
                    "id": "#wf_antismash.cwl/chunking"
                },
                {
                    "run": "#filtering_fasta_for_antismash.cwl",
                    "in": [
                        {
                            "source": "#wf_antismash.cwl/contig_min_limit",
                            "id": "#wf_antismash.cwl/filtering/contig_min_limit"
                        },
                        {
                            "source": "#wf_antismash.cwl/input_filtered_fasta",
                            "id": "#wf_antismash.cwl/filtering/fasta"
                        }
                    ],
                    "out": [
                        "#wf_antismash.cwl/filtering/filtered_fasta_for_antismash",
                        "#wf_antismash.cwl/filtering/count_after_filtering"
                    ],
                    "id": "#wf_antismash.cwl/filtering"
                },
                {
                    "when": "$(inputs.value == 0)",
                    "run": "#no_antismash_subwf.cwl",
                    "in": [
                        {
                            "source": "#wf_antismash.cwl/filtering/filtered_fasta_for_antismash",
                            "id": "#wf_antismash.cwl/no_antismash_subwf/filtered_fasta"
                        },
                        {
                            "source": "#wf_antismash.cwl/final_folder_name",
                            "id": "#wf_antismash.cwl/no_antismash_subwf/final_folder_name"
                        },
                        {
                            "source": "#wf_antismash.cwl/filtering/count_after_filtering",
                            "id": "#wf_antismash.cwl/no_antismash_subwf/value"
                        }
                    ],
                    "out": [
                        "#wf_antismash.cwl/no_antismash_subwf/antismash_result_folder"
                    ],
                    "id": "#wf_antismash.cwl/no_antismash_subwf"
                }
            ],
            "id": "#wf_antismash.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "gather summary file from InterProScan",
            "requirements": [
                {
                    "ramMin": 300,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-a"
                    },
                    "id": "#move_antismash_summary.cwl/antismash_summary"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-f"
                    },
                    "id": "#move_antismash_summary.cwl/folder_name"
                }
            ],
            "baseCommand": [
                "move_antismash_summary.py"
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.folder_name)"
                    },
                    "id": "#move_antismash_summary.cwl/summary_in_folder"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "id": "#move_antismash_summary.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "microbiomeinformatics/pipeline-v5.bash-scripts:v1.2",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "-f"
                    },
                    "id": "#fasta_index.cwl/fasta"
                }
            ],
            "arguments": [
                "-n",
                "$(inputs.fasta.basename)"
            ],
            "baseCommand": [
                "run_samtools.sh"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.fasta.basename).bgz.gzi"
                    },
                    "id": "#fasta_index.cwl/bgz_index"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.fasta.basename).bgz"
                    },
                    "id": "#fasta_index.cwl/fasta_bgz"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.fasta.basename).bgz.fai"
                    },
                    "id": "#fasta_index.cwl/fasta_index"
                }
            ],
            "id": "#fasta_index.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": [
                {
                    "name": "#fasta_index.cwl/EMBL - European Bioinformatics Institute"
                },
                {
                    "url": "https://www.ebi.ac.uk/"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "Combined Gene Caller: FragGeneScan",
            "requirements": [
                {
                    "ramMin": 5000,
                    "coresMin": 4,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "run_FGS.sh"
            ],
            "arguments": null,
            "inputs": [
                {
                    "format": "http://edamontology.org/format_1929",
                    "type": "File",
                    "inputBinding": {
                        "separate": true,
                        "prefix": "-i"
                    },
                    "id": "#FGS.cwl/input_fasta"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "separate": true,
                        "prefix": "-o"
                    },
                    "id": "#FGS.cwl/output"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "separate": true,
                        "prefix": "-s"
                    },
                    "id": "#FGS.cwl/seq_type"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "separate": true,
                        "prefix": "-t"
                    },
                    "default": "illumina_5",
                    "id": "#FGS.cwl/train"
                }
            ],
            "stdout": "stdout.txt",
            "stderr": "stderr.txt",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output).faa"
                    },
                    "id": "#FGS.cwl/predicted_proteins_faa"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output).ffn"
                    },
                    "id": "#FGS.cwl/predicted_proteins_ffn"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output).out"
                    },
                    "id": "#FGS.cwl/predicted_proteins_out"
                },
                {
                    "type": "File",
                    "id": "#FGS.cwl/stderr",
                    "outputBinding": {
                        "glob": "stderr.txt"
                    }
                },
                {
                    "type": "File",
                    "id": "#FGS.cwl/stdout",
                    "outputBinding": {
                        "glob": "stdout.txt"
                    }
                }
            ],
            "id": "#FGS.cwl",
            "http://schema.org/author": "Ekaterina Sakharova",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "Combined Gene Caller: post-processing of FGS and Prodigal",
            "requirements": [
                {
                    "ramMin": 5000,
                    "coresMin": 4,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "unite_protein_predictions.py"
            ],
            "inputs": [
                {
                    "inputBinding": {
                        "prefix": "--name"
                    },
                    "type": "string",
                    "id": "#post-processing.cwl/basename"
                },
                {
                    "inputBinding": {
                        "prefix": "--caller-priority"
                    },
                    "type": "string",
                    "id": "#post-processing.cwl/genecaller_order"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--mask"
                    },
                    "id": "#post-processing.cwl/masking_file"
                },
                {
                    "inputBinding": {
                        "prefix": "--fgs-faa"
                    },
                    "type": "File",
                    "id": "#post-processing.cwl/predicted_proteins_fgs_faa"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--fgs-ffn"
                    },
                    "id": "#post-processing.cwl/predicted_proteins_fgs_ffn"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--fgs-out"
                    },
                    "id": "#post-processing.cwl/predicted_proteins_fgs_out"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--prodigal-faa"
                    },
                    "id": "#post-processing.cwl/predicted_proteins_prodigal_faa"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--prodigal-ffn"
                    },
                    "id": "#post-processing.cwl/predicted_proteins_prodigal_ffn"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--prodigal-out"
                    },
                    "id": "#post-processing.cwl/predicted_proteins_prodigal_out"
                }
            ],
            "stdout": "stdout.txt",
            "stderr": "stderr.txt",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "$(inputs.basename).faa"
                    },
                    "id": "#post-processing.cwl/predicted_proteins"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "$(inputs.basename).ffn"
                    },
                    "id": "#post-processing.cwl/predicted_seq"
                },
                {
                    "type": "File",
                    "id": "#post-processing.cwl/stderr",
                    "outputBinding": {
                        "glob": "stderr.txt"
                    }
                },
                {
                    "type": "File",
                    "id": "#post-processing.cwl/stdout",
                    "outputBinding": {
                        "glob": "stdout.txt"
                    }
                }
            ],
            "id": "#post-processing.cwl",
            "http://schema.org/author": "Ekaterina Sakharova",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "ramMin": 5000,
                    "coresMin": 8,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "default": "illumina_5",
                    "id": "#predict_proteins_assemblies.cwl/fgs_train"
                },
                {
                    "type": "string",
                    "default": "prodigal,fgs",
                    "id": "#predict_proteins_assemblies.cwl/genecaller_order"
                },
                {
                    "type": "File",
                    "id": "#predict_proteins_assemblies.cwl/input_fasta"
                },
                {
                    "type": "File",
                    "id": "#predict_proteins_assemblies.cwl/maskfile"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#predict_proteins_assemblies.cwl/post-processing/predicted_proteins",
                    "id": "#predict_proteins_assemblies.cwl/predicted_proteins"
                },
                {
                    "type": "File",
                    "outputSource": "#predict_proteins_assemblies.cwl/post-processing/predicted_seq",
                    "id": "#predict_proteins_assemblies.cwl/predicted_seq"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#predict_proteins_assemblies.cwl/input_fasta",
                            "id": "#predict_proteins_assemblies.cwl/FGS/input_fasta"
                        },
                        {
                            "source": "#predict_proteins_assemblies.cwl/input_fasta",
                            "valueFrom": "$(self.basename).fgs",
                            "id": "#predict_proteins_assemblies.cwl/FGS/output"
                        },
                        {
                            "default": "1",
                            "id": "#predict_proteins_assemblies.cwl/FGS/seq_type"
                        },
                        {
                            "source": "#predict_proteins_assemblies.cwl/fgs_train",
                            "id": "#predict_proteins_assemblies.cwl/FGS/train"
                        }
                    ],
                    "out": [
                        "#predict_proteins_assemblies.cwl/FGS/predicted_proteins_out",
                        "#predict_proteins_assemblies.cwl/FGS/predicted_proteins_ffn",
                        "#predict_proteins_assemblies.cwl/FGS/predicted_proteins_faa"
                    ],
                    "run": "#FGS.cwl",
                    "id": "#predict_proteins_assemblies.cwl/FGS"
                },
                {
                    "in": [
                        {
                            "source": "#predict_proteins_assemblies.cwl/input_fasta",
                            "valueFrom": "$(self.basename)",
                            "id": "#predict_proteins_assemblies.cwl/post-processing/basename"
                        },
                        {
                            "source": "#predict_proteins_assemblies.cwl/genecaller_order",
                            "id": "#predict_proteins_assemblies.cwl/post-processing/genecaller_order"
                        },
                        {
                            "source": "#predict_proteins_assemblies.cwl/maskfile",
                            "id": "#predict_proteins_assemblies.cwl/post-processing/masking_file"
                        },
                        {
                            "source": "#predict_proteins_assemblies.cwl/FGS/predicted_proteins_faa",
                            "id": "#predict_proteins_assemblies.cwl/post-processing/predicted_proteins_fgs_faa"
                        },
                        {
                            "source": "#predict_proteins_assemblies.cwl/FGS/predicted_proteins_ffn",
                            "id": "#predict_proteins_assemblies.cwl/post-processing/predicted_proteins_fgs_ffn"
                        },
                        {
                            "source": "#predict_proteins_assemblies.cwl/FGS/predicted_proteins_out",
                            "id": "#predict_proteins_assemblies.cwl/post-processing/predicted_proteins_fgs_out"
                        },
                        {
                            "source": "#predict_proteins_assemblies.cwl/prodigal/predicted_proteins_faa",
                            "id": "#predict_proteins_assemblies.cwl/post-processing/predicted_proteins_prodigal_faa"
                        },
                        {
                            "source": "#predict_proteins_assemblies.cwl/prodigal/predicted_proteins_ffn",
                            "id": "#predict_proteins_assemblies.cwl/post-processing/predicted_proteins_prodigal_ffn"
                        },
                        {
                            "source": "#predict_proteins_assemblies.cwl/prodigal/predicted_proteins_out",
                            "id": "#predict_proteins_assemblies.cwl/post-processing/predicted_proteins_prodigal_out"
                        }
                    ],
                    "out": [
                        "#predict_proteins_assemblies.cwl/post-processing/predicted_proteins",
                        "#predict_proteins_assemblies.cwl/post-processing/predicted_seq"
                    ],
                    "run": "#post-processing.cwl",
                    "id": "#predict_proteins_assemblies.cwl/post-processing"
                },
                {
                    "in": [
                        {
                            "source": "#predict_proteins_assemblies.cwl/input_fasta",
                            "id": "#predict_proteins_assemblies.cwl/prodigal/input_fasta"
                        }
                    ],
                    "out": [
                        "#predict_proteins_assemblies.cwl/prodigal/predicted_proteins_out",
                        "#predict_proteins_assemblies.cwl/prodigal/predicted_proteins_ffn",
                        "#predict_proteins_assemblies.cwl/prodigal/predicted_proteins_faa"
                    ],
                    "run": "#prodigal.cwl",
                    "id": "#predict_proteins_assemblies.cwl/prodigal"
                }
            ],
            "id": "#predict_proteins_assemblies.cwl",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "Combined Gene Caller: Prodigal",
            "requirements": [
                {
                    "ramMin": 5000,
                    "coresMin": 4,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "prodigal"
            ],
            "arguments": [
                {
                    "valueFrom": "sco",
                    "prefix": "-f"
                },
                {
                    "valueFrom": "meta",
                    "prefix": "-p"
                },
                {
                    "valueFrom": "$(inputs.input_fasta.basename).prodigal",
                    "prefix": "-o"
                },
                {
                    "valueFrom": "$(inputs.input_fasta.basename).prodigal.ffn",
                    "prefix": "-d"
                },
                {
                    "valueFrom": "$(inputs.input_fasta.basename).prodigal.faa",
                    "prefix": "-a"
                }
            ],
            "inputs": [
                {
                    "format": "http://edamontology.org/format_1929",
                    "type": "File",
                    "inputBinding": {
                        "separate": true,
                        "prefix": "-i"
                    },
                    "id": "#prodigal.cwl/input_fasta"
                }
            ],
            "stdout": "stdout.txt",
            "stderr": "stderr.txt",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_fasta.basename).prodigal.faa"
                    },
                    "id": "#prodigal.cwl/predicted_proteins_faa"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_fasta.basename).prodigal.ffn"
                    },
                    "id": "#prodigal.cwl/predicted_proteins_ffn"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_fasta.basename).prodigal"
                    },
                    "id": "#prodigal.cwl/predicted_proteins_out"
                },
                {
                    "type": "File",
                    "id": "#prodigal.cwl/stderr",
                    "outputBinding": {
                        "glob": "stderr.txt"
                    }
                },
                {
                    "type": "File",
                    "id": "#prodigal.cwl/stdout",
                    "outputBinding": {
                        "glob": "stdout.txt"
                    }
                }
            ],
            "id": "#prodigal.cwl",
            "http://schema.org/author": "Ekaterina Sakharova",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 4000,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "go_slim:latest",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005732"
                            ],
                            "version": [
                                "8d53bbce1ffe60d9aa3357c1001599f9a882317a"
                            ],
                            "package": "owltools"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "inputBinding": {
                        "prefix": "--input-file"
                    },
                    "id": "#go_summary.cwl/InterProScan_results"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--config"
                    },
                    "id": "#go_summary.cwl/config"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--output-file"
                    },
                    "id": "#go_summary.cwl/output_name"
                }
            ],
            "baseCommand": [
                "go_summary_pipeline-1.0.py"
            ],
            "stderr": "stderr.txt",
            "stdout": "stdout.txt",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3752",
                    "outputBinding": {
                        "glob": "*.go"
                    },
                    "id": "#go_summary.cwl/go_summary"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3752",
                    "outputBinding": {
                        "glob": "*.go_slim"
                    },
                    "id": "#go_summary.cwl/go_summary_slim"
                },
                {
                    "type": "File",
                    "id": "#go_summary.cwl/stderr",
                    "outputBinding": {
                        "glob": "stderr.txt"
                    }
                },
                {
                    "type": "File",
                    "id": "#go_summary.cwl/stdout",
                    "outputBinding": {
                        "glob": "stdout.txt"
                    }
                }
            ],
            "id": "#go_summary.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "id": "#InterProScan-v5-none_docker.cwl",
            "baseCommand": "interproscan.sh",
            "inputs": [
                {
                    "id": "#InterProScan-v5-none_docker.cwl/i5/inputFile",
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "position": 8,
                        "prefix": "--input"
                    },
                    "label": "Input file path",
                    "doc": "Optional, path to fasta file that should be loaded on Master startup. Alternatively, in CONVERT mode, the InterProScan 5 XML file to convert."
                },
                {
                    "id": "#InterProScan-v5-none_docker.cwl/i5/applications",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 9,
                        "itemSeparator": ",",
                        "prefix": "--applications"
                    },
                    "label": "Analysis",
                    "doc": "Optional, comma separated list of analyses. If this option is not set, ALL analyses will be run."
                },
                {
                    "id": "#InterProScan-v5-none_docker.cwl/i5/outputFormat",
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "inputBinding": {
                        "position": 10,
                        "itemSeparator": ",",
                        "prefix": "--formats"
                    },
                    "label": "output format",
                    "doc": "Optional, case-insensitive, comma separated list of output formats. Supported formats are TSV, XML, JSON, GFF3, HTML and SVG. Default for protein sequences are TSV, XML and GFF3, or for nucleotide sequences GFF3 and XML."
                },
                {
                    "id": "#InterProScan-v5-none_docker.cwl/i5/databases",
                    "type": [
                        "null",
                        "string"
                    ]
                },
                {
                    "id": "#InterProScan-v5-none_docker.cwl/i5/disableResidueAnnotation",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "--disable-residue-annot"
                    },
                    "label": "Disables residue annotation",
                    "doc": "Optional, excludes sites from the XML, JSON output."
                },
                {
                    "id": "#InterProScan-v5-none_docker.cwl/i5/seqtype",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#InterProScan-v5-none_docker.cwl/i5/seqtype/seqtype/p",
                                "#InterProScan-v5-none_docker.cwl/i5/seqtype/seqtype/n"
                            ],
                            "name": "#InterProScan-v5-none_docker.cwl/i5/seqtype/seqtype"
                        }
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "--seqtype"
                    },
                    "label": "Sequence type",
                    "doc": "Optional, the type of the input sequences (dna/rna (n) or protein (p)). The default sequence type is protein."
                }
            ],
            "outputs": [
                {
                    "id": "#InterProScan-v5-none_docker.cwl/i5/i5Annotations",
                    "format": "http://edamontology.org/format_3475",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.inputFile.nameroot).f*.tsv"
                    }
                }
            ],
            "doc": "InterProScan is the software package that allows sequences (protein and nucleic) to be scanned against InterPro's signatures. Signatures are predictive models, provided by several different databases, that make up the InterPro consortium. This tool description is using a Docker container tagged as version v5.30-69.0. Documentation on how to run InterProScan 5 can be found here: https://github.com/ebi-pf-team/interproscan/wiki/HowToRun",
            "label": "InterProScan: protein sequence classifier",
            "arguments": [
                {
                    "position": 0,
                    "valueFrom": "--disable-precalc"
                },
                {
                    "position": 1,
                    "valueFrom": "--goterms"
                },
                {
                    "position": 2,
                    "valueFrom": "--pathways"
                },
                {
                    "position": 3,
                    "prefix": "--tempdir",
                    "valueFrom": "$(runtime.tmpdir)"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 15000,
                    "coresMin": 4
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "http://schema.org/author": "Michael Crusoe, Aleksandra Ola Tarkowska, Maxim Scheremetjew",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "label": "Parse Pfam hits from Interpro annotation output",
            "inputs": [
                {
                    "type": "File",
                    "label": "Interpro scan results in TSV format",
                    "format": "http://edamontology.org/format_3475",
                    "id": "#pfam_annotations.cwl/interpro"
                },
                {
                    "type": "string",
                    "id": "#pfam_annotations.cwl/outputname"
                }
            ],
            "baseCommand": [],
            "arguments": [
                "awk",
                "/Pfam/",
                "$(inputs.interpro)"
            ],
            "stdout": "$(inputs.outputname)",
            "outputs": [
                {
                    "type": "File",
                    "label": "Pfam results only",
                    "format": "http://edamontology.org/format_3475",
                    "id": "#pfam_annotations.cwl/annotations",
                    "outputBinding": {
                        "glob": "$(inputs.outputname)"
                    }
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "id": "#pfam_annotations.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 300,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "quay.io/biocontainers/biom-format:2.1.6--py36_0",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "biom-convert.sh"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3746",
                    "inputBinding": {
                        "prefix": "--input-fp"
                    },
                    "id": "#biom-convert.cwl/biom"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as HDF5-formatted table.",
                    "inputBinding": {
                        "prefix": "--to-hdf5"
                    },
                    "id": "#biom-convert.cwl/hdf5"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "The observation metadata to include from the input BIOM table file when\ncreating a tsv table file. By default no observation metadata will be\nincluded.\n",
                    "inputBinding": {
                        "prefix": "--header-key"
                    },
                    "id": "#biom-convert.cwl/header_key"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as JSON-formatted table.",
                    "inputBinding": {
                        "prefix": "--to-json"
                    },
                    "id": "#biom-convert.cwl/json"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--table-type",
                        "separate": true,
                        "valueFrom": "$(inputs.table_type)"
                    },
                    "id": "#biom-convert.cwl/table_type"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as TSV-formatted (classic) table.",
                    "inputBinding": {
                        "prefix": "--to-tsv"
                    },
                    "id": "#biom-convert.cwl/tsv"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "${ var ext = \"\";\n   if (inputs.json) { ext = \"_json.biom\"; }\n   if (inputs.hdf5) { ext = \"_hdf5.biom\"; }\n   if (inputs.tsv) { ext = \"_tsv.biom\"; }\n   var pre = inputs.biom.nameroot.split('.');\n   pre.pop()\n   return pre.join('.') + ext; }\n",
                    "prefix": "--output-fp"
                },
                {
                    "valueFrom": "--collapsed-observations"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${ var ext = \"\";\nif (inputs.json) { ext = \"_json.biom\"; }\nif (inputs.hdf5) { ext = \"_hdf5.biom\"; }\nif (inputs.tsv) { ext = \"_tsv.biom\"; }\nvar pre = inputs.biom.nameroot.split('.');\npre.pop()\nreturn pre.join('.') + ext; }\n"
                    },
                    "id": "#biom-convert.cwl/result"
                }
            ],
            "id": "#biom-convert.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "cmsearch-deoverlap.pl"
            ],
            "inputs": [
                {
                    "id": "#cmsearch-deoverlap-v0.02.cwl/clan_information",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--clanin"
                    },
                    "label": "clan information on the models provided",
                    "doc": "Not all models provided need to be a member of a clan"
                },
                {
                    "id": "#cmsearch-deoverlap-v0.02.cwl/cmsearch_matches",
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "inputBinding": {
                        "position": 1,
                        "valueFrom": "$(self.basename)"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#cmsearch-deoverlap-v0.02.cwl/deoverlapped_matches",
                    "doc": "http://eddylab.org/infernal/Userguide.pdf#page=60",
                    "label": "target hits table, format 2",
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "outputBinding": {
                        "glob": "*.deoverlapped"
                    }
                }
            ],
            "doc": "https://github.com/nawrockie/cmsearch_tblout_deoverlap/blob/master/00README.txt",
            "label": "Remove lower scoring overlaps from cmsearch --tblout files.",
            "requirements": [
                {
                    "class": "EnvVarRequirement",
                    "envDef": [
                        {
                            "envValue": "C",
                            "envName": "LC_ALL"
                        }
                    ]
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 200,
                    "coresMin": 2
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        "$(inputs.cmsearch_matches)"
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://github.com/nawrockie/cmsearch_tblout_deoverlap"
                            ],
                            "version": [
                                "0.02"
                            ],
                            "package": "cmsearch_tblout_deoverlap"
                        }
                    ]
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biocrusoe/cmsearch-deoverlap"
                }
            ],
            "id": "#cmsearch-deoverlap-v0.02.cwl",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/author": "Michael Crusoe, Maxim Scheremetjew"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "cmsearch"
            ],
            "inputs": [
                {
                    "id": "#infernal-cmsearch-v1.1.2.cwl/covariance_model_database",
                    "type": [
                        "string",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1
                    }
                },
                {
                    "id": "#infernal-cmsearch-v1.1.2.cwl/cpu",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--cpu"
                    },
                    "label": "Number of parallel CPU workers to use for multithreads"
                },
                {
                    "default": false,
                    "id": "#infernal-cmsearch-v1.1.2.cwl/cut_ga",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--cut_ga"
                    },
                    "label": "use CM's GA gathering cutoffs as reporting thresholds"
                },
                {
                    "id": "#infernal-cmsearch-v1.1.2.cwl/omit_alignment_section",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--noali"
                    },
                    "label": "Omit the alignment section from the main output.",
                    "doc": "This can greatly reduce the output volume."
                },
                {
                    "default": false,
                    "id": "#infernal-cmsearch-v1.1.2.cwl/only_hmm",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--hmmonly"
                    },
                    "label": "Only use the filter profile HMM for searches, do not use the CM",
                    "doc": "Only filter stages F1 through F3 will be executed, using strict P-value\nthresholds (0.02 for F1, 0.001 for F2 and 0.00001 for F3). Additionally\na bias composition filter is used after the F1 stage (with P=0.02\nsurvival threshold). Any hit that survives all stages and has an HMM\nE-value or bit score above the reporting threshold will be output.\n"
                },
                {
                    "id": "#infernal-cmsearch-v1.1.2.cwl/query_sequences",
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "position": 2
                    }
                },
                {
                    "id": "#infernal-cmsearch-v1.1.2.cwl/search_space_size",
                    "type": "int",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "-Z"
                    },
                    "label": "search space size in *Mb* to <x> for E-value calculations"
                }
            ],
            "outputs": [
                {
                    "id": "#infernal-cmsearch-v1.1.2.cwl/matches",
                    "doc": "http://eddylab.org/infernal/Userguide.pdf#page=60",
                    "label": "target hits table, format 2",
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "outputBinding": {
                        "glob": "${\n  var name = \"\";\n  if (typeof inputs.covariance_model_database == \"string\") {\n    name =\n      inputs.query_sequences.basename +\n      \".\" +\n      inputs.covariance_model_database.split(\"/\").slice(-1)[0] +\n      \".cmsearch_matches.tbl\";\n  } else {\n    name =\n      inputs.query_sequences.basename +\n      \".\" +\n      inputs.covariance_model_database.nameroot +\n      \".cmsearch_matches.tbl\";\n  }\n  return name;\n}\n"
                    }
                },
                {
                    "id": "#infernal-cmsearch-v1.1.2.cwl/programOutput",
                    "label": "direct output to file, not stdout",
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "outputBinding": {
                        "glob": "${\n  var name = \"\";\n  if (typeof inputs.covariance_model_database == \"string\") {\n    name =\n      inputs.query_sequences.basename +\n      \".\" +\n      inputs.covariance_model_database.split(\"/\").slice(-1)[0] +\n      \".cmsearch.out\";\n  } else {\n    name =\n      inputs.query_sequences.basename +\n      \".\" +\n      inputs.covariance_model_database.nameroot +\n      \".cmsearch.out\";\n  }\n  return name;\n}\n"
                    }
                }
            ],
            "doc": "Infernal (\"INFERence of RNA ALignment\") is for searching DNA sequence databases for RNA structure and sequence similarities. It is an implementation of a special case of profile stochastic context-free grammars called covariance models (CMs). A CM is like a sequence profile, but it scores a combination of sequence consensus and RNA secondary structure consensus, so in many cases, it is more capable of identifying RNA homologs that conserve their secondary structure more than their primary sequence.\nPlease visit http://eddylab.org/infernal/ for full documentation.\nVersion 1.1.2 can be downloaded from http://eddylab.org/infernal/infernal-1.1.2.tar.gz\n",
            "label": "Search sequence(s) against a covariance model database",
            "arguments": [
                {
                    "position": 0,
                    "prefix": "--tblout",
                    "valueFrom": "${\n  var name = \"\";\n  if (typeof inputs.covariance_model_database == \"string\") {\n    name =\n      inputs.query_sequences.basename +\n      \".\" +\n      inputs.covariance_model_database.split(\"/\").slice(-1)[0] +\n      \".cmsearch_matches.tbl\";\n  } else {\n    name =\n      inputs.query_sequences.basename +\n      \".\" +\n      inputs.covariance_model_database.nameroot +\n      \".cmsearch_matches.tbl\";\n  }\n  return name;\n}\n"
                },
                {
                    "position": 0,
                    "prefix": "-o",
                    "valueFrom": "${\n  var name = \"\";\n  if (typeof inputs.covariance_model_database == \"string\") {\n    name =\n      inputs.query_sequences.basename +\n      \".\" +\n      inputs.covariance_model_database.split(\"/\").slice(-1)[0] +\n      \".cmsearch.out\";\n  } else {\n    name =\n      inputs.query_sequences.basename +\n      \".\" +\n      inputs.covariance_model_database.nameroot +\n      \".cmsearch.out\";\n  }\n  return name;\n}\n"
                },
                {
                    "valueFrom": "> /dev/null",
                    "shellQuote": false,
                    "position": 10
                },
                {
                    "valueFrom": "2> /dev/null",
                    "shellQuote": false,
                    "position": 11
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_011809"
                            ],
                            "version": [
                                "1.1.2"
                            ],
                            "package": "infernal"
                        }
                    ]
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/infernal:1.1.2--h470a237_1"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 32000,
                    "coresMin": 8
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "id": "#infernal-cmsearch-v1.1.2.cwl",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/author": "Michael Crusoe, Maxim Scheremetjew, Ekaterina Sakharova"
        },
        {
            "class": "CommandLineTool",
            "label": "index a sequence file for use by esl-sfetch",
            "doc": "https://github.com/EddyRivasLab/easel",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "quay.io/biocontainers/hmmer:3.2.1--hf484d3e_1",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "esl-index.sh"
            ],
            "requirements": [
                {
                    "listing": [
                        "$(inputs.sequences)"
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "coresMin": 4,
                    "ramMin": 5000,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "-f",
                        "position": 1,
                        "valueFrom": "$(self.basename)"
                    },
                    "label": "Input fasta file.",
                    "id": "#esl-sfetch-index.cwl/sequences"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".ssi"
                        }
                    ],
                    "outputBinding": {
                        "glob": "folder/$(inputs.sequences.basename)"
                    },
                    "label": "The index file",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-sfetch-index.cwl/sequences_with_index"
                }
            ],
            "id": "#esl-sfetch-index.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "extract by names from an indexed sequence file",
            "doc": "https://github.com/EddyRivasLab/easel",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "quay.io/biocontainers/hmmer:3.2.1--hf484d3e_1",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "ramMin": 200,
                    "coresMin": 2,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "label": "sequence file indexed by esl-sfetch-index",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-Cf",
                        "position": 1
                    },
                    "secondaryFiles": [
                        {
                            "pattern": ".ssi"
                        }
                    ],
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-sfetch-manyseqs.cwl/indexed_sequences"
                },
                {
                    "doc": "GDF format: <newname> <from> <to> <source seqname>\nspace/tabdelimited\n",
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#esl-sfetch-manyseqs.cwl/names_contain_subseq_coords"
                }
            ],
            "baseCommand": [
                "esl-sfetch"
            ],
            "stdout": "$(inputs.indexed_sequences.basename)_$(inputs.names_contain_subseq_coords.basename).fasta",
            "outputs": [
                {
                    "type": "File",
                    "id": "#esl-sfetch-manyseqs.cwl/sequences",
                    "outputBinding": {
                        "glob": "$(inputs.indexed_sequences.basename)_$(inputs.names_contain_subseq_coords.basename).fasta"
                    }
                }
            ],
            "id": "#esl-sfetch-manyseqs.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "alpine:3.7",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 2,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "label": "output from infernal cmsearch",
                    "format": "http://edamontology.org/format_3475",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#extract-coords_awk.cwl/infernal_matches"
                },
                {
                    "label": "output file name",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-n",
                        "valueFrom": "$(self? self : inputs.infernal_matches.basename)\n"
                    },
                    "default": "",
                    "id": "#extract-coords_awk.cwl/name"
                }
            ],
            "baseCommand": "awk_tool",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "outputBinding": {
                        "glob": "*matched_seqs_with_coords*"
                    },
                    "id": "#extract-coords_awk.cwl/matched_seqs_with_coords"
                }
            ],
            "doc": "The awk script takes the output of Infernal's cmsearch so-called fmt=1 mode\nand makes it suitable for use by esl-sfetch, a sequence selector\n\nReading the user's guide for Infernal, Version 1.1.2; July 2016\nhttp://eddylab.org/infernal/Userguide.pdf#page=60 we see that\nthe relevant fields in the cmsearch output are:\n(column number: explanation)\n1: The name of the target sequence or profile\n3: The name of the query sequence or profile\n8: The start of the alignment of this hit with respect to the\n    sequence, numbered 1..L for a sequence of L residues.\n9: The end of the alignment of this hit with respect to the sequence,\n    numbered 1..L for a sequence of L residues\n\nLikewise the format esl-sfetch wants is: <newname> <from> <to> <source seqname>\n\nPutting it all together we see that the newname (which esl-sfetch with\noutput using) is a concatenation of the original name, the sequence\nnumber, and the coordinates.\n",
            "id": "#extract-coords_awk.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "ramMin": 200,
                    "coresMin": 8,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "label": "fasta file (from esl) with all subunits",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#get_subunits_coords.cwl/input"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-l"
                    },
                    "id": "#get_subunits_coords.cwl/pattern_LSU"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#get_subunits_coords.cwl/pattern_SSU"
                }
            ],
            "baseCommand": "get_subunits_coords.py",
            "stdout": "stdout.txt",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*LSU*"
                    },
                    "id": "#get_subunits_coords.cwl/LSU_seqs"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*SSU*"
                    },
                    "id": "#get_subunits_coords.cwl/SSU_seqs"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "RNA-counts"
                    },
                    "id": "#get_subunits_coords.cwl/counts"
                },
                {
                    "type": "File",
                    "id": "#get_subunits_coords.cwl/stdout",
                    "outputBinding": {
                        "glob": "stdout.txt"
                    }
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "id": "#get_subunits_coords.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "requirements": [
                {
                    "ramMin": 200,
                    "coresMin": 2,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "label": "fasta file (from esl) with all subunits",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#get_subunits.cwl/input"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-e"
                    },
                    "id": "#get_subunits.cwl/pattern_5.8S"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-f"
                    },
                    "id": "#get_subunits.cwl/pattern_5S"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-l"
                    },
                    "id": "#get_subunits.cwl/pattern_LSU"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#get_subunits.cwl/pattern_SSU"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "id": "#get_subunits.cwl/prefix"
                }
            ],
            "baseCommand": "get_subunits.py",
            "stdout": "stdout.txt",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "sequence-categorisation/*LSU.fasta*"
                    },
                    "id": "#get_subunits.cwl/LSU_seqs"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "sequence-categorisation/*SSU.fasta*"
                    },
                    "id": "#get_subunits.cwl/SSU_seqs"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "sequence-categorisation/*.fa"
                    },
                    "id": "#get_subunits.cwl/fastas"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputBinding": {
                        "glob": "sequence-categorisation"
                    },
                    "id": "#get_subunits.cwl/sequence-categorisation"
                },
                {
                    "type": "File",
                    "id": "#get_subunits.cwl/stdout",
                    "outputBinding": {
                        "glob": "stdout.txt"
                    }
                }
            ],
            "id": "#get_subunits.cwl",
            "http://schema.org/author": "Ekaterina Sakharova, Varsha Kale",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0"
        },
        {
            "class": "CommandLineTool",
            "label": "visualize using krona",
            "requirements": [
                {
                    "ramMin": 200,
                    "coresMin": 2,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "Tab-delimited text file",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#krona.cwl/otu_counts"
                }
            ],
            "baseCommand": "ktImportText",
            "arguments": [
                {
                    "valueFrom": "krona.html",
                    "prefix": "-o"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/html",
                    "outputBinding": {
                        "glob": "*.html"
                    },
                    "id": "#krona.cwl/otu_visualization"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "kronav2.7.1:1.0",
                    "class": "DockerRequirement"
                }
            ],
            "id": "#krona.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "MAPseq v 1.2.3",
            "doc": "sequence read classification tools designed to assign taxonomy and OTU\nclassifications to ribosomal RNA sequences.\nhttps://github.com/jfmrod/MAPseq\n",
            "requirements": [
                {
                    "ramMin": 25000,
                    "coresMin": 8,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster"
                        }
                    ],
                    "format": "http://edamontology.org/format_1929",
                    "id": "#mapseq.cwl/database"
                },
                {
                    "type": "File",
                    "id": "#mapseq.cwl/prefix"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "format": "http://edamontology.org/format_1929",
                    "id": "#mapseq.cwl/sequences"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#mapseq.cwl/taxonomy"
                }
            ],
            "baseCommand": "mapseq",
            "arguments": [
                "-nthreads",
                "8",
                "-tophits",
                "80",
                "-topotus",
                "40",
                "-outfmt",
                "simple"
            ],
            "stdout": "$(inputs.prefix.nameroot)_$(inputs.database.basename).mseq",
            "outputs": [
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "id": "#mapseq.cwl/classifications",
                    "outputBinding": {
                        "glob": "$(inputs.prefix.nameroot)_$(inputs.database.basename).mseq"
                    }
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mapseq:latest"
                }
            ],
            "id": "#mapseq.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "mapseq2biom:latest",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "ramMin": 200,
                    "tmpdirMin": 200,
                    "coresMin": 2,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "label": "label to add to the top of the outfile OTU table",
                    "inputBinding": {
                        "prefix": "--label"
                    },
                    "id": "#mapseq2biom.cwl/label"
                },
                {
                    "type": "string",
                    "doc": "the OTU table produced for the taxonomies found in the reference\ndatabases that was used with MAPseq\n",
                    "inputBinding": {
                        "prefix": "--otuTable"
                    },
                    "id": "#mapseq2biom.cwl/otu_table"
                },
                {
                    "type": "File",
                    "label": "the output from the MAPseq that assigns a taxonomy to a sequence",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "inputBinding": {
                        "prefix": "--query"
                    },
                    "id": "#mapseq2biom.cwl/query"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "output NCBI taxids for all databases bar UNITE",
                    "inputBinding": {
                        "prefix": "--taxid"
                    },
                    "id": "#mapseq2biom.cwl/taxid_flag"
                }
            ],
            "baseCommand": [
                "mapseq2biom.pl"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.query.basename).tsv",
                    "prefix": "--outfile"
                },
                {
                    "valueFrom": "$(inputs.query.basename).txt",
                    "prefix": "--krona"
                },
                {
                    "valueFrom": "$(inputs.query.basename).notaxid.tsv",
                    "prefix": "--notaxidfile"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3746",
                    "outputBinding": {
                        "glob": "$(inputs.query.basename).tsv"
                    },
                    "id": "#mapseq2biom.cwl/otu_tsv"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3746",
                    "outputBinding": {
                        "glob": "$(inputs.query.basename).notaxid.tsv"
                    },
                    "id": "#mapseq2biom.cwl/otu_tsv_notaxid"
                },
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.query.basename).txt"
                    },
                    "id": "#mapseq2biom.cwl/otu_txt"
                }
            ],
            "id": "#mapseq2biom.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#pull_ncrnas.cwl/hits"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#pull_ncrnas.cwl/model"
                }
            ],
            "baseCommand": [
                "pull_ncrnas.sh"
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.RF*"
                    },
                    "id": "#pull_ncrnas.cwl/matches"
                }
            ],
            "id": "#pull_ncrnas.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "split FASTA by number of records",
            "doc": "based upon code by Maxim Scheremetjew, EMBL-EBI",
            "requirements": [
                {
                    "listing": [
                        "$(inputs.seqs)"
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 5000,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "mgnify/pipeline-v5.dna_chunking:latest",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#fasta_chunker.cwl/chunk_size"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#fasta_chunker.cwl/number_of_output_files"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#fasta_chunker.cwl/same_number_of_residues"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#fasta_chunker.cwl/seqs"
                }
            ],
            "baseCommand": [
                "esl-ssplit.sh"
            ],
            "outputs": [
                {
                    "format": "http://edamontology.org/format_1929",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "$(inputs.seqs.basename).*"
                    },
                    "id": "#fasta_chunker.cwl/chunks"
                }
            ],
            "id": "#fasta_chunker.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "split FAA by number of records",
            "doc": "based upon code by Maxim Scheremetjew, EMBL-EBI",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 8000,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "alpine:3.7",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_007173"
                            ],
                            "version": [
                                "1.65",
                                "1.66",
                                "1.69"
                            ],
                            "package": "biopython"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#protein_chunker.cwl/chunk_size"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-f"
                    },
                    "id": "#protein_chunker.cwl/file_format"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#protein_chunker.cwl/seqs"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "> /dev/null",
                    "shellQuote": false,
                    "position": 10
                },
                {
                    "valueFrom": "2> /dev/null",
                    "shellQuote": false,
                    "position": 11
                }
            ],
            "baseCommand": [
                "split_to_chunks.py"
            ],
            "outputs": [
                {
                    "format": "http://edamontology.org/format_1929",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*_*"
                    },
                    "id": "#protein_chunker.cwl/chunks"
                }
            ],
            "id": "#protein_chunker.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "mgnify/pipeline-v5.python3:latest",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "format": "http://edamontology.org/format_3475",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#hmmscan_tab_modification.cwl/input_table"
                }
            ],
            "baseCommand": [
                "hmmscan_tab.py"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.input_table.nameroot).tsv",
                    "prefix": "-o"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "outputBinding": {
                        "glob": "*.tsv"
                    },
                    "id": "#hmmscan_tab_modification.cwl/output_with_tabs"
                }
            ],
            "id": "#hmmscan_tab_modification.cwl",
            "http://schema.org/author": "Ekaterina Sakharova",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0"
        },
        {
            "class": "CommandLineTool",
            "label": "Biosequence analysis using profile hidden Markov models",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "quay.io/biocontainers/hmmer:3.2.1--hf484d3e_1",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 6000,
                    "coresMin": 4,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "baseCommand": [
                "hmmsearch"
            ],
            "arguments": [
                {
                    "valueFrom": "> /dev/null",
                    "shellQuote": false,
                    "position": 10
                },
                {
                    "valueFrom": "2> /dev/null",
                    "shellQuote": false,
                    "position": 11
                },
                {
                    "prefix": "--domtblout",
                    "valueFrom": "$(inputs.seqfile.nameroot)_hmmsearch.tbl",
                    "position": 2
                },
                {
                    "prefix": "--cpu",
                    "valueFrom": "4"
                },
                {
                    "prefix": "-o",
                    "valueFrom": "/dev/null"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--cut_ga"
                    },
                    "id": "#hmmsearch.cwl/gathering_bit_score"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--noali"
                    },
                    "id": "#hmmsearch.cwl/omit_alignment"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#hmmsearch.cwl/path_database"
                },
                {
                    "format": "http://edamontology.org/format_1929",
                    "type": "File",
                    "inputBinding": {
                        "position": 6,
                        "separate": true
                    },
                    "id": "#hmmsearch.cwl/seqfile"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "outputBinding": {
                        "glob": "*_hmmsearch.tbl"
                    },
                    "id": "#hmmsearch.cwl/output_table"
                }
            ],
            "id": "#hmmsearch.cwl",
            "http://schema.org/author": "Ekaterina Sakharova",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0"
        },
        {
            "class": "CommandLineTool",
            "label": "Quality control filtering step using the BioPython package.",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "alpine:3.7",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 4,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "run_quality_filtering.py"
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#qc-filtering.cwl/input_file_format"
                },
                {
                    "type": "int",
                    "default": 100,
                    "label": "Minimum read or contig length",
                    "doc": "Specify the minimum read or contig length for sequences to pass QC filtering.\n",
                    "id": "#qc-filtering.cwl/min_length"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "label": "Trimmed sequence file",
                    "doc": "Trimmed and FASTQ to FASTA converted sequences file.\n",
                    "id": "#qc-filtering.cwl/seq_file"
                },
                {
                    "type": "string",
                    "default": "stats_summary",
                    "label": "Post QC stats output file name",
                    "doc": "Give a name for the file which will hold the stats after QC.\n",
                    "id": "#qc-filtering.cwl/stats_file_name"
                },
                {
                    "type": "int",
                    "label": "Number of submitted sequences",
                    "doc": "Number of originally submitted sequences as in the user submitted FASTQ file - single end FASTQ or pair end merged FASTQ file.\n",
                    "id": "#qc-filtering.cwl/submitted_seq_count"
                }
            ],
            "outputs": [
                {
                    "label": "Filtered output file",
                    "format": "http://edamontology.org/format_1929",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.seq_file.nameroot).fasta"
                    },
                    "id": "#qc-filtering.cwl/filtered_file"
                },
                {
                    "label": "Stats summary output file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.stats_file_name)"
                    },
                    "id": "#qc-filtering.cwl/stats_summary_file"
                }
            ],
            "arguments": [
                {
                    "position": 2,
                    "valueFrom": "$(inputs.seq_file.nameroot).fasta"
                },
                {
                    "position": 3,
                    "valueFrom": "$(inputs.stats_file_name)"
                },
                {
                    "position": 4,
                    "valueFrom": "$(inputs.submitted_seq_count)"
                },
                {
                    "position": 5,
                    "prefix": "--min_length",
                    "valueFrom": "$(inputs.min_length)"
                },
                {
                    "position": 6,
                    "prefix": "--extension",
                    "valueFrom": "$(inputs.input_file_format)"
                }
            ],
            "id": "#qc-filtering.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "Post QC-ed input analysis of sequence file",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "qc-stats:latest",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "listing": [
                        {
                            "entry": "$({class: 'Directory', listing: []})",
                            "entryname": "$(inputs.out_dir_name)",
                            "writable": true
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 4,
                    "ramMin": 900,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "MGRAST_base.py"
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#qc-stats.cwl/QCed_reads"
                },
                {
                    "label": "Prefix for the files associated with GC distribution",
                    "type": "string",
                    "default": "GC-distribution.out",
                    "id": "#qc-stats.cwl/gc_sum"
                },
                {
                    "label": "Prefix for the files assocaited with sequence length distribution",
                    "type": "string",
                    "default": "seq-length.out",
                    "id": "#qc-stats.cwl/length_sum"
                },
                {
                    "label": "Maximum number of sequences to sub-sample",
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2000000,
                    "id": "#qc-stats.cwl/max_seq"
                },
                {
                    "label": "Prefix for the files associated with nucleotide distribution",
                    "type": "string",
                    "default": "nucleotide-distribution.out",
                    "id": "#qc-stats.cwl/nucleotide_distribution"
                },
                {
                    "label": "Specifies output subdirectory",
                    "type": "string",
                    "default": "qc-statistics",
                    "id": "#qc-stats.cwl/out_dir_name"
                },
                {
                    "label": "Specifies the number of sequences in the input read file (FASTA formatted)",
                    "type": "int",
                    "id": "#qc-stats.cwl/sequence_count"
                },
                {
                    "label": "File names for summary of sequences, e.g. number, min/max length etc.",
                    "type": "string",
                    "default": "summary.out",
                    "id": "#qc-stats.cwl/summary"
                }
            ],
            "outputs": [
                {
                    "label": "Contains all stats output files",
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.out_dir_name)"
                    },
                    "id": "#qc-stats.cwl/output_dir"
                },
                {
                    "label": "Contains the summary statistics for the input sequence file",
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/plain",
                    "outputBinding": {
                        "glob": "$(inputs.out_dir_name)/$(inputs.summary)"
                    },
                    "id": "#qc-stats.cwl/summary_out"
                }
            ],
            "arguments": [
                {
                    "position": 1,
                    "prefix": "-o",
                    "valueFrom": "$(inputs.out_dir_name)/$(inputs.summary)"
                },
                {
                    "position": 2,
                    "prefix": "-d",
                    "valueFrom": "${ var suffix = '.full';\n   if (inputs.sequence_count > inputs.max_seq) {\n     suffix = '.sub-set';\n   }\n   return \"\".concat(inputs.out_dir_name, '/', inputs.nucleotide_distribution, suffix);\n}\n"
                },
                {
                    "position": 3,
                    "prefix": "-g",
                    "valueFrom": "${ var suffix = '.full';\n   if (inputs.sequence_count > inputs.max_seq) {\n     suffix = '.sub-set';\n   }\n   return \"\".concat(inputs.out_dir_name, '/', inputs.gc_sum, suffix);\n}\n"
                },
                {
                    "position": 4,
                    "prefix": "-l",
                    "valueFrom": "${ var suffix = '.full';\n   if (inputs.sequence_count > inputs.max_seq) {\n     suffix = '.sub-set';\n   }\n   return \"\".concat(inputs.out_dir_name, '/', inputs.length_sum, suffix);\n}\n"
                },
                {
                    "position": 5,
                    "valueFrom": "${ if (inputs.sequence_count > inputs.max_seq) { return '-m '.concat(inputs.max_seq)} else { return ''} }"
                }
            ],
            "id": "#qc-stats.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "generate all functional stats and orf stats",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 8000,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-a"
                    },
                    "id": "#functional_stats.cwl/antismash_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-c"
                    },
                    "id": "#functional_stats.cwl/cds_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-r"
                    },
                    "id": "#functional_stats.cwl/cmsearch_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-k"
                    },
                    "id": "#functional_stats.cwl/hmmscan"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#functional_stats.cwl/interproscan"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-ko"
                    },
                    "id": "#functional_stats.cwl/ko_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "id": "#functional_stats.cwl/pfam"
                }
            ],
            "baseCommand": [
                "functional_stats.py"
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3750",
                    "outputBinding": {
                        "glob": "antismash*.yaml"
                    },
                    "id": "#functional_stats.cwl/antismash_yaml"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3750",
                    "outputBinding": {
                        "glob": "InterProScan*.yaml"
                    },
                    "id": "#functional_stats.cwl/ips_yaml"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3750",
                    "outputBinding": {
                        "glob": "KO*.yaml"
                    },
                    "id": "#functional_stats.cwl/ko_yaml"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3750",
                    "outputBinding": {
                        "glob": "pfam*.yaml"
                    },
                    "id": "#functional_stats.cwl/pfam_yaml"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "functional-annotation"
                    },
                    "id": "#functional_stats.cwl/stats"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "id": "#functional_stats.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "gather summary file from InterProScan",
            "requirements": [
                {
                    "ramMin": 9500,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3750",
                    "inputBinding": {
                        "prefix": "-a"
                    },
                    "id": "#write_summaries.cwl/antismash_entry_maps"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--antismash-name"
                    },
                    "id": "#write_summaries.cwl/antismash_outname"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3750",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#write_summaries.cwl/ips_entry_maps"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--ips-name"
                    },
                    "id": "#write_summaries.cwl/ips_outname"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3750",
                    "inputBinding": {
                        "prefix": "-k"
                    },
                    "id": "#write_summaries.cwl/ko_entry_maps"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--ko-name"
                    },
                    "id": "#write_summaries.cwl/ko_outname"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3750",
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "id": "#write_summaries.cwl/pfam_entry_maps"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--pfam-name"
                    },
                    "id": "#write_summaries.cwl/pfam_outname"
                }
            ],
            "baseCommand": [
                "write_summaries.py"
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*summary.antismash"
                    },
                    "id": "#write_summaries.cwl/summary_antismash"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*summary.ips"
                    },
                    "id": "#write_summaries.cwl/summary_ips"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*summary.ko"
                    },
                    "id": "#write_summaries.cwl/summary_ko"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*summary.pfam"
                    },
                    "id": "#write_summaries.cwl/summary_pfam"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "id": "#write_summaries.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "alpine:3.7",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 200,
                    "coresMin": 8,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "add_header"
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-h"
                    },
                    "id": "#add_header.cwl/header"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#add_header.cwl/input_table"
                }
            ],
            "stdout": "$(inputs.input_table.nameroot)",
            "outputs": [
                {
                    "type": "File",
                    "format": "${if (\"format\" in inputs.input_table) return inputs.input_table.format; else return 'undefined'}",
                    "id": "#add_header.cwl/output_table",
                    "outputBinding": {
                        "glob": "$(inputs.input_table.nameroot)"
                    }
                }
            ],
            "id": "#add_header.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "Replaces problematic characters from FASTA headers with dashes",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#clean_fasta_headers.cwl/sequences"
                }
            ],
            "stdin": "$(inputs.sequences.path)",
            "baseCommand": [
                "tr",
                "\" /|<_;#\"",
                "-------"
            ],
            "stdout": "$(inputs.sequences.nameroot).unfiltered_fasta",
            "outputs": [
                {
                    "type": "File",
                    "id": "#clean_fasta_headers.cwl/sequences_with_cleaned_headers",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.nameroot).unfiltered_fasta"
                    }
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "id": "#clean_fasta_headers.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "Redirecting Multiple Files Contain in a Single File",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "baseCommand": [
                "cat"
            ],
            "inputs": [
                {
                    "type": [
                        {
                            "type": "array",
                            "items": [
                                "File",
                                "string"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#concatenate.cwl/files"
                },
                {
                    "type": "string",
                    "id": "#concatenate.cwl/outputFileName"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#concatenate.cwl/postfix"
                }
            ],
            "stdout": "$(inputs.outputFileName)$(inputs.postfix)",
            "outputs": [
                {
                    "id": "#concatenate.cwl/result",
                    "type": "File",
                    "format": "${if ((typeof(inputs.files[0]) == 'string') || (inputs.files.length == 0)) return 'undefined'; else { if (\"format\" in inputs.files[0]) return inputs.files[0].format; else return 'undefined'} }",
                    "outputBinding": {
                        "glob": "$(inputs.outputFileName)$(inputs.postfix)"
                    }
                }
            ],
            "doc": "The cat (short for concatenate) command is one of the most frequently used command in Linux/Unix like operating systems. cat command allows us to create single or multiple files, view contain of file, concatenate files and redirect output in terminal or files.\n",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 200,
                    "coresMax": 1
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "id": "#concatenate.cwl",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/author": "Michael Crusoe, Maxim Scheremetjew"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "baseCommand": [
                "grep",
                "-c",
                "^>"
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#count_fasta.cwl/number"
                },
                {
                    "type": "File",
                    "streamable": true,
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#count_fasta.cwl/sequences"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "|",
                    "position": 2,
                    "shellQuote": false
                },
                {
                    "valueFrom": "cat",
                    "shellQuote": false,
                    "position": 3
                }
            ],
            "stdout": "grepcount",
            "outputs": [
                {
                    "type": "int",
                    "outputBinding": {
                        "glob": "grepcount",
                        "loadContents": true,
                        "outputEval": "${\n  var grep_count = parseInt(self[0].contents) || 0;\n  if (grep_count === 0) {\n    return 0;\n  } else {\n    return parseInt(grep_count / inputs.number);\n  }\n}\n"
                    },
                    "id": "#count_fasta.cwl/count"
                }
            ],
            "id": "#count_fasta.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "id": "#count_number_lines.cwl/input_file"
                }
            ],
            "baseCommand": [
                "bash"
            ],
            "arguments": [
                {
                    "valueFrom": "expr \\$(cat $(inputs.input_file.path) | wc -l)\n",
                    "prefix": "-c"
                }
            ],
            "stdout": "count",
            "outputs": [
                {
                    "type": "int",
                    "outputBinding": {
                        "glob": "count",
                        "outputEval": "$(Number(self[0].contents))",
                        "loadContents": true
                    },
                    "id": "#count_number_lines.cwl/number"
                }
            ],
            "id": "#count_number_lines.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 5000,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-i"
                    },
                    "id": "#generate_checksum.cwl/input_file"
                }
            ],
            "baseCommand": [
                "generate_checksum.py"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*sha1"
                    },
                    "id": "#generate_checksum.cwl/hashsum"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "id": "#generate_checksum.cwl",
            "https://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "https://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "make_csv.py"
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#make_csv.cwl/output_name"
                },
                {
                    "format": "http://edamontology.org/format_3475",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#make_csv.cwl/tab_sep_table"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3752",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    },
                    "id": "#make_csv.cwl/csv_result"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "alpine:3.7",
                    "class": "DockerRequirement"
                }
            ],
            "id": "#make_csv.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 16,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#move.cwl/initial_file"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#move.cwl/out_file_name"
                }
            ],
            "baseCommand": [
                "mv"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.out_file_name)"
                    },
                    "id": "#move.cwl/renamed_file"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "id": "#move.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "unzip files",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 2000,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "alpine:3.7",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "specs": null,
                            "package": "gunzip"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "is this an assembly file?",
                    "id": "#multiple-gunzip.cwl/assembly"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 2
                    },
                    "label": "for seqprep result: unmerged forward seqprep output or single end reads",
                    "id": "#multiple-gunzip.cwl/forward_unmerged_reads"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "are these raw reads or amplicon reads?",
                    "id": "#multiple-gunzip.cwl/reads"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 3
                    },
                    "label": " unmerged reverse seqprep output",
                    "id": "#multiple-gunzip.cwl/reverse_unmerged_reads"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "label": "merged seq prep output",
                    "id": "#multiple-gunzip.cwl/target_reads"
                }
            ],
            "baseCommand": [
                "gunzip",
                "-c"
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "$(inputs.target_reads.format)",
                    "id": "#multiple-gunzip.cwl/unzipped_file",
                    "outputBinding": {
                        "glob": "${ var ext = \"\"; if (inputs.assembly) { ext = inputs.target_reads.nameroot.split('.')[0] + '_FASTA.unfiltered'; } if (inputs.reads) { ext = inputs.target_reads.nameroot.split('.')[0] + '_FASTQ.fastq'; } return ext; }"
                    }
                }
            ],
            "stdout": "${ var ext = \"\"; if (inputs.assembly) { ext = inputs.target_reads.nameroot.split('.')[0] + '_FASTA.unfiltered'; } if (inputs.reads) { ext = inputs.target_reads.nameroot.split('.')[0] + '_FASTQ.fastq'; } return ext; }",
            "id": "#multiple-gunzip.cwl",
            "https://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "https://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 16,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#gzip.cwl/uncompressed_file"
                }
            ],
            "baseCommand": [
                "pigz"
            ],
            "arguments": [
                "-p",
                "16",
                "-c"
            ],
            "stdout": "$(inputs.uncompressed_file.basename).gz",
            "outputs": [
                {
                    "type": "File",
                    "id": "#gzip.cwl/compressed_file",
                    "outputBinding": {
                        "glob": "$(inputs.uncompressed_file.basename).gz"
                    }
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "id": "#gzip.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "output QC-FAILED or QC-PASSED file as intermediate flag",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#qc-flag.cwl/qc_count"
                }
            ],
            "baseCommand": [
                "touch"
            ],
            "arguments": [
                {
                    "valueFrom": "${ var flag = \"\"; if (inputs.qc_count == 0) { flag = 'QC-FAILED'; } else { flag = 'QC-PASSED'; } return flag; }"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "QC-*"
                    },
                    "id": "#qc-flag.cwl/qc-flag"
                }
            ],
            "id": "#qc-flag.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 1000,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-f"
                    },
                    "id": "#result_chunker.cwl/format_file"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#result_chunker.cwl/infile"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#result_chunker.cwl/outdirname"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-t"
                    },
                    "id": "#result_chunker.cwl/type_fasta"
                }
            ],
            "baseCommand": [
                "run_result_file_chunker.py"
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "$(inputs.outdirname)/*"
                    },
                    "id": "#result_chunker.cwl/chunks"
                }
            ],
            "id": "#result_chunker.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "null",
                                "Directory"
                            ]
                        }
                    ],
                    "id": "#return_directory.cwl/dir_list"
                },
                {
                    "type": "string",
                    "id": "#return_directory.cwl/dir_name"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "null",
                                "File"
                            ]
                        }
                    ],
                    "id": "#return_directory.cwl/file_list"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "id": "#return_directory.cwl/out"
                }
            ],
            "expression": "${\n  var list2 = [];\n  var process;\n  if (inputs.file_list) { process = inputs.file_list } else { process = inputs.dir_list}\n  for (const item in process) {\n      if (process[item] != null) {\n          list2.push(process[item]) }; }\n  return {\"out\": {\n    \"class\": \"Directory\",\n    \"basename\": inputs.dir_name,\n    \"listing\": list2\n    }\n  }; }\n",
            "id": "#return_directory.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "ubuntu:latest",
                    "class": "DockerRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 1000,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "touch"
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#touch_file.cwl/filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.filename)"
                    },
                    "id": "#touch_file.cwl/created_file"
                }
            ],
            "id": "#touch_file.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 20000
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#main/5.8s_pattern"
                },
                {
                    "type": "string",
                    "id": "#main/5s_pattern"
                },
                {
                    "type": "string",
                    "id": "#main/CGC_config"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/CGC_postfixes"
                },
                {
                    "type": "string",
                    "id": "#main/EggNOG_data_dir"
                },
                {
                    "type": "string",
                    "id": "#main/EggNOG_db"
                },
                {
                    "type": "string",
                    "id": "#main/EggNOG_diamond_db"
                },
                {
                    "type": "boolean",
                    "id": "#main/HMM_gathering_bit_score"
                },
                {
                    "type": "string",
                    "id": "#main/HMM_name_database"
                },
                {
                    "type": "boolean",
                    "id": "#main/HMM_omit_alignment"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/InterProScan_applications"
                },
                {
                    "type": "string",
                    "id": "#main/InterProScan_databases"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/InterProScan_outputFormat"
                },
                {
                    "type": "string",
                    "id": "#main/Uniref90_db_txt"
                },
                {
                    "type": "int",
                    "id": "#main/cgc_chunk_size"
                },
                {
                    "type": "string",
                    "id": "#main/clusters_glossary"
                },
                {
                    "type": "int",
                    "id": "#main/contig_min_length"
                },
                {
                    "type": "File",
                    "id": "#main/contigs"
                },
                {
                    "type": "string",
                    "id": "#main/diamond_databaseFile"
                },
                {
                    "type": "string",
                    "id": "#main/diamond_header"
                },
                {
                    "type": "int",
                    "id": "#main/diamond_maxTargetSeqs"
                },
                {
                    "type": "string",
                    "default": "illumina_5",
                    "id": "#main/fgs_train"
                },
                {
                    "type": "string",
                    "id": "#main/func_ann_names_hmmer"
                },
                {
                    "type": "string",
                    "id": "#main/func_ann_names_ips"
                },
                {
                    "type": "string",
                    "default": "prodigal,fgs",
                    "id": "#main/genecaller_order"
                },
                {
                    "type": "string",
                    "id": "#main/go_config"
                },
                {
                    "type": "string",
                    "id": "#main/gp_flatfiles_path"
                },
                {
                    "type": "string",
                    "id": "#main/graphs"
                },
                {
                    "type": "string",
                    "id": "#main/hmmsearch_header"
                },
                {
                    "type": "string",
                    "id": "#main/ips_header"
                },
                {
                    "type": "string",
                    "id": "#main/ko_file"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster",
                            "required": null
                        }
                    ],
                    "id": "#main/lsu_db"
                },
                {
                    "type": "string",
                    "id": "#main/lsu_label"
                },
                {
                    "type": "string",
                    "id": "#main/lsu_otus"
                },
                {
                    "type": "string",
                    "id": "#main/lsu_tax"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/other_ncrna_models"
                },
                {
                    "type": "string",
                    "id": "#main/pathways_classes"
                },
                {
                    "type": "string",
                    "id": "#main/pathways_names"
                },
                {
                    "type": "int",
                    "id": "#main/protein_chunk_size_IPS"
                },
                {
                    "type": "int",
                    "id": "#main/protein_chunk_size_eggnog"
                },
                {
                    "type": "int",
                    "id": "#main/protein_chunk_size_hmm"
                },
                {
                    "type": "string",
                    "id": "#main/rfam_model_clans"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/rfam_models"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster",
                            "required": null
                        }
                    ],
                    "id": "#main/ssu_db"
                },
                {
                    "type": "string",
                    "id": "#main/ssu_label"
                },
                {
                    "type": "string",
                    "id": "#main/ssu_otus"
                },
                {
                    "type": "string",
                    "id": "#main/ssu_tax"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/after-qc/bgzip_fasta_file",
                    "id": "#main/bgzip_fasta_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/after-qc/bgzip_index",
                    "id": "#main/bgzip_index"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#main/after-qc/chunking_nucleotides",
                    "id": "#main/chunking_nucleotides"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#main/after-qc/chunking_proteins",
                    "id": "#main/chunking_proteins"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/touch_file_flag/created_file",
                    "id": "#main/completed_flag_file"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/after-qc/compressed_files",
                    "pickValue": "all_non_null",
                    "id": "#main/compressed_files"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#main/after-qc/functional_annotation_folder",
                    "id": "#main/functional_annotation_folder"
                },
                {
                    "type": "File",
                    "outputSource": "#main/before-qc/hashsum_input",
                    "id": "#main/hashsum_input"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/after-qc/index_fasta_file",
                    "id": "#main/index_fasta_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/touch_no_cds_flag/created_file",
                    "id": "#main/no_cds_flag_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/after-qc/optional_tax_file_flag",
                    "id": "#main/no_tax_flag_file"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#main/after-qc/pathways_systems_folder",
                    "id": "#main/pathways_systems_folder"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#main/after-qc/pathways_systems_folder_antismash",
                    "id": "#main/pathways_systems_folder_antismash"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#main/after-qc/pathways_systems_folder_antismash_summary",
                    "id": "#main/pathways_systems_folder_antismash_summary"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/before-qc/qc-statistics_folder",
                    "id": "#main/qc-statistics_folder"
                },
                {
                    "type": "File",
                    "outputSource": "#main/before-qc/qc-status",
                    "id": "#main/qc-status"
                },
                {
                    "type": "File",
                    "outputSource": "#main/before-qc/qc_summary",
                    "id": "#main/qc_summary"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/after-qc/rna-count",
                    "id": "#main/rna-count"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#main/after-qc/sequence-categorisation_folder",
                    "id": "#main/sequence-categorisation_folder"
                },
                {
                    "outputSource": "#main/after-qc/stats",
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "id": "#main/stats"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#main/after-qc/taxonomy-summary_folder",
                    "id": "#main/taxonomy-summary_folder"
                }
            ],
            "steps": [
                {
                    "run": "#assembly-2.cwl",
                    "when": "$(inputs.status.basename == 'QC-PASSED')",
                    "in": [
                        {
                            "source": "#main/5.8s_pattern",
                            "id": "#main/after-qc/5.8s_pattern"
                        },
                        {
                            "source": "#main/5s_pattern",
                            "id": "#main/after-qc/5s_pattern"
                        },
                        {
                            "source": "#main/CGC_config",
                            "id": "#main/after-qc/CGC_config"
                        },
                        {
                            "source": "#main/CGC_postfixes",
                            "id": "#main/after-qc/CGC_postfixes"
                        },
                        {
                            "source": "#main/EggNOG_data_dir",
                            "id": "#main/after-qc/EggNOG_data_dir"
                        },
                        {
                            "source": "#main/EggNOG_db",
                            "id": "#main/after-qc/EggNOG_db"
                        },
                        {
                            "source": "#main/EggNOG_diamond_db",
                            "id": "#main/after-qc/EggNOG_diamond_db"
                        },
                        {
                            "source": "#main/HMM_gathering_bit_score",
                            "id": "#main/after-qc/HMM_gathering_bit_score"
                        },
                        {
                            "source": "#main/HMM_name_database",
                            "id": "#main/after-qc/HMM_name_database"
                        },
                        {
                            "source": "#main/HMM_omit_alignment",
                            "id": "#main/after-qc/HMM_omit_alignment"
                        },
                        {
                            "source": "#main/InterProScan_applications",
                            "id": "#main/after-qc/InterProScan_applications"
                        },
                        {
                            "source": "#main/InterProScan_databases",
                            "id": "#main/after-qc/InterProScan_databases"
                        },
                        {
                            "source": "#main/InterProScan_outputFormat",
                            "id": "#main/after-qc/InterProScan_outputFormat"
                        },
                        {
                            "source": "#main/Uniref90_db_txt",
                            "id": "#main/after-qc/Uniref90_db_txt"
                        },
                        {
                            "source": "#main/cgc_chunk_size",
                            "id": "#main/after-qc/cgc_chunk_size"
                        },
                        {
                            "source": "#main/clusters_glossary",
                            "id": "#main/after-qc/clusters_glossary"
                        },
                        {
                            "source": "#main/diamond_databaseFile",
                            "id": "#main/after-qc/diamond_databaseFile"
                        },
                        {
                            "source": "#main/diamond_header",
                            "id": "#main/after-qc/diamond_header"
                        },
                        {
                            "source": "#main/diamond_maxTargetSeqs",
                            "id": "#main/after-qc/diamond_maxTargetSeqs"
                        },
                        {
                            "source": "#main/fgs_train",
                            "id": "#main/after-qc/fgs_train"
                        },
                        {
                            "source": "#main/before-qc/filtered_fasta",
                            "id": "#main/after-qc/filtered_fasta"
                        },
                        {
                            "source": "#main/func_ann_names_hmmer",
                            "id": "#main/after-qc/func_ann_names_hmmer"
                        },
                        {
                            "source": "#main/func_ann_names_ips",
                            "id": "#main/after-qc/func_ann_names_ips"
                        },
                        {
                            "source": "#main/genecaller_order",
                            "id": "#main/after-qc/genecaller_order"
                        },
                        {
                            "source": "#main/go_config",
                            "id": "#main/after-qc/go_config"
                        },
                        {
                            "source": "#main/gp_flatfiles_path",
                            "id": "#main/after-qc/gp_flatfiles_path"
                        },
                        {
                            "source": "#main/graphs",
                            "id": "#main/after-qc/graphs"
                        },
                        {
                            "source": "#main/hmmsearch_header",
                            "id": "#main/after-qc/hmmsearch_header"
                        },
                        {
                            "source": "#main/ips_header",
                            "id": "#main/after-qc/ips_header"
                        },
                        {
                            "source": "#main/ko_file",
                            "id": "#main/after-qc/ko_file"
                        },
                        {
                            "source": "#main/lsu_db",
                            "id": "#main/after-qc/lsu_db"
                        },
                        {
                            "source": "#main/lsu_label",
                            "id": "#main/after-qc/lsu_label"
                        },
                        {
                            "source": "#main/lsu_otus",
                            "id": "#main/after-qc/lsu_otus"
                        },
                        {
                            "source": "#main/lsu_tax",
                            "id": "#main/after-qc/lsu_tax"
                        },
                        {
                            "source": "#main/other_ncrna_models",
                            "id": "#main/after-qc/other_ncrna_models"
                        },
                        {
                            "source": "#main/pathways_classes",
                            "id": "#main/after-qc/pathways_classes"
                        },
                        {
                            "source": "#main/pathways_names",
                            "id": "#main/after-qc/pathways_names"
                        },
                        {
                            "source": "#main/protein_chunk_size_IPS",
                            "id": "#main/after-qc/protein_chunk_size_IPS"
                        },
                        {
                            "source": "#main/protein_chunk_size_eggnog",
                            "id": "#main/after-qc/protein_chunk_size_eggnog"
                        },
                        {
                            "source": "#main/protein_chunk_size_hmm",
                            "id": "#main/after-qc/protein_chunk_size_hmm"
                        },
                        {
                            "source": "#main/rfam_model_clans",
                            "id": "#main/after-qc/rfam_model_clans"
                        },
                        {
                            "source": "#main/rfam_models",
                            "id": "#main/after-qc/rfam_models"
                        },
                        {
                            "source": "#main/ssu_db",
                            "id": "#main/after-qc/ssu_db"
                        },
                        {
                            "source": "#main/ssu_label",
                            "id": "#main/after-qc/ssu_label"
                        },
                        {
                            "source": "#main/ssu_otus",
                            "id": "#main/after-qc/ssu_otus"
                        },
                        {
                            "source": "#main/ssu_tax",
                            "id": "#main/after-qc/ssu_tax"
                        },
                        {
                            "source": "#main/before-qc/qc-status",
                            "id": "#main/after-qc/status"
                        }
                    ],
                    "out": [
                        "#main/after-qc/compressed_files",
                        "#main/after-qc/index_fasta_file",
                        "#main/after-qc/bgzip_fasta_file",
                        "#main/after-qc/bgzip_index",
                        "#main/after-qc/chunking_nucleotides",
                        "#main/after-qc/chunking_proteins",
                        "#main/after-qc/functional_annotation_folder",
                        "#main/after-qc/stats",
                        "#main/after-qc/pathways_systems_folder",
                        "#main/after-qc/pathways_systems_folder_antismash",
                        "#main/after-qc/pathways_systems_folder_antismash_summary",
                        "#main/after-qc/sequence-categorisation_folder",
                        "#main/after-qc/rna-count",
                        "#main/after-qc/taxonomy-summary_folder",
                        "#main/after-qc/count_CDS",
                        "#main/after-qc/optional_tax_file_flag"
                    ],
                    "id": "#main/after-qc"
                },
                {
                    "run": "#assembly-1.cwl",
                    "in": [
                        {
                            "source": "#main/contig_min_length",
                            "id": "#main/before-qc/contig_min_length"
                        },
                        {
                            "source": "#main/contigs",
                            "id": "#main/before-qc/contigs"
                        }
                    ],
                    "out": [
                        "#main/before-qc/qc-status",
                        "#main/before-qc/qc_summary",
                        "#main/before-qc/qc-statistics_folder",
                        "#main/before-qc/filtered_fasta",
                        "#main/before-qc/hashsum_input"
                    ],
                    "id": "#main/before-qc"
                },
                {
                    "when": "$(inputs.count != undefined || inputs.status.basename == \"QC-FAILED\")",
                    "run": "#touch_file.cwl",
                    "in": [
                        {
                            "source": "#main/after-qc/rna-count",
                            "id": "#main/touch_file_flag/count"
                        },
                        {
                            "default": "wf-completed",
                            "id": "#main/touch_file_flag/filename"
                        },
                        {
                            "source": "#main/before-qc/qc-status",
                            "id": "#main/touch_file_flag/status"
                        }
                    ],
                    "out": [
                        "#main/touch_file_flag/created_file"
                    ],
                    "id": "#main/touch_file_flag"
                },
                {
                    "when": "$(inputs.value == 0 )",
                    "run": "#touch_file.cwl",
                    "in": [
                        {
                            "default": "no-cds",
                            "id": "#main/touch_no_cds_flag/filename"
                        },
                        {
                            "source": "#main/after-qc/count_CDS",
                            "id": "#main/touch_no_cds_flag/value"
                        }
                    ],
                    "out": [
                        "#main/touch_no_cds_flag/created_file"
                    ],
                    "id": "#main/touch_no_cds_flag"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 20000
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#assembly-1.cwl/contig_min_length"
                },
                {
                    "type": "File",
                    "id": "#assembly-1.cwl/contigs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#assembly-1.cwl/length_filter/filtered_file",
                    "id": "#assembly-1.cwl/filtered_fasta"
                },
                {
                    "type": "File",
                    "outputSource": "#assembly-1.cwl/hashsum/hashsum",
                    "id": "#assembly-1.cwl/hashsum_input"
                },
                {
                    "type": "Directory",
                    "outputSource": "#assembly-1.cwl/qc_stats/output_dir",
                    "id": "#assembly-1.cwl/qc-statistics_folder"
                },
                {
                    "type": "File",
                    "outputSource": "#assembly-1.cwl/QC-FLAG/qc-flag",
                    "id": "#assembly-1.cwl/qc-status"
                },
                {
                    "type": "File",
                    "outputSource": "#assembly-1.cwl/length_filter/stats_summary_file",
                    "id": "#assembly-1.cwl/qc_summary"
                }
            ],
            "steps": [
                {
                    "run": "#qc-flag.cwl",
                    "in": [
                        {
                            "source": "#assembly-1.cwl/count_processed_reads/count",
                            "id": "#assembly-1.cwl/QC-FLAG/qc_count"
                        }
                    ],
                    "out": [
                        "#assembly-1.cwl/QC-FLAG/qc-flag"
                    ],
                    "id": "#assembly-1.cwl/QC-FLAG"
                },
                {
                    "in": [
                        {
                            "source": "#assembly-1.cwl/unzip/unzipped_file",
                            "id": "#assembly-1.cwl/clean_headers/sequences"
                        }
                    ],
                    "out": [
                        "#assembly-1.cwl/clean_headers/sequences_with_cleaned_headers"
                    ],
                    "run": "#clean_fasta_headers.cwl",
                    "label": "removes spaces in some headers",
                    "id": "#assembly-1.cwl/clean_headers"
                },
                {
                    "in": [
                        {
                            "default": 1,
                            "id": "#assembly-1.cwl/count_processed_reads/number"
                        },
                        {
                            "source": "#assembly-1.cwl/length_filter/filtered_file",
                            "id": "#assembly-1.cwl/count_processed_reads/sequences"
                        }
                    ],
                    "out": [
                        "#assembly-1.cwl/count_processed_reads/count"
                    ],
                    "run": "#count_fasta.cwl",
                    "id": "#assembly-1.cwl/count_processed_reads"
                },
                {
                    "in": [
                        {
                            "default": 1,
                            "id": "#assembly-1.cwl/count_reads/number"
                        },
                        {
                            "source": "#assembly-1.cwl/unzip/unzipped_file",
                            "id": "#assembly-1.cwl/count_reads/sequences"
                        }
                    ],
                    "out": [
                        "#assembly-1.cwl/count_reads/count"
                    ],
                    "run": "#count_fasta.cwl",
                    "id": "#assembly-1.cwl/count_reads"
                },
                {
                    "run": "#generate_checksum.cwl",
                    "in": [
                        {
                            "source": "#assembly-1.cwl/contigs",
                            "id": "#assembly-1.cwl/hashsum/input_file"
                        }
                    ],
                    "out": [
                        "#assembly-1.cwl/hashsum/hashsum"
                    ],
                    "id": "#assembly-1.cwl/hashsum"
                },
                {
                    "in": [
                        {
                            "default": "fasta",
                            "id": "#assembly-1.cwl/length_filter/input_file_format"
                        },
                        {
                            "source": "#assembly-1.cwl/contig_min_length",
                            "id": "#assembly-1.cwl/length_filter/min_length"
                        },
                        {
                            "source": "#assembly-1.cwl/clean_headers/sequences_with_cleaned_headers",
                            "id": "#assembly-1.cwl/length_filter/seq_file"
                        },
                        {
                            "default": "qc_summary",
                            "id": "#assembly-1.cwl/length_filter/stats_file_name"
                        },
                        {
                            "source": "#assembly-1.cwl/count_reads/count",
                            "id": "#assembly-1.cwl/length_filter/submitted_seq_count"
                        }
                    ],
                    "out": [
                        "#assembly-1.cwl/length_filter/filtered_file",
                        "#assembly-1.cwl/length_filter/stats_summary_file"
                    ],
                    "run": "#qc-filtering.cwl",
                    "id": "#assembly-1.cwl/length_filter"
                },
                {
                    "in": [
                        {
                            "source": "#assembly-1.cwl/length_filter/filtered_file",
                            "id": "#assembly-1.cwl/qc_stats/QCed_reads"
                        },
                        {
                            "source": "#assembly-1.cwl/count_processed_reads/count",
                            "id": "#assembly-1.cwl/qc_stats/sequence_count"
                        }
                    ],
                    "out": [
                        "#assembly-1.cwl/qc_stats/output_dir",
                        "#assembly-1.cwl/qc_stats/summary_out"
                    ],
                    "run": "#qc-stats.cwl",
                    "id": "#assembly-1.cwl/qc_stats"
                },
                {
                    "in": [
                        {
                            "default": true,
                            "id": "#assembly-1.cwl/unzip/assembly"
                        },
                        {
                            "source": "#assembly-1.cwl/contigs",
                            "id": "#assembly-1.cwl/unzip/target_reads"
                        }
                    ],
                    "out": [
                        "#assembly-1.cwl/unzip/unzipped_file"
                    ],
                    "run": "#multiple-gunzip.cwl",
                    "id": "#assembly-1.cwl/unzip"
                }
            ],
            "id": "#assembly-1.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 20000
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/5.8s_pattern"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/5s_pattern"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/CGC_config"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#assembly-2.cwl/CGC_postfixes"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/EggNOG_data_dir"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/EggNOG_db"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/EggNOG_diamond_db"
                },
                {
                    "type": "boolean",
                    "id": "#assembly-2.cwl/HMM_gathering_bit_score"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/HMM_name_database"
                },
                {
                    "type": "boolean",
                    "id": "#assembly-2.cwl/HMM_omit_alignment"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#assembly-2.cwl/InterProScan_applications"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/InterProScan_databases"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#assembly-2.cwl/InterProScan_outputFormat"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/Uniref90_db_txt"
                },
                {
                    "type": "int",
                    "id": "#assembly-2.cwl/cgc_chunk_size"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/clusters_glossary"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/diamond_databaseFile"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/diamond_header"
                },
                {
                    "type": "int",
                    "id": "#assembly-2.cwl/diamond_maxTargetSeqs"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/fgs_train"
                },
                {
                    "type": "File",
                    "id": "#assembly-2.cwl/filtered_fasta"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/func_ann_names_hmmer"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/func_ann_names_ips"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/genecaller_order"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/go_config"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/gp_flatfiles_path"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/graphs"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/hmmsearch_header"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/ips_header"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/ko_file"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster",
                            "required": null
                        }
                    ],
                    "id": "#assembly-2.cwl/lsu_db"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/lsu_label"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/lsu_otus"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/lsu_tax"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#assembly-2.cwl/other_ncrna_models"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/pathways_classes"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/pathways_names"
                },
                {
                    "type": "int",
                    "id": "#assembly-2.cwl/protein_chunk_size_IPS"
                },
                {
                    "type": "int",
                    "id": "#assembly-2.cwl/protein_chunk_size_eggnog"
                },
                {
                    "type": "int",
                    "id": "#assembly-2.cwl/protein_chunk_size_hmm"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/rfam_model_clans"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#assembly-2.cwl/rfam_models"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster",
                            "required": null
                        }
                    ],
                    "id": "#assembly-2.cwl/ssu_db"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/ssu_label"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/ssu_otus"
                },
                {
                    "type": "string",
                    "id": "#assembly-2.cwl/ssu_tax"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#assembly-2.cwl/fasta_index/fasta_bgz",
                    "id": "#assembly-2.cwl/bgzip_fasta_file"
                },
                {
                    "type": "File",
                    "outputSource": "#assembly-2.cwl/fasta_index/bgz_index",
                    "id": "#assembly-2.cwl/bgzip_index"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#assembly-2.cwl/chunking_final/nucleotide_fasta_chunks",
                    "id": "#assembly-2.cwl/chunking_nucleotides"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#assembly-2.cwl/chunking_final/protein_fasta_chunks",
                    "id": "#assembly-2.cwl/chunking_proteins"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#assembly-2.cwl/compression/compressed_file",
                    "id": "#assembly-2.cwl/compressed_files"
                },
                {
                    "type": "int",
                    "outputSource": "#assembly-2.cwl/cgc/count_faa",
                    "id": "#assembly-2.cwl/count_CDS"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#assembly-2.cwl/functional_annotation_and_post_processing/functional_annotation_folder",
                    "id": "#assembly-2.cwl/functional_annotation_folder"
                },
                {
                    "type": "File",
                    "outputSource": "#assembly-2.cwl/fasta_index/fasta_index",
                    "id": "#assembly-2.cwl/index_fasta_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#assembly-2.cwl/no_tax_file_flag/created_file",
                    "id": "#assembly-2.cwl/optional_tax_file_flag"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#assembly-2.cwl/functional_annotation_and_post_processing/pathways_systems_folder",
                    "id": "#assembly-2.cwl/pathways_systems_folder"
                },
                {
                    "type": "Directory",
                    "outputSource": "#assembly-2.cwl/antismash/antismash_folder",
                    "id": "#assembly-2.cwl/pathways_systems_folder_antismash"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#assembly-2.cwl/functional_annotation_and_post_processing/pathways_systems_folder_antismash_summary",
                    "id": "#assembly-2.cwl/pathways_systems_folder_antismash_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#assembly-2.cwl/rna_prediction/LSU-SSU-count",
                    "id": "#assembly-2.cwl/rna-count"
                },
                {
                    "type": "Directory",
                    "outputSource": "#assembly-2.cwl/move_to_seq_cat_folder/out",
                    "id": "#assembly-2.cwl/sequence-categorisation_folder"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#assembly-2.cwl/functional_annotation_and_post_processing/stats",
                    "id": "#assembly-2.cwl/stats"
                },
                {
                    "type": "Directory",
                    "outputSource": "#assembly-2.cwl/return_tax_dir/out",
                    "id": "#assembly-2.cwl/taxonomy-summary_folder"
                }
            ],
            "steps": [
                {
                    "run": "#wf_antismash.cwl",
                    "in": [
                        {
                            "source": "#assembly-2.cwl/clusters_glossary",
                            "id": "#assembly-2.cwl/antismash/clusters_glossary"
                        },
                        {
                            "default": "pathways-systems",
                            "id": "#assembly-2.cwl/antismash/final_folder_name"
                        },
                        {
                            "source": "#assembly-2.cwl/filtered_fasta",
                            "id": "#assembly-2.cwl/antismash/input_filtered_fasta"
                        }
                    ],
                    "out": [
                        "#assembly-2.cwl/antismash/antismash_folder",
                        "#assembly-2.cwl/antismash/antismash_clusters"
                    ],
                    "id": "#assembly-2.cwl/antismash"
                },
                {
                    "in": [
                        {
                            "source": "#assembly-2.cwl/cgc_chunk_size",
                            "id": "#assembly-2.cwl/cgc/chunk_size"
                        },
                        {
                            "source": "#assembly-2.cwl/fgs_train",
                            "id": "#assembly-2.cwl/cgc/fgs_train"
                        },
                        {
                            "source": "#assembly-2.cwl/genecaller_order",
                            "id": "#assembly-2.cwl/cgc/genecaller_order"
                        },
                        {
                            "source": "#assembly-2.cwl/filtered_fasta",
                            "id": "#assembly-2.cwl/cgc/input_fasta"
                        },
                        {
                            "source": "#assembly-2.cwl/rna_prediction/ncRNA",
                            "id": "#assembly-2.cwl/cgc/maskfile"
                        },
                        {
                            "source": "#assembly-2.cwl/CGC_postfixes",
                            "id": "#assembly-2.cwl/cgc/postfixes"
                        }
                    ],
                    "out": [
                        "#assembly-2.cwl/cgc/results",
                        "#assembly-2.cwl/cgc/count_faa"
                    ],
                    "run": "#CGC-subwf.cwl",
                    "id": "#assembly-2.cwl/cgc"
                },
                {
                    "run": "#final_chunking.cwl",
                    "in": [
                        {
                            "source": "#assembly-2.cwl/rna_prediction/LSU_fasta",
                            "id": "#assembly-2.cwl/chunking_final/LSU"
                        },
                        {
                            "source": "#assembly-2.cwl/rna_prediction/SSU_fasta",
                            "id": "#assembly-2.cwl/chunking_final/SSU"
                        },
                        {
                            "source": "#assembly-2.cwl/cgc/results",
                            "valueFrom": "$( self.filter(file => !!file.basename.match(/^.*.faa.*$/)).pop() )",
                            "id": "#assembly-2.cwl/chunking_final/faa"
                        },
                        {
                            "source": "#assembly-2.cwl/filtered_fasta",
                            "id": "#assembly-2.cwl/chunking_final/fasta"
                        },
                        {
                            "source": "#assembly-2.cwl/cgc/results",
                            "valueFrom": "$( self.filter(file => !!file.basename.match(/^.*.ffn.*$/)).pop() )",
                            "id": "#assembly-2.cwl/chunking_final/ffn"
                        }
                    ],
                    "out": [
                        "#assembly-2.cwl/chunking_final/nucleotide_fasta_chunks",
                        "#assembly-2.cwl/chunking_final/protein_fasta_chunks",
                        "#assembly-2.cwl/chunking_final/SC_fasta_chunks"
                    ],
                    "id": "#assembly-2.cwl/chunking_final"
                },
                {
                    "run": "#gzip.cwl",
                    "scatter": "#assembly-2.cwl/compression/uncompressed_file",
                    "in": [
                        {
                            "source": [
                                "#assembly-2.cwl/rna_prediction/ncRNA",
                                "#assembly-2.cwl/rna_prediction/cmsearch_result"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#assembly-2.cwl/compression/uncompressed_file"
                        }
                    ],
                    "out": [
                        "#assembly-2.cwl/compression/compressed_file"
                    ],
                    "id": "#assembly-2.cwl/compression"
                },
                {
                    "run": "#fasta_index.cwl",
                    "in": [
                        {
                            "source": "#assembly-2.cwl/filtered_fasta",
                            "id": "#assembly-2.cwl/fasta_index/fasta"
                        }
                    ],
                    "out": [
                        "#assembly-2.cwl/fasta_index/fasta_index",
                        "#assembly-2.cwl/fasta_index/fasta_bgz",
                        "#assembly-2.cwl/fasta_index/bgz_index"
                    ],
                    "id": "#assembly-2.cwl/fasta_index"
                },
                {
                    "when": "$(inputs.check_value != 0)",
                    "run": "#func_ann_and_post_processing-subwf.cwl",
                    "in": [
                        {
                            "source": "#assembly-2.cwl/EggNOG_data_dir",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/EggNOG_data_dir"
                        },
                        {
                            "source": "#assembly-2.cwl/EggNOG_db",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/EggNOG_db"
                        },
                        {
                            "source": "#assembly-2.cwl/EggNOG_diamond_db",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/EggNOG_diamond_db"
                        },
                        {
                            "source": "#assembly-2.cwl/HMM_gathering_bit_score",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/HMM_gathering_bit_score"
                        },
                        {
                            "source": "#assembly-2.cwl/HMM_name_database",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/HMM_name_database"
                        },
                        {
                            "source": "#assembly-2.cwl/HMM_omit_alignment",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/HMM_omit_alignment"
                        },
                        {
                            "source": "#assembly-2.cwl/InterProScan_applications",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/InterProScan_applications"
                        },
                        {
                            "source": "#assembly-2.cwl/InterProScan_databases",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/InterProScan_databases"
                        },
                        {
                            "source": "#assembly-2.cwl/InterProScan_outputFormat",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/InterProScan_outputFormat"
                        },
                        {
                            "source": "#assembly-2.cwl/Uniref90_db_txt",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/Uniref90_db_txt"
                        },
                        {
                            "source": "#assembly-2.cwl/antismash/antismash_clusters",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/antismash_geneclusters_txt"
                        },
                        {
                            "source": "#assembly-2.cwl/cgc/results",
                            "valueFrom": "$( self.filter(file => !!file.basename.match(/^.*.faa.*$/)).pop() )",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/cgc_results_faa"
                        },
                        {
                            "source": "#assembly-2.cwl/cgc/count_faa",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/check_value"
                        },
                        {
                            "source": "#assembly-2.cwl/diamond_databaseFile",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/diamond_databaseFile"
                        },
                        {
                            "source": "#assembly-2.cwl/diamond_header",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/diamond_header"
                        },
                        {
                            "source": "#assembly-2.cwl/diamond_maxTargetSeqs",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/diamond_maxTargetSeqs"
                        },
                        {
                            "source": "#assembly-2.cwl/filtered_fasta",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/filtered_fasta"
                        },
                        {
                            "source": "#assembly-2.cwl/func_ann_names_hmmer",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/func_ann_names_hmmer"
                        },
                        {
                            "source": "#assembly-2.cwl/func_ann_names_ips",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/func_ann_names_ips"
                        },
                        {
                            "source": "#assembly-2.cwl/go_config",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/go_config"
                        },
                        {
                            "source": "#assembly-2.cwl/gp_flatfiles_path",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/gp_flatfiles_path"
                        },
                        {
                            "source": "#assembly-2.cwl/graphs",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/graphs"
                        },
                        {
                            "source": "#assembly-2.cwl/hmmsearch_header",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/hmmsearch_header"
                        },
                        {
                            "source": "#assembly-2.cwl/ips_header",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/ips_header"
                        },
                        {
                            "source": "#assembly-2.cwl/ko_file",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/ko_file"
                        },
                        {
                            "source": "#assembly-2.cwl/pathways_classes",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/pathways_classes"
                        },
                        {
                            "source": "#assembly-2.cwl/pathways_names",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/pathways_names"
                        },
                        {
                            "source": "#assembly-2.cwl/protein_chunk_size_IPS",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/protein_chunk_size_IPS"
                        },
                        {
                            "source": "#assembly-2.cwl/protein_chunk_size_eggnog",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/protein_chunk_size_eggnog"
                        },
                        {
                            "source": "#assembly-2.cwl/protein_chunk_size_hmm",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/protein_chunk_size_hmm"
                        },
                        {
                            "source": "#assembly-2.cwl/rna_prediction/ncRNA",
                            "id": "#assembly-2.cwl/functional_annotation_and_post_processing/rna_prediction_ncRNA"
                        }
                    ],
                    "out": [
                        "#assembly-2.cwl/functional_annotation_and_post_processing/functional_annotation_folder",
                        "#assembly-2.cwl/functional_annotation_and_post_processing/stats",
                        "#assembly-2.cwl/functional_annotation_and_post_processing/pathways_systems_folder_antismash_summary",
                        "#assembly-2.cwl/functional_annotation_and_post_processing/pathways_systems_folder"
                    ],
                    "id": "#assembly-2.cwl/functional_annotation_and_post_processing"
                },
                {
                    "run": "#return_directory.cwl",
                    "in": [
                        {
                            "default": "sequence-categorisation",
                            "id": "#assembly-2.cwl/move_to_seq_cat_folder/dir_name"
                        },
                        {
                            "source": [
                                "#assembly-2.cwl/chunking_final/SC_fasta_chunks",
                                "#assembly-2.cwl/rna_prediction/compressed_rnas",
                                "#assembly-2.cwl/other_ncrnas/ncrnas"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#assembly-2.cwl/move_to_seq_cat_folder/file_list"
                        }
                    ],
                    "out": [
                        "#assembly-2.cwl/move_to_seq_cat_folder/out"
                    ],
                    "id": "#assembly-2.cwl/move_to_seq_cat_folder"
                },
                {
                    "when": "$(inputs.count_lsu < 3 && inputs.count_ssu < 3)",
                    "run": "#touch_file.cwl",
                    "in": [
                        {
                            "source": "#assembly-2.cwl/rna_prediction/number_LSU_mapseq",
                            "id": "#assembly-2.cwl/no_tax_file_flag/count_lsu"
                        },
                        {
                            "source": "#assembly-2.cwl/rna_prediction/number_SSU_mapseq",
                            "id": "#assembly-2.cwl/no_tax_file_flag/count_ssu"
                        },
                        {
                            "default": "no-tax",
                            "id": "#assembly-2.cwl/no_tax_file_flag/filename"
                        }
                    ],
                    "out": [
                        "#assembly-2.cwl/no_tax_file_flag/created_file"
                    ],
                    "id": "#assembly-2.cwl/no_tax_file_flag"
                },
                {
                    "run": "#other_ncrnas.cwl",
                    "in": [
                        {
                            "source": "#assembly-2.cwl/rna_prediction/ncRNA",
                            "id": "#assembly-2.cwl/other_ncrnas/cmsearch_file"
                        },
                        {
                            "source": "#assembly-2.cwl/filtered_fasta",
                            "id": "#assembly-2.cwl/other_ncrnas/input_sequences"
                        },
                        {
                            "default": "other_ncrna",
                            "id": "#assembly-2.cwl/other_ncrnas/name_string"
                        },
                        {
                            "source": "#assembly-2.cwl/other_ncrna_models",
                            "id": "#assembly-2.cwl/other_ncrnas/other_ncRNA_ribosomal_models"
                        }
                    ],
                    "out": [
                        "#assembly-2.cwl/other_ncrnas/ncrnas"
                    ],
                    "id": "#assembly-2.cwl/other_ncrnas"
                },
                {
                    "run": "#return_directory.cwl",
                    "in": [
                        {
                            "source": [
                                "#assembly-2.cwl/rna_prediction/SSU_folder",
                                "#assembly-2.cwl/rna_prediction/LSU_folder"
                            ],
                            "id": "#assembly-2.cwl/return_tax_dir/dir_list"
                        },
                        {
                            "default": "taxonomy-summary",
                            "id": "#assembly-2.cwl/return_tax_dir/dir_name"
                        }
                    ],
                    "out": [
                        "#assembly-2.cwl/return_tax_dir/out"
                    ],
                    "id": "#assembly-2.cwl/return_tax_dir"
                },
                {
                    "in": [
                        {
                            "source": "#assembly-2.cwl/filtered_fasta",
                            "id": "#assembly-2.cwl/rna_prediction/input_sequences"
                        },
                        {
                            "source": "#assembly-2.cwl/rfam_model_clans",
                            "id": "#assembly-2.cwl/rna_prediction/ncRNA_ribosomal_model_clans"
                        },
                        {
                            "source": "#assembly-2.cwl/rfam_models",
                            "id": "#assembly-2.cwl/rna_prediction/ncRNA_ribosomal_models"
                        },
                        {
                            "source": "#assembly-2.cwl/5.8s_pattern",
                            "id": "#assembly-2.cwl/rna_prediction/pattern_5.8S"
                        },
                        {
                            "source": "#assembly-2.cwl/5s_pattern",
                            "id": "#assembly-2.cwl/rna_prediction/pattern_5S"
                        },
                        {
                            "source": "#assembly-2.cwl/lsu_label",
                            "id": "#assembly-2.cwl/rna_prediction/pattern_LSU"
                        },
                        {
                            "source": "#assembly-2.cwl/ssu_label",
                            "id": "#assembly-2.cwl/rna_prediction/pattern_SSU"
                        },
                        {
                            "source": "#assembly-2.cwl/lsu_db",
                            "id": "#assembly-2.cwl/rna_prediction/silva_lsu_database"
                        },
                        {
                            "source": "#assembly-2.cwl/lsu_otus",
                            "id": "#assembly-2.cwl/rna_prediction/silva_lsu_otus"
                        },
                        {
                            "source": "#assembly-2.cwl/lsu_tax",
                            "id": "#assembly-2.cwl/rna_prediction/silva_lsu_taxonomy"
                        },
                        {
                            "source": "#assembly-2.cwl/ssu_db",
                            "id": "#assembly-2.cwl/rna_prediction/silva_ssu_database"
                        },
                        {
                            "source": "#assembly-2.cwl/ssu_otus",
                            "id": "#assembly-2.cwl/rna_prediction/silva_ssu_otus"
                        },
                        {
                            "source": "#assembly-2.cwl/ssu_tax",
                            "id": "#assembly-2.cwl/rna_prediction/silva_ssu_taxonomy"
                        },
                        {
                            "default": "assembly",
                            "id": "#assembly-2.cwl/rna_prediction/type"
                        }
                    ],
                    "out": [
                        "#assembly-2.cwl/rna_prediction/ncRNA",
                        "#assembly-2.cwl/rna_prediction/cmsearch_result",
                        "#assembly-2.cwl/rna_prediction/SSU_folder",
                        "#assembly-2.cwl/rna_prediction/LSU_folder",
                        "#assembly-2.cwl/rna_prediction/LSU-SSU-count",
                        "#assembly-2.cwl/rna_prediction/SSU_fasta",
                        "#assembly-2.cwl/rna_prediction/LSU_fasta",
                        "#assembly-2.cwl/rna_prediction/compressed_rnas",
                        "#assembly-2.cwl/rna_prediction/number_LSU_mapseq",
                        "#assembly-2.cwl/rna_prediction/number_SSU_mapseq"
                    ],
                    "run": "#rna_prediction-sub-wf.cwl",
                    "id": "#assembly-2.cwl/rna_prediction"
                }
            ],
            "id": "#assembly-2.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "ramMin": 5000,
                    "coresMin": 8,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#CGC-subwf.cwl/chunk_size"
                },
                {
                    "type": "string",
                    "id": "#CGC-subwf.cwl/fgs_train"
                },
                {
                    "type": "string",
                    "id": "#CGC-subwf.cwl/genecaller_order"
                },
                {
                    "type": "File",
                    "id": "#CGC-subwf.cwl/input_fasta"
                },
                {
                    "type": "File",
                    "id": "#CGC-subwf.cwl/maskfile"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#CGC-subwf.cwl/postfixes"
                }
            ],
            "outputs": [
                {
                    "type": "int",
                    "outputSource": "#CGC-subwf.cwl/count_cds/count",
                    "id": "#CGC-subwf.cwl/count_faa"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#CGC-subwf.cwl/combine/result",
                    "id": "#CGC-subwf.cwl/results"
                }
            ],
            "steps": [
                {
                    "scatter": [
                        "#CGC-subwf.cwl/combine/files",
                        "#CGC-subwf.cwl/combine/postfix"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": [
                                "#CGC-subwf.cwl/combined_gene_caller/predicted_proteins",
                                "#CGC-subwf.cwl/combined_gene_caller/predicted_seq"
                            ],
                            "id": "#CGC-subwf.cwl/combine/files"
                        },
                        {
                            "source": "#CGC-subwf.cwl/input_fasta",
                            "valueFrom": "$(self.nameroot)",
                            "id": "#CGC-subwf.cwl/combine/outputFileName"
                        },
                        {
                            "source": "#CGC-subwf.cwl/postfixes",
                            "id": "#CGC-subwf.cwl/combine/postfix"
                        }
                    ],
                    "out": [
                        "#CGC-subwf.cwl/combine/result"
                    ],
                    "run": "#concatenate.cwl",
                    "id": "#CGC-subwf.cwl/combine"
                },
                {
                    "scatter": "#CGC-subwf.cwl/combined_gene_caller/input_fasta",
                    "in": [
                        {
                            "source": "#CGC-subwf.cwl/fgs_train",
                            "id": "#CGC-subwf.cwl/combined_gene_caller/fgs_train"
                        },
                        {
                            "source": "#CGC-subwf.cwl/genecaller_order",
                            "id": "#CGC-subwf.cwl/combined_gene_caller/genecaller_order"
                        },
                        {
                            "source": "#CGC-subwf.cwl/split_seqs/chunks",
                            "id": "#CGC-subwf.cwl/combined_gene_caller/input_fasta"
                        },
                        {
                            "source": "#CGC-subwf.cwl/maskfile",
                            "id": "#CGC-subwf.cwl/combined_gene_caller/maskfile"
                        }
                    ],
                    "out": [
                        "#CGC-subwf.cwl/combined_gene_caller/predicted_proteins",
                        "#CGC-subwf.cwl/combined_gene_caller/predicted_seq"
                    ],
                    "run": "#predict_proteins_assemblies.cwl",
                    "label": "CGC run",
                    "id": "#CGC-subwf.cwl/combined_gene_caller"
                },
                {
                    "run": "#count_fasta.cwl",
                    "in": [
                        {
                            "default": 1,
                            "id": "#CGC-subwf.cwl/count_cds/number"
                        },
                        {
                            "source": "#CGC-subwf.cwl/combine/result",
                            "valueFrom": "$( self.filter(file => !!file.basename.match(/^.*.faa.*$/)).pop() )",
                            "id": "#CGC-subwf.cwl/count_cds/sequences"
                        }
                    ],
                    "out": [
                        "#CGC-subwf.cwl/count_cds/count"
                    ],
                    "id": "#CGC-subwf.cwl/count_cds"
                },
                {
                    "in": [
                        {
                            "source": "#CGC-subwf.cwl/chunk_size",
                            "id": "#CGC-subwf.cwl/split_seqs/chunk_size"
                        },
                        {
                            "default": "False",
                            "id": "#CGC-subwf.cwl/split_seqs/number_of_output_files"
                        },
                        {
                            "default": "False",
                            "id": "#CGC-subwf.cwl/split_seqs/same_number_of_residues"
                        },
                        {
                            "source": "#CGC-subwf.cwl/input_fasta",
                            "id": "#CGC-subwf.cwl/split_seqs/seqs"
                        }
                    ],
                    "out": [
                        "#CGC-subwf.cwl/split_seqs/chunks"
                    ],
                    "run": "#fasta_chunker.cwl",
                    "id": "#CGC-subwf.cwl/split_seqs"
                }
            ],
            "id": "#CGC-subwf.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#change_formats_and_names.cwl/fasta"
                },
                {
                    "type": "File",
                    "id": "#change_formats_and_names.cwl/genome_properties_summary"
                },
                {
                    "type": "File",
                    "id": "#change_formats_and_names.cwl/kegg_summary"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#change_formats_and_names.cwl/create_csv_gp/csv_result",
                    "id": "#change_formats_and_names.cwl/gp_summary_csv"
                },
                {
                    "type": "File",
                    "outputSource": "#change_formats_and_names.cwl/create_csv_kp/csv_result",
                    "id": "#change_formats_and_names.cwl/kegg_summary_csv"
                }
            ],
            "steps": [
                {
                    "run": "#make_csv.cwl",
                    "in": [
                        {
                            "source": "#change_formats_and_names.cwl/genome_properties_summary",
                            "valueFrom": "$(self.nameroot.split('SUMMARY_FILE_')[1])",
                            "id": "#change_formats_and_names.cwl/create_csv_gp/output_name"
                        },
                        {
                            "source": "#change_formats_and_names.cwl/genome_properties_summary",
                            "id": "#change_formats_and_names.cwl/create_csv_gp/tab_sep_table"
                        }
                    ],
                    "out": [
                        "#change_formats_and_names.cwl/create_csv_gp/csv_result"
                    ],
                    "id": "#change_formats_and_names.cwl/create_csv_gp"
                },
                {
                    "run": "#make_csv.cwl",
                    "in": [
                        {
                            "source": "#change_formats_and_names.cwl/kegg_summary",
                            "valueFrom": "$(self.nameroot)",
                            "id": "#change_formats_and_names.cwl/create_csv_kp/output_name"
                        },
                        {
                            "source": "#change_formats_and_names.cwl/kegg_summary",
                            "id": "#change_formats_and_names.cwl/create_csv_kp/tab_sep_table"
                        }
                    ],
                    "out": [
                        "#change_formats_and_names.cwl/create_csv_kp/csv_result"
                    ],
                    "id": "#change_formats_and_names.cwl/create_csv_kp"
                }
            ],
            "id": "#change_formats_and_names.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "Identifies non-coding RNAs using Rfams covariance models",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#cmsearch-multimodel-assembly.cwl/clan_info"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#cmsearch-multimodel-assembly.cwl/covariance_models"
                },
                {
                    "type": "File",
                    "id": "#cmsearch-multimodel-assembly.cwl/query_sequences"
                }
            ],
            "outputs": [
                {
                    "outputSource": "#cmsearch-multimodel-assembly.cwl/run_concatenate_matches/result",
                    "type": "File",
                    "id": "#cmsearch-multimodel-assembly.cwl/concatenate_matches"
                },
                {
                    "outputSource": "#cmsearch-multimodel-assembly.cwl/remove_overlaps/deoverlapped_matches",
                    "type": "File",
                    "id": "#cmsearch-multimodel-assembly.cwl/deoverlapped_matches"
                },
                {
                    "outputSource": "#cmsearch-multimodel-assembly.cwl/cmsearch/matches",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#cmsearch-multimodel-assembly.cwl/matches"
                }
            ],
            "steps": [
                {
                    "label": "Search sequence(s) against a covariance model database",
                    "run": "#infernal-cmsearch-v1.1.2.cwl",
                    "in": [
                        {
                            "source": "#cmsearch-multimodel-assembly.cwl/covariance_models",
                            "id": "#cmsearch-multimodel-assembly.cwl/cmsearch/covariance_model_database"
                        },
                        {
                            "default": 8,
                            "id": "#cmsearch-multimodel-assembly.cwl/cmsearch/cpu"
                        },
                        {
                            "default": true,
                            "id": "#cmsearch-multimodel-assembly.cwl/cmsearch/omit_alignment_section"
                        },
                        {
                            "default": true,
                            "id": "#cmsearch-multimodel-assembly.cwl/cmsearch/only_hmm"
                        },
                        {
                            "source": "#cmsearch-multimodel-assembly.cwl/query_sequences",
                            "id": "#cmsearch-multimodel-assembly.cwl/cmsearch/query_sequences"
                        },
                        {
                            "default": 1000,
                            "id": "#cmsearch-multimodel-assembly.cwl/cmsearch/search_space_size"
                        }
                    ],
                    "scatter": "#cmsearch-multimodel-assembly.cwl/cmsearch/covariance_model_database",
                    "out": [
                        "#cmsearch-multimodel-assembly.cwl/cmsearch/matches",
                        "#cmsearch-multimodel-assembly.cwl/cmsearch/programOutput"
                    ],
                    "id": "#cmsearch-multimodel-assembly.cwl/cmsearch"
                },
                {
                    "label": "Remove lower scoring overlaps from cmsearch --tblout files.",
                    "run": "#cmsearch-deoverlap-v0.02.cwl",
                    "in": [
                        {
                            "source": "#cmsearch-multimodel-assembly.cwl/clan_info",
                            "id": "#cmsearch-multimodel-assembly.cwl/remove_overlaps/clan_information"
                        },
                        {
                            "source": "#cmsearch-multimodel-assembly.cwl/run_concatenate_matches/result",
                            "id": "#cmsearch-multimodel-assembly.cwl/remove_overlaps/cmsearch_matches"
                        }
                    ],
                    "out": [
                        "#cmsearch-multimodel-assembly.cwl/remove_overlaps/deoverlapped_matches"
                    ],
                    "id": "#cmsearch-multimodel-assembly.cwl/remove_overlaps"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": [
                                "#cmsearch-multimodel-assembly.cwl/cmsearch/matches"
                            ],
                            "id": "#cmsearch-multimodel-assembly.cwl/run_concatenate_matches/files"
                        },
                        {
                            "source": "#cmsearch-multimodel-assembly.cwl/query_sequences",
                            "valueFrom": "$(self.nameroot)",
                            "id": "#cmsearch-multimodel-assembly.cwl/run_concatenate_matches/outputFileName"
                        },
                        {
                            "default": ".cmsearch.all.tblout",
                            "id": "#cmsearch-multimodel-assembly.cwl/run_concatenate_matches/postfix"
                        }
                    ],
                    "out": [
                        "#cmsearch-multimodel-assembly.cwl/run_concatenate_matches/result"
                    ],
                    "id": "#cmsearch-multimodel-assembly.cwl/run_concatenate_matches"
                }
            ],
            "id": "#cmsearch-multimodel-assembly.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/author": "Arnaud Meng, Maxim Scheremetjew, Ekaterina Sakharova",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#deal_with_functional_annotation.cwl/IPS_table"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#deal_with_functional_annotation.cwl/antismash_geneclusters_txt"
                },
                {
                    "type": "File",
                    "id": "#deal_with_functional_annotation.cwl/cds"
                },
                {
                    "type": "string",
                    "id": "#deal_with_functional_annotation.cwl/diamond_header"
                },
                {
                    "type": "File",
                    "id": "#deal_with_functional_annotation.cwl/diamond_table"
                },
                {
                    "type": "File",
                    "id": "#deal_with_functional_annotation.cwl/eggnog_annotations"
                },
                {
                    "type": "File",
                    "id": "#deal_with_functional_annotation.cwl/eggnog_orthologs"
                },
                {
                    "type": "File",
                    "id": "#deal_with_functional_annotation.cwl/fasta"
                },
                {
                    "type": "string",
                    "id": "#deal_with_functional_annotation.cwl/go_config"
                },
                {
                    "type": "File",
                    "id": "#deal_with_functional_annotation.cwl/hmmscan_table"
                },
                {
                    "type": "string",
                    "id": "#deal_with_functional_annotation.cwl/hmmsearch_header"
                },
                {
                    "type": "string",
                    "id": "#deal_with_functional_annotation.cwl/ips_header"
                },
                {
                    "type": "string",
                    "id": "#deal_with_functional_annotation.cwl/ko_file"
                },
                {
                    "type": "File",
                    "id": "#deal_with_functional_annotation.cwl/output_gff_gz"
                },
                {
                    "type": "File",
                    "id": "#deal_with_functional_annotation.cwl/output_gff_index"
                },
                {
                    "type": "File",
                    "id": "#deal_with_functional_annotation.cwl/rna"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputSource": "#deal_with_functional_annotation.cwl/move_to_functional_annotation_folder/out",
                    "id": "#deal_with_functional_annotation.cwl/functional_annotation_folder"
                },
                {
                    "type": "Directory",
                    "outputSource": "#deal_with_functional_annotation.cwl/write_summaries/stats",
                    "id": "#deal_with_functional_annotation.cwl/stats"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#deal_with_functional_annotation.cwl/write_summaries/summary_antismash",
                    "id": "#deal_with_functional_annotation.cwl/summary_antismash"
                }
            ],
            "steps": [
                {
                    "run": "#result_chunker.cwl",
                    "in": [
                        {
                            "default": "tsv",
                            "id": "#deal_with_functional_annotation.cwl/chunking_tsv/format_file"
                        },
                        {
                            "source": "#deal_with_functional_annotation.cwl/header_addition/output_table",
                            "id": "#deal_with_functional_annotation.cwl/chunking_tsv/infile"
                        },
                        {
                            "default": "table",
                            "id": "#deal_with_functional_annotation.cwl/chunking_tsv/outdirname"
                        }
                    ],
                    "out": [
                        "#deal_with_functional_annotation.cwl/chunking_tsv/chunks"
                    ],
                    "id": "#deal_with_functional_annotation.cwl/chunking_tsv"
                },
                {
                    "run": "#gzip.cwl",
                    "scatter": "#deal_with_functional_annotation.cwl/compression_func_ann/uncompressed_file",
                    "in": [
                        {
                            "source": [
                                "#deal_with_functional_annotation.cwl/eggnog_annotations",
                                "#deal_with_functional_annotation.cwl/eggnog_orthologs"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#deal_with_functional_annotation.cwl/compression_func_ann/uncompressed_file"
                        }
                    ],
                    "out": [
                        "#deal_with_functional_annotation.cwl/compression_func_ann/compressed_file"
                    ],
                    "id": "#deal_with_functional_annotation.cwl/compression_func_ann"
                },
                {
                    "run": "#go_summary.cwl",
                    "in": [
                        {
                            "source": "#deal_with_functional_annotation.cwl/IPS_table",
                            "id": "#deal_with_functional_annotation.cwl/go_summary/InterProScan_results"
                        },
                        {
                            "source": "#deal_with_functional_annotation.cwl/go_config",
                            "id": "#deal_with_functional_annotation.cwl/go_summary/config"
                        },
                        {
                            "source": "#deal_with_functional_annotation.cwl/fasta",
                            "valueFrom": "$(self.nameroot).summary.go",
                            "id": "#deal_with_functional_annotation.cwl/go_summary/output_name"
                        }
                    ],
                    "out": [
                        "#deal_with_functional_annotation.cwl/go_summary/go_summary",
                        "#deal_with_functional_annotation.cwl/go_summary/go_summary_slim"
                    ],
                    "id": "#deal_with_functional_annotation.cwl/go_summary"
                },
                {
                    "scatter": [
                        "#deal_with_functional_annotation.cwl/header_addition/input_table",
                        "#deal_with_functional_annotation.cwl/header_addition/header"
                    ],
                    "scatterMethod": "dotproduct",
                    "run": "#add_header.cwl",
                    "in": [
                        {
                            "source": [
                                "#deal_with_functional_annotation.cwl/diamond_header",
                                "#deal_with_functional_annotation.cwl/hmmsearch_header",
                                "#deal_with_functional_annotation.cwl/ips_header"
                            ],
                            "id": "#deal_with_functional_annotation.cwl/header_addition/header"
                        },
                        {
                            "source": [
                                "#deal_with_functional_annotation.cwl/diamond_table",
                                "#deal_with_functional_annotation.cwl/hmmscan_table",
                                "#deal_with_functional_annotation.cwl/IPS_table"
                            ],
                            "id": "#deal_with_functional_annotation.cwl/header_addition/input_table"
                        }
                    ],
                    "out": [
                        "#deal_with_functional_annotation.cwl/header_addition/output_table"
                    ],
                    "id": "#deal_with_functional_annotation.cwl/header_addition"
                },
                {
                    "run": "#return_directory.cwl",
                    "in": [
                        {
                            "default": "functional-annotation",
                            "id": "#deal_with_functional_annotation.cwl/move_to_functional_annotation_folder/dir_name"
                        },
                        {
                            "source": [
                                "#deal_with_functional_annotation.cwl/output_gff_gz",
                                "#deal_with_functional_annotation.cwl/output_gff_index",
                                "#deal_with_functional_annotation.cwl/compression_func_ann/compressed_file",
                                "#deal_with_functional_annotation.cwl/write_summaries/summary_ips",
                                "#deal_with_functional_annotation.cwl/write_summaries/summary_ko",
                                "#deal_with_functional_annotation.cwl/write_summaries/summary_pfam",
                                "#deal_with_functional_annotation.cwl/go_summary/go_summary",
                                "#deal_with_functional_annotation.cwl/go_summary/go_summary_slim",
                                "#deal_with_functional_annotation.cwl/chunking_tsv/chunks"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#deal_with_functional_annotation.cwl/move_to_functional_annotation_folder/file_list"
                        }
                    ],
                    "out": [
                        "#deal_with_functional_annotation.cwl/move_to_functional_annotation_folder/out"
                    ],
                    "id": "#deal_with_functional_annotation.cwl/move_to_functional_annotation_folder"
                },
                {
                    "run": "#pfam_annotations.cwl",
                    "in": [
                        {
                            "source": "#deal_with_functional_annotation.cwl/IPS_table",
                            "id": "#deal_with_functional_annotation.cwl/pfam/interpro"
                        },
                        {
                            "source": "#deal_with_functional_annotation.cwl/fasta",
                            "valueFrom": "$(self.nameroot).pfam",
                            "id": "#deal_with_functional_annotation.cwl/pfam/outputname"
                        }
                    ],
                    "out": [
                        "#deal_with_functional_annotation.cwl/pfam/annotations"
                    ],
                    "id": "#deal_with_functional_annotation.cwl/pfam"
                },
                {
                    "run": "#func_summaries.cwl",
                    "in": [
                        {
                            "source": "#deal_with_functional_annotation.cwl/antismash_geneclusters_txt",
                            "id": "#deal_with_functional_annotation.cwl/write_summaries/antismash_gene_clusters"
                        },
                        {
                            "source": "#deal_with_functional_annotation.cwl/cds",
                            "id": "#deal_with_functional_annotation.cwl/write_summaries/cds"
                        },
                        {
                            "source": "#deal_with_functional_annotation.cwl/hmmscan_table",
                            "id": "#deal_with_functional_annotation.cwl/write_summaries/hmmscan_annotation"
                        },
                        {
                            "source": "#deal_with_functional_annotation.cwl/IPS_table",
                            "id": "#deal_with_functional_annotation.cwl/write_summaries/interproscan_annotation"
                        },
                        {
                            "source": "#deal_with_functional_annotation.cwl/ko_file",
                            "id": "#deal_with_functional_annotation.cwl/write_summaries/ko_file"
                        },
                        {
                            "source": "#deal_with_functional_annotation.cwl/pfam/annotations",
                            "id": "#deal_with_functional_annotation.cwl/write_summaries/pfam_annotation"
                        },
                        {
                            "source": "#deal_with_functional_annotation.cwl/rna",
                            "id": "#deal_with_functional_annotation.cwl/write_summaries/rna"
                        }
                    ],
                    "out": [
                        "#deal_with_functional_annotation.cwl/write_summaries/summary_ips",
                        "#deal_with_functional_annotation.cwl/write_summaries/summary_ko",
                        "#deal_with_functional_annotation.cwl/write_summaries/summary_pfam",
                        "#deal_with_functional_annotation.cwl/write_summaries/summary_antismash",
                        "#deal_with_functional_annotation.cwl/write_summaries/stats"
                    ],
                    "id": "#deal_with_functional_annotation.cwl/write_summaries"
                }
            ],
            "id": "#deal_with_functional_annotation.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 20000
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#func_ann_and_post_processing-subwf.cwl/EggNOG_data_dir"
                },
                {
                    "type": "string",
                    "id": "#func_ann_and_post_processing-subwf.cwl/EggNOG_db"
                },
                {
                    "type": "string",
                    "id": "#func_ann_and_post_processing-subwf.cwl/EggNOG_diamond_db"
                },
                {
                    "type": "boolean",
                    "id": "#func_ann_and_post_processing-subwf.cwl/HMM_gathering_bit_score"
                },
                {
                    "type": "string",
                    "id": "#func_ann_and_post_processing-subwf.cwl/HMM_name_database"
                },
                {
                    "type": "boolean",
                    "id": "#func_ann_and_post_processing-subwf.cwl/HMM_omit_alignment"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#func_ann_and_post_processing-subwf.cwl/InterProScan_applications"
                },
                {
                    "type": "string",
                    "id": "#func_ann_and_post_processing-subwf.cwl/InterProScan_databases"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#func_ann_and_post_processing-subwf.cwl/InterProScan_outputFormat"
                },
                {
                    "type": "string",
                    "id": "#func_ann_and_post_processing-subwf.cwl/Uniref90_db_txt"
                },
                {
                    "type": "File",
                    "id": "#func_ann_and_post_processing-subwf.cwl/antismash_geneclusters_txt"
                },
                {
                    "type": "File",
                    "id": "#func_ann_and_post_processing-subwf.cwl/cgc_results_faa"
                },
                {
                    "type": "string",
                    "id": "#func_ann_and_post_processing-subwf.cwl/diamond_databaseFile"
                },
                {
                    "type": "string",
                    "id": "#func_ann_and_post_processing-subwf.cwl/diamond_header"
                },
                {
                    "type": "int",
                    "id": "#func_ann_and_post_processing-subwf.cwl/diamond_maxTargetSeqs"
                },
                {
                    "type": "File",
                    "id": "#func_ann_and_post_processing-subwf.cwl/filtered_fasta"
                },
                {
                    "type": "string",
                    "id": "#func_ann_and_post_processing-subwf.cwl/func_ann_names_hmmer"
                },
                {
                    "type": "string",
                    "id": "#func_ann_and_post_processing-subwf.cwl/func_ann_names_ips"
                },
                {
                    "type": "string",
                    "id": "#func_ann_and_post_processing-subwf.cwl/go_config"
                },
                {
                    "type": "string",
                    "id": "#func_ann_and_post_processing-subwf.cwl/gp_flatfiles_path"
                },
                {
                    "type": "string",
                    "id": "#func_ann_and_post_processing-subwf.cwl/graphs"
                },
                {
                    "type": "string",
                    "id": "#func_ann_and_post_processing-subwf.cwl/hmmsearch_header"
                },
                {
                    "type": "string",
                    "id": "#func_ann_and_post_processing-subwf.cwl/ips_header"
                },
                {
                    "type": "string",
                    "id": "#func_ann_and_post_processing-subwf.cwl/ko_file"
                },
                {
                    "type": "string",
                    "id": "#func_ann_and_post_processing-subwf.cwl/pathways_classes"
                },
                {
                    "type": "string",
                    "id": "#func_ann_and_post_processing-subwf.cwl/pathways_names"
                },
                {
                    "type": "int",
                    "id": "#func_ann_and_post_processing-subwf.cwl/protein_chunk_size_IPS"
                },
                {
                    "type": "int",
                    "id": "#func_ann_and_post_processing-subwf.cwl/protein_chunk_size_eggnog"
                },
                {
                    "type": "int",
                    "id": "#func_ann_and_post_processing-subwf.cwl/protein_chunk_size_hmm"
                },
                {
                    "type": "File",
                    "id": "#func_ann_and_post_processing-subwf.cwl/rna_prediction_ncRNA"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#func_ann_and_post_processing-subwf.cwl/folder_functional_annotation/functional_annotation_folder",
                    "id": "#func_ann_and_post_processing-subwf.cwl/functional_annotation_folder"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#func_ann_and_post_processing-subwf.cwl/move_to_pathways_systems_folder/out",
                    "id": "#func_ann_and_post_processing-subwf.cwl/pathways_systems_folder"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#func_ann_and_post_processing-subwf.cwl/move_antismash_summary_to_pathways_systems_folder/summary_in_folder",
                    "id": "#func_ann_and_post_processing-subwf.cwl/pathways_systems_folder_antismash_summary"
                },
                {
                    "outputSource": "#func_ann_and_post_processing-subwf.cwl/folder_functional_annotation/stats",
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "id": "#func_ann_and_post_processing-subwf.cwl/stats"
                }
            ],
            "steps": [
                {
                    "run": "#change_formats_and_names.cwl",
                    "in": [
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/filtered_fasta",
                            "id": "#func_ann_and_post_processing-subwf.cwl/change_formats_and_names/fasta"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/genome_properties/summary",
                            "id": "#func_ann_and_post_processing-subwf.cwl/change_formats_and_names/genome_properties_summary"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/pathways/kegg_pathways_summary",
                            "id": "#func_ann_and_post_processing-subwf.cwl/change_formats_and_names/kegg_summary"
                        }
                    ],
                    "out": [
                        "#func_ann_and_post_processing-subwf.cwl/change_formats_and_names/gp_summary_csv",
                        "#func_ann_and_post_processing-subwf.cwl/change_formats_and_names/kegg_summary_csv"
                    ],
                    "id": "#func_ann_and_post_processing-subwf.cwl/change_formats_and_names"
                },
                {
                    "run": "#diamond-subwf.cwl",
                    "in": [
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/Uniref90_db_txt",
                            "id": "#func_ann_and_post_processing-subwf.cwl/diamond/Uniref90_db_txt"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/diamond_databaseFile",
                            "id": "#func_ann_and_post_processing-subwf.cwl/diamond/databaseFile"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/filtered_fasta",
                            "valueFrom": "$(self.nameroot)",
                            "id": "#func_ann_and_post_processing-subwf.cwl/diamond/filename"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/diamond_maxTargetSeqs",
                            "id": "#func_ann_and_post_processing-subwf.cwl/diamond/maxTargetSeqs"
                        },
                        {
                            "default": "6",
                            "id": "#func_ann_and_post_processing-subwf.cwl/diamond/outputFormat"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/cgc_results_faa",
                            "id": "#func_ann_and_post_processing-subwf.cwl/diamond/queryInputFile"
                        },
                        {
                            "default": "both",
                            "id": "#func_ann_and_post_processing-subwf.cwl/diamond/strand"
                        },
                        {
                            "default": 32,
                            "id": "#func_ann_and_post_processing-subwf.cwl/diamond/threads"
                        }
                    ],
                    "out": [
                        "#func_ann_and_post_processing-subwf.cwl/diamond/post-processing_output"
                    ],
                    "id": "#func_ann_and_post_processing-subwf.cwl/diamond"
                },
                {
                    "run": "#deal_with_functional_annotation.cwl",
                    "in": [
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/functional_annotation/ips_result",
                            "id": "#func_ann_and_post_processing-subwf.cwl/folder_functional_annotation/IPS_table"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/antismash_geneclusters_txt",
                            "id": "#func_ann_and_post_processing-subwf.cwl/folder_functional_annotation/antismash_geneclusters_txt"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/cgc_results_faa",
                            "id": "#func_ann_and_post_processing-subwf.cwl/folder_functional_annotation/cds"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/diamond_header",
                            "id": "#func_ann_and_post_processing-subwf.cwl/folder_functional_annotation/diamond_header"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/diamond/post-processing_output",
                            "id": "#func_ann_and_post_processing-subwf.cwl/folder_functional_annotation/diamond_table"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/functional_annotation/eggnog_annotations",
                            "id": "#func_ann_and_post_processing-subwf.cwl/folder_functional_annotation/eggnog_annotations"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/functional_annotation/eggnog_orthologs",
                            "id": "#func_ann_and_post_processing-subwf.cwl/folder_functional_annotation/eggnog_orthologs"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/filtered_fasta",
                            "id": "#func_ann_and_post_processing-subwf.cwl/folder_functional_annotation/fasta"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/go_config",
                            "id": "#func_ann_and_post_processing-subwf.cwl/folder_functional_annotation/go_config"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/functional_annotation/hmm_result",
                            "id": "#func_ann_and_post_processing-subwf.cwl/folder_functional_annotation/hmmscan_table"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/hmmsearch_header",
                            "id": "#func_ann_and_post_processing-subwf.cwl/folder_functional_annotation/hmmsearch_header"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/ips_header",
                            "id": "#func_ann_and_post_processing-subwf.cwl/folder_functional_annotation/ips_header"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/ko_file",
                            "id": "#func_ann_and_post_processing-subwf.cwl/folder_functional_annotation/ko_file"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/gff/output_gff_gz",
                            "id": "#func_ann_and_post_processing-subwf.cwl/folder_functional_annotation/output_gff_gz"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/gff/output_gff_index",
                            "id": "#func_ann_and_post_processing-subwf.cwl/folder_functional_annotation/output_gff_index"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/rna_prediction_ncRNA",
                            "id": "#func_ann_and_post_processing-subwf.cwl/folder_functional_annotation/rna"
                        }
                    ],
                    "out": [
                        "#func_ann_and_post_processing-subwf.cwl/folder_functional_annotation/functional_annotation_folder",
                        "#func_ann_and_post_processing-subwf.cwl/folder_functional_annotation/stats",
                        "#func_ann_and_post_processing-subwf.cwl/folder_functional_annotation/summary_antismash"
                    ],
                    "id": "#func_ann_and_post_processing-subwf.cwl/folder_functional_annotation"
                },
                {
                    "run": "#functional_annotation.cwl",
                    "in": [
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/cgc_results_faa",
                            "id": "#func_ann_and_post_processing-subwf.cwl/functional_annotation/CGC_predicted_proteins"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/EggNOG_data_dir",
                            "id": "#func_ann_and_post_processing-subwf.cwl/functional_annotation/EggNOG_data_dir"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/EggNOG_db",
                            "id": "#func_ann_and_post_processing-subwf.cwl/functional_annotation/EggNOG_db"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/EggNOG_diamond_db",
                            "id": "#func_ann_and_post_processing-subwf.cwl/functional_annotation/EggNOG_diamond_db"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/HMM_name_database",
                            "id": "#func_ann_and_post_processing-subwf.cwl/functional_annotation/HMM_database"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/HMM_gathering_bit_score",
                            "id": "#func_ann_and_post_processing-subwf.cwl/functional_annotation/HMM_gathering_bit_score"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/HMM_omit_alignment",
                            "id": "#func_ann_and_post_processing-subwf.cwl/functional_annotation/HMM_omit_alignment"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/InterProScan_applications",
                            "id": "#func_ann_and_post_processing-subwf.cwl/functional_annotation/InterProScan_applications"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/InterProScan_databases",
                            "id": "#func_ann_and_post_processing-subwf.cwl/functional_annotation/InterProScan_databases"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/InterProScan_outputFormat",
                            "id": "#func_ann_and_post_processing-subwf.cwl/functional_annotation/InterProScan_outputFormat"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/protein_chunk_size_IPS",
                            "id": "#func_ann_and_post_processing-subwf.cwl/functional_annotation/chunk_size_IPS"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/protein_chunk_size_eggnog",
                            "id": "#func_ann_and_post_processing-subwf.cwl/functional_annotation/chunk_size_eggnog"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/protein_chunk_size_hmm",
                            "id": "#func_ann_and_post_processing-subwf.cwl/functional_annotation/chunk_size_hmm"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/func_ann_names_hmmer",
                            "id": "#func_ann_and_post_processing-subwf.cwl/functional_annotation/name_hmmer"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/func_ann_names_ips",
                            "id": "#func_ann_and_post_processing-subwf.cwl/functional_annotation/name_ips"
                        }
                    ],
                    "out": [
                        "#func_ann_and_post_processing-subwf.cwl/functional_annotation/hmm_result",
                        "#func_ann_and_post_processing-subwf.cwl/functional_annotation/ips_result",
                        "#func_ann_and_post_processing-subwf.cwl/functional_annotation/eggnog_annotations",
                        "#func_ann_and_post_processing-subwf.cwl/functional_annotation/eggnog_orthologs"
                    ],
                    "id": "#func_ann_and_post_processing-subwf.cwl/functional_annotation"
                },
                {
                    "run": "#genome_properties.cwl",
                    "in": [
                        {
                            "default": "genomeProperties.txt",
                            "id": "#func_ann_and_post_processing-subwf.cwl/genome_properties/GP_txt"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/gp_flatfiles_path",
                            "id": "#func_ann_and_post_processing-subwf.cwl/genome_properties/flatfiles_path"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/functional_annotation/ips_result",
                            "id": "#func_ann_and_post_processing-subwf.cwl/genome_properties/input_tsv_file"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/filtered_fasta",
                            "valueFrom": "$(self.nameroot).summary.gprops.tsv",
                            "id": "#func_ann_and_post_processing-subwf.cwl/genome_properties/name"
                        }
                    ],
                    "out": [
                        "#func_ann_and_post_processing-subwf.cwl/genome_properties/summary"
                    ],
                    "id": "#func_ann_and_post_processing-subwf.cwl/genome_properties"
                },
                {
                    "run": "#gff_generation.cwl",
                    "in": [
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/functional_annotation/eggnog_annotations",
                            "id": "#func_ann_and_post_processing-subwf.cwl/gff/eggnog_results"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/cgc_results_faa",
                            "id": "#func_ann_and_post_processing-subwf.cwl/gff/input_faa"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/functional_annotation/ips_result",
                            "id": "#func_ann_and_post_processing-subwf.cwl/gff/ips_results"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/filtered_fasta",
                            "valueFrom": "$(self.nameroot).annotations.gff",
                            "id": "#func_ann_and_post_processing-subwf.cwl/gff/output_name"
                        }
                    ],
                    "out": [
                        "#func_ann_and_post_processing-subwf.cwl/gff/output_gff_gz",
                        "#func_ann_and_post_processing-subwf.cwl/gff/output_gff_index"
                    ],
                    "id": "#func_ann_and_post_processing-subwf.cwl/gff"
                },
                {
                    "run": "#move_antismash_summary.cwl",
                    "in": [
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/folder_functional_annotation/summary_antismash",
                            "id": "#func_ann_and_post_processing-subwf.cwl/move_antismash_summary_to_pathways_systems_folder/antismash_summary"
                        },
                        {
                            "default": "pathways-systems",
                            "id": "#func_ann_and_post_processing-subwf.cwl/move_antismash_summary_to_pathways_systems_folder/folder_name"
                        }
                    ],
                    "out": [
                        "#func_ann_and_post_processing-subwf.cwl/move_antismash_summary_to_pathways_systems_folder/summary_in_folder"
                    ],
                    "id": "#func_ann_and_post_processing-subwf.cwl/move_antismash_summary_to_pathways_systems_folder"
                },
                {
                    "run": "#return_directory.cwl",
                    "in": [
                        {
                            "default": "pathways-systems",
                            "id": "#func_ann_and_post_processing-subwf.cwl/move_to_pathways_systems_folder/dir_name"
                        },
                        {
                            "source": [
                                "#func_ann_and_post_processing-subwf.cwl/pathways/kegg_contigs_summary",
                                "#func_ann_and_post_processing-subwf.cwl/change_formats_and_names/kegg_summary_csv",
                                "#func_ann_and_post_processing-subwf.cwl/change_formats_and_names/gp_summary_csv"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#func_ann_and_post_processing-subwf.cwl/move_to_pathways_systems_folder/file_list"
                        }
                    ],
                    "out": [
                        "#func_ann_and_post_processing-subwf.cwl/move_to_pathways_systems_folder/out"
                    ],
                    "id": "#func_ann_and_post_processing-subwf.cwl/move_to_pathways_systems_folder"
                },
                {
                    "run": "#kegg_analysis.cwl",
                    "in": [
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/filtered_fasta",
                            "id": "#func_ann_and_post_processing-subwf.cwl/pathways/filtered_fasta"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/graphs",
                            "id": "#func_ann_and_post_processing-subwf.cwl/pathways/graphs"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/functional_annotation/hmm_result",
                            "id": "#func_ann_and_post_processing-subwf.cwl/pathways/input_table_hmmscan"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/filtered_fasta",
                            "valueFrom": "$(self.nameroot)",
                            "id": "#func_ann_and_post_processing-subwf.cwl/pathways/outputname"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/pathways_classes",
                            "id": "#func_ann_and_post_processing-subwf.cwl/pathways/pathways_classes"
                        },
                        {
                            "source": "#func_ann_and_post_processing-subwf.cwl/pathways_names",
                            "id": "#func_ann_and_post_processing-subwf.cwl/pathways/pathways_names"
                        }
                    ],
                    "out": [
                        "#func_ann_and_post_processing-subwf.cwl/pathways/kegg_pathways_summary",
                        "#func_ann_and_post_processing-subwf.cwl/pathways/kegg_contigs_summary"
                    ],
                    "id": "#func_ann_and_post_processing-subwf.cwl/pathways"
                }
            ],
            "id": "#func_ann_and_post_processing-subwf.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "ramMin": 1000,
                    "coresMin": 1,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#functional_annotation.cwl/CGC_predicted_proteins"
                },
                {
                    "type": "string",
                    "id": "#functional_annotation.cwl/EggNOG_data_dir"
                },
                {
                    "type": "string",
                    "id": "#functional_annotation.cwl/EggNOG_db"
                },
                {
                    "type": "string",
                    "id": "#functional_annotation.cwl/EggNOG_diamond_db"
                },
                {
                    "type": "string",
                    "id": "#functional_annotation.cwl/HMM_database"
                },
                {
                    "type": "boolean",
                    "id": "#functional_annotation.cwl/HMM_gathering_bit_score"
                },
                {
                    "type": "boolean",
                    "id": "#functional_annotation.cwl/HMM_omit_alignment"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#functional_annotation.cwl/InterProScan_applications"
                },
                {
                    "type": "string",
                    "id": "#functional_annotation.cwl/InterProScan_databases"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#functional_annotation.cwl/InterProScan_outputFormat"
                },
                {
                    "type": "int",
                    "id": "#functional_annotation.cwl/chunk_size_IPS"
                },
                {
                    "type": "int",
                    "id": "#functional_annotation.cwl/chunk_size_eggnog"
                },
                {
                    "type": "int",
                    "id": "#functional_annotation.cwl/chunk_size_hmm"
                },
                {
                    "type": "string",
                    "id": "#functional_annotation.cwl/name_hmmer"
                },
                {
                    "type": "string",
                    "id": "#functional_annotation.cwl/name_ips"
                }
            ],
            "outputs": [
                {
                    "outputSource": "#functional_annotation.cwl/eggnog/annotations",
                    "type": "File",
                    "id": "#functional_annotation.cwl/eggnog_annotations"
                },
                {
                    "outputSource": "#functional_annotation.cwl/eggnog/orthologs",
                    "type": "File",
                    "id": "#functional_annotation.cwl/eggnog_orthologs"
                },
                {
                    "type": "File",
                    "outputSource": "#functional_annotation.cwl/run_hmmer/hmm_result",
                    "id": "#functional_annotation.cwl/hmm_result"
                },
                {
                    "type": "File",
                    "outputSource": "#functional_annotation.cwl/run_IPS/ips_result",
                    "id": "#functional_annotation.cwl/ips_result"
                }
            ],
            "steps": [
                {
                    "run": "#eggnog-subwf.cwl",
                    "in": [
                        {
                            "default": 16,
                            "id": "#functional_annotation.cwl/eggnog/cpu"
                        },
                        {
                            "source": "#functional_annotation.cwl/EggNOG_data_dir",
                            "id": "#functional_annotation.cwl/eggnog/data_dir"
                        },
                        {
                            "source": "#functional_annotation.cwl/EggNOG_db",
                            "id": "#functional_annotation.cwl/eggnog/db"
                        },
                        {
                            "source": "#functional_annotation.cwl/EggNOG_diamond_db",
                            "id": "#functional_annotation.cwl/eggnog/db_diamond"
                        },
                        {
                            "source": "#functional_annotation.cwl/split_seqs/chunks",
                            "id": "#functional_annotation.cwl/eggnog/fasta_file"
                        },
                        {
                            "source": "#functional_annotation.cwl/CGC_predicted_proteins",
                            "valueFrom": "$(self.nameroot)",
                            "id": "#functional_annotation.cwl/eggnog/file_acc"
                        }
                    ],
                    "out": [
                        "#functional_annotation.cwl/eggnog/annotations",
                        "#functional_annotation.cwl/eggnog/orthologs"
                    ],
                    "id": "#functional_annotation.cwl/eggnog"
                },
                {
                    "run": "#chunking-subwf-IPS.cwl",
                    "in": [
                        {
                            "source": "#functional_annotation.cwl/CGC_predicted_proteins",
                            "id": "#functional_annotation.cwl/run_IPS/CGC_predicted_proteins"
                        },
                        {
                            "source": "#functional_annotation.cwl/InterProScan_applications",
                            "id": "#functional_annotation.cwl/run_IPS/InterProScan_applications"
                        },
                        {
                            "source": "#functional_annotation.cwl/InterProScan_databases",
                            "id": "#functional_annotation.cwl/run_IPS/InterProScan_databases"
                        },
                        {
                            "source": "#functional_annotation.cwl/InterProScan_outputFormat",
                            "id": "#functional_annotation.cwl/run_IPS/InterProScan_outputFormat"
                        },
                        {
                            "source": "#functional_annotation.cwl/chunk_size_IPS",
                            "id": "#functional_annotation.cwl/run_IPS/chunk_size"
                        },
                        {
                            "source": "#functional_annotation.cwl/name_ips",
                            "id": "#functional_annotation.cwl/run_IPS/name_ips"
                        }
                    ],
                    "out": [
                        "#functional_annotation.cwl/run_IPS/ips_result"
                    ],
                    "id": "#functional_annotation.cwl/run_IPS"
                },
                {
                    "run": "#chunking-subwf-hmmsearch.cwl",
                    "in": [
                        {
                            "source": "#functional_annotation.cwl/CGC_predicted_proteins",
                            "id": "#functional_annotation.cwl/run_hmmer/CGC_predicted_proteins"
                        },
                        {
                            "source": "#functional_annotation.cwl/HMM_database",
                            "id": "#functional_annotation.cwl/run_hmmer/HMM_database"
                        },
                        {
                            "source": "#functional_annotation.cwl/HMM_gathering_bit_score",
                            "id": "#functional_annotation.cwl/run_hmmer/HMM_gathering_bit_score"
                        },
                        {
                            "source": "#functional_annotation.cwl/HMM_omit_alignment",
                            "id": "#functional_annotation.cwl/run_hmmer/HMM_omit_alignment"
                        },
                        {
                            "source": "#functional_annotation.cwl/chunk_size_hmm",
                            "id": "#functional_annotation.cwl/run_hmmer/chunk_size"
                        },
                        {
                            "source": "#functional_annotation.cwl/name_hmmer",
                            "id": "#functional_annotation.cwl/run_hmmer/name_hmmer"
                        },
                        {
                            "source": "#functional_annotation.cwl/run_IPS/ips_result",
                            "id": "#functional_annotation.cwl/run_hmmer/previous_step_result"
                        }
                    ],
                    "out": [
                        "#functional_annotation.cwl/run_hmmer/hmm_result"
                    ],
                    "id": "#functional_annotation.cwl/run_hmmer"
                },
                {
                    "in": [
                        {
                            "source": "#functional_annotation.cwl/chunk_size_eggnog",
                            "id": "#functional_annotation.cwl/split_seqs/chunk_size"
                        },
                        {
                            "source": "#functional_annotation.cwl/CGC_predicted_proteins",
                            "id": "#functional_annotation.cwl/split_seqs/seqs"
                        }
                    ],
                    "out": [
                        "#functional_annotation.cwl/split_seqs/chunks"
                    ],
                    "run": "#protein_chunker.cwl",
                    "id": "#functional_annotation.cwl/split_seqs"
                }
            ],
            "id": "#functional_annotation.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#kegg_analysis.cwl/filtered_fasta"
                },
                {
                    "type": "string",
                    "id": "#kegg_analysis.cwl/graphs"
                },
                {
                    "type": "File",
                    "id": "#kegg_analysis.cwl/input_table_hmmscan"
                },
                {
                    "type": "string",
                    "id": "#kegg_analysis.cwl/outputname"
                },
                {
                    "type": "string",
                    "id": "#kegg_analysis.cwl/pathways_classes"
                },
                {
                    "type": "string",
                    "id": "#kegg_analysis.cwl/pathways_names"
                }
            ],
            "outputs": [
                {
                    "outputSource": "#kegg_analysis.cwl/kegg_pathways/summary_contigs",
                    "type": "File",
                    "id": "#kegg_analysis.cwl/kegg_contigs_summary"
                },
                {
                    "outputSource": "#kegg_analysis.cwl/kegg_pathways/summary_pathways",
                    "type": "File",
                    "id": "#kegg_analysis.cwl/kegg_pathways_summary"
                },
                {
                    "outputSource": "#kegg_analysis.cwl/tab_modification/output_with_tabs",
                    "type": "File",
                    "id": "#kegg_analysis.cwl/modification_out"
                },
                {
                    "outputSource": "#kegg_analysis.cwl/parsing_hmmscan/output_table",
                    "type": "File",
                    "id": "#kegg_analysis.cwl/parsing_hmmscan_out"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#kegg_analysis.cwl/graphs",
                            "id": "#kegg_analysis.cwl/kegg_pathways/graphs"
                        },
                        {
                            "source": "#kegg_analysis.cwl/parsing_hmmscan/output_table",
                            "id": "#kegg_analysis.cwl/kegg_pathways/input_table"
                        },
                        {
                            "source": "#kegg_analysis.cwl/outputname",
                            "id": "#kegg_analysis.cwl/kegg_pathways/outputname"
                        },
                        {
                            "source": "#kegg_analysis.cwl/pathways_classes",
                            "id": "#kegg_analysis.cwl/kegg_pathways/pathways_classes"
                        },
                        {
                            "source": "#kegg_analysis.cwl/pathways_names",
                            "id": "#kegg_analysis.cwl/kegg_pathways/pathways_names"
                        }
                    ],
                    "out": [
                        "#kegg_analysis.cwl/kegg_pathways/summary_pathways",
                        "#kegg_analysis.cwl/kegg_pathways/summary_contigs"
                    ],
                    "run": "#kegg_pathways.cwl",
                    "id": "#kegg_analysis.cwl/kegg_pathways"
                },
                {
                    "in": [
                        {
                            "source": "#kegg_analysis.cwl/filtered_fasta",
                            "id": "#kegg_analysis.cwl/parsing_hmmscan/fasta"
                        },
                        {
                            "source": "#kegg_analysis.cwl/tab_modification/output_with_tabs",
                            "id": "#kegg_analysis.cwl/parsing_hmmscan/table"
                        }
                    ],
                    "out": [
                        "#kegg_analysis.cwl/parsing_hmmscan/output_table"
                    ],
                    "run": "#parsing_hmmscan.cwl",
                    "label": "leave file with contig and it's KO",
                    "id": "#kegg_analysis.cwl/parsing_hmmscan"
                },
                {
                    "in": [
                        {
                            "source": "#kegg_analysis.cwl/input_table_hmmscan",
                            "id": "#kegg_analysis.cwl/tab_modification/input_table"
                        }
                    ],
                    "out": [
                        "#kegg_analysis.cwl/tab_modification/output_with_tabs"
                    ],
                    "run": "#modification_table.cwl",
                    "label": "make table tab-separated",
                    "id": "#kegg_analysis.cwl/tab_modification"
                }
            ],
            "id": "#kegg_analysis.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 1000,
                    "coresMin": 1,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#chunking-subwf-IPS.cwl/CGC_predicted_proteins"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#chunking-subwf-IPS.cwl/InterProScan_applications"
                },
                {
                    "type": "string",
                    "id": "#chunking-subwf-IPS.cwl/InterProScan_databases"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#chunking-subwf-IPS.cwl/InterProScan_outputFormat"
                },
                {
                    "type": "int",
                    "id": "#chunking-subwf-IPS.cwl/chunk_size"
                },
                {
                    "type": "string",
                    "id": "#chunking-subwf-IPS.cwl/name_ips"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#chunking-subwf-IPS.cwl/combine_ips/result",
                    "id": "#chunking-subwf-IPS.cwl/ips_result"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#chunking-subwf-IPS.cwl/interproscan/i5Annotations",
                            "id": "#chunking-subwf-IPS.cwl/combine_ips/files"
                        },
                        {
                            "source": "#chunking-subwf-IPS.cwl/CGC_predicted_proteins",
                            "valueFrom": "$(self.nameroot.split('_CDS')[0])",
                            "id": "#chunking-subwf-IPS.cwl/combine_ips/outputFileName"
                        },
                        {
                            "source": "#chunking-subwf-IPS.cwl/name_ips",
                            "id": "#chunking-subwf-IPS.cwl/combine_ips/postfix"
                        }
                    ],
                    "out": [
                        "#chunking-subwf-IPS.cwl/combine_ips/result"
                    ],
                    "run": "#concatenate.cwl",
                    "id": "#chunking-subwf-IPS.cwl/combine_ips"
                },
                {
                    "scatter": "#chunking-subwf-IPS.cwl/interproscan/inputFile",
                    "in": [
                        {
                            "source": "#chunking-subwf-IPS.cwl/InterProScan_applications",
                            "id": "#chunking-subwf-IPS.cwl/interproscan/applications"
                        },
                        {
                            "source": "#chunking-subwf-IPS.cwl/InterProScan_databases",
                            "id": "#chunking-subwf-IPS.cwl/interproscan/databases"
                        },
                        {
                            "source": "#chunking-subwf-IPS.cwl/split_seqs/chunks",
                            "id": "#chunking-subwf-IPS.cwl/interproscan/inputFile"
                        },
                        {
                            "source": "#chunking-subwf-IPS.cwl/InterProScan_outputFormat",
                            "id": "#chunking-subwf-IPS.cwl/interproscan/outputFormat"
                        }
                    ],
                    "out": [
                        "#chunking-subwf-IPS.cwl/interproscan/i5Annotations"
                    ],
                    "run": "#InterProScan-v5-none_docker.cwl",
                    "label": "InterProScan: protein sequence classifier",
                    "id": "#chunking-subwf-IPS.cwl/interproscan"
                },
                {
                    "in": [
                        {
                            "source": "#chunking-subwf-IPS.cwl/chunk_size",
                            "id": "#chunking-subwf-IPS.cwl/split_seqs/chunk_size"
                        },
                        {
                            "source": "#chunking-subwf-IPS.cwl/CGC_predicted_proteins",
                            "id": "#chunking-subwf-IPS.cwl/split_seqs/seqs"
                        }
                    ],
                    "out": [
                        "#chunking-subwf-IPS.cwl/split_seqs/chunks"
                    ],
                    "run": "#protein_chunker.cwl",
                    "id": "#chunking-subwf-IPS.cwl/split_seqs"
                }
            ],
            "id": "#chunking-subwf-IPS.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 1000,
                    "coresMin": 1,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#chunking-subwf-hmmsearch.cwl/CGC_predicted_proteins"
                },
                {
                    "type": "string",
                    "id": "#chunking-subwf-hmmsearch.cwl/HMM_database"
                },
                {
                    "type": "boolean",
                    "id": "#chunking-subwf-hmmsearch.cwl/HMM_gathering_bit_score"
                },
                {
                    "type": "boolean",
                    "id": "#chunking-subwf-hmmsearch.cwl/HMM_omit_alignment"
                },
                {
                    "type": "int",
                    "id": "#chunking-subwf-hmmsearch.cwl/chunk_size"
                },
                {
                    "type": "string",
                    "id": "#chunking-subwf-hmmsearch.cwl/name_hmmer"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#chunking-subwf-hmmsearch.cwl/previous_step_result"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#chunking-subwf-hmmsearch.cwl/make_tab_sep/output_with_tabs",
                    "id": "#chunking-subwf-hmmsearch.cwl/hmm_result"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#chunking-subwf-hmmsearch.cwl/hmmsearch/output_table",
                            "id": "#chunking-subwf-hmmsearch.cwl/combine/files"
                        },
                        {
                            "source": "#chunking-subwf-hmmsearch.cwl/CGC_predicted_proteins",
                            "valueFrom": "$(self.nameroot.split('_CDS')[0])",
                            "id": "#chunking-subwf-hmmsearch.cwl/combine/outputFileName"
                        },
                        {
                            "source": "#chunking-subwf-hmmsearch.cwl/name_hmmer",
                            "id": "#chunking-subwf-hmmsearch.cwl/combine/postfix"
                        }
                    ],
                    "out": [
                        "#chunking-subwf-hmmsearch.cwl/combine/result"
                    ],
                    "run": "#concatenate.cwl",
                    "id": "#chunking-subwf-hmmsearch.cwl/combine"
                },
                {
                    "scatter": "#chunking-subwf-hmmsearch.cwl/hmmsearch/seqfile",
                    "in": [
                        {
                            "source": "#chunking-subwf-hmmsearch.cwl/HMM_gathering_bit_score",
                            "id": "#chunking-subwf-hmmsearch.cwl/hmmsearch/gathering_bit_score"
                        },
                        {
                            "source": "#chunking-subwf-hmmsearch.cwl/HMM_omit_alignment",
                            "id": "#chunking-subwf-hmmsearch.cwl/hmmsearch/omit_alignment"
                        },
                        {
                            "source": "#chunking-subwf-hmmsearch.cwl/HMM_database",
                            "id": "#chunking-subwf-hmmsearch.cwl/hmmsearch/path_database"
                        },
                        {
                            "source": "#chunking-subwf-hmmsearch.cwl/split_seqs/chunks",
                            "id": "#chunking-subwf-hmmsearch.cwl/hmmsearch/seqfile"
                        }
                    ],
                    "out": [
                        "#chunking-subwf-hmmsearch.cwl/hmmsearch/output_table"
                    ],
                    "run": "#hmmsearch.cwl",
                    "label": "Analysis using profile HMM on db",
                    "id": "#chunking-subwf-hmmsearch.cwl/hmmsearch"
                },
                {
                    "run": "#hmmscan_tab_modification.cwl",
                    "in": [
                        {
                            "source": "#chunking-subwf-hmmsearch.cwl/combine/result",
                            "id": "#chunking-subwf-hmmsearch.cwl/make_tab_sep/input_table"
                        }
                    ],
                    "out": [
                        "#chunking-subwf-hmmsearch.cwl/make_tab_sep/output_with_tabs"
                    ],
                    "id": "#chunking-subwf-hmmsearch.cwl/make_tab_sep"
                },
                {
                    "in": [
                        {
                            "source": "#chunking-subwf-hmmsearch.cwl/chunk_size",
                            "id": "#chunking-subwf-hmmsearch.cwl/split_seqs/chunk_size"
                        },
                        {
                            "source": "#chunking-subwf-hmmsearch.cwl/CGC_predicted_proteins",
                            "id": "#chunking-subwf-hmmsearch.cwl/split_seqs/seqs"
                        }
                    ],
                    "out": [
                        "#chunking-subwf-hmmsearch.cwl/split_seqs/chunks"
                    ],
                    "run": "#protein_chunker.cwl",
                    "id": "#chunking-subwf-hmmsearch.cwl/split_seqs"
                }
            ],
            "id": "#chunking-subwf-hmmsearch.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "Run taxonomic classification, create OTU table and krona visualisation",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#classify-otu-visualise.cwl/fasta"
                },
                {
                    "type": "File",
                    "id": "#classify-otu-visualise.cwl/file_for_prefix"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster",
                            "required": null
                        }
                    ],
                    "id": "#classify-otu-visualise.cwl/mapseq_ref"
                },
                {
                    "type": "string",
                    "id": "#classify-otu-visualise.cwl/mapseq_taxonomy"
                },
                {
                    "type": "string",
                    "id": "#classify-otu-visualise.cwl/otu_label"
                },
                {
                    "type": "string",
                    "id": "#classify-otu-visualise.cwl/otu_ref"
                },
                {
                    "type": "string",
                    "id": "#classify-otu-visualise.cwl/return_dirname"
                }
            ],
            "outputs": [
                {
                    "type": "int",
                    "outputSource": "#classify-otu-visualise.cwl/count_lines_mapseq/number",
                    "id": "#classify-otu-visualise.cwl/number_lines_mapseq"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#classify-otu-visualise.cwl/return_output_dir/out",
                    "id": "#classify-otu-visualise.cwl/out_dir"
                }
            ],
            "steps": [
                {
                    "run": "#mapseq2biom.cwl",
                    "in": [
                        {
                            "source": "#classify-otu-visualise.cwl/otu_label",
                            "id": "#classify-otu-visualise.cwl/classifications_to_otu_counts/label"
                        },
                        {
                            "source": "#classify-otu-visualise.cwl/otu_ref",
                            "id": "#classify-otu-visualise.cwl/classifications_to_otu_counts/otu_table"
                        },
                        {
                            "source": "#classify-otu-visualise.cwl/mapseq/classifications",
                            "id": "#classify-otu-visualise.cwl/classifications_to_otu_counts/query"
                        },
                        {
                            "default": true,
                            "id": "#classify-otu-visualise.cwl/classifications_to_otu_counts/taxid_flag"
                        }
                    ],
                    "out": [
                        "#classify-otu-visualise.cwl/classifications_to_otu_counts/otu_tsv",
                        "#classify-otu-visualise.cwl/classifications_to_otu_counts/otu_txt",
                        "#classify-otu-visualise.cwl/classifications_to_otu_counts/otu_tsv_notaxid"
                    ],
                    "id": "#classify-otu-visualise.cwl/classifications_to_otu_counts"
                },
                {
                    "run": "#gzip.cwl",
                    "in": [
                        {
                            "source": "#classify-otu-visualise.cwl/mapseq/classifications",
                            "id": "#classify-otu-visualise.cwl/compress_mapseq/uncompressed_file"
                        }
                    ],
                    "out": [
                        "#classify-otu-visualise.cwl/compress_mapseq/compressed_file"
                    ],
                    "label": "gzip mapseq output",
                    "id": "#classify-otu-visualise.cwl/compress_mapseq"
                },
                {
                    "run": "#count_number_lines.cwl",
                    "in": [
                        {
                            "source": "#classify-otu-visualise.cwl/mapseq/classifications",
                            "id": "#classify-otu-visualise.cwl/count_lines_mapseq/input_file"
                        }
                    ],
                    "out": [
                        "#classify-otu-visualise.cwl/count_lines_mapseq/number"
                    ],
                    "id": "#classify-otu-visualise.cwl/count_lines_mapseq"
                },
                {
                    "when": "$(inputs.count > 2)",
                    "run": "#biom-convert.cwl",
                    "in": [
                        {
                            "source": "#classify-otu-visualise.cwl/classifications_to_otu_counts/otu_tsv_notaxid",
                            "id": "#classify-otu-visualise.cwl/counts_to_hdf5/biom"
                        },
                        {
                            "source": "#classify-otu-visualise.cwl/count_lines_mapseq/number",
                            "id": "#classify-otu-visualise.cwl/counts_to_hdf5/count"
                        },
                        {
                            "default": true,
                            "id": "#classify-otu-visualise.cwl/counts_to_hdf5/hdf5"
                        },
                        {
                            "default": "OTU table",
                            "id": "#classify-otu-visualise.cwl/counts_to_hdf5/table_type"
                        }
                    ],
                    "out": [
                        "#classify-otu-visualise.cwl/counts_to_hdf5/result"
                    ],
                    "id": "#classify-otu-visualise.cwl/counts_to_hdf5"
                },
                {
                    "when": "$(inputs.count > 2)",
                    "run": "#biom-convert.cwl",
                    "in": [
                        {
                            "source": "#classify-otu-visualise.cwl/classifications_to_otu_counts/otu_tsv_notaxid",
                            "id": "#classify-otu-visualise.cwl/counts_to_json/biom"
                        },
                        {
                            "source": "#classify-otu-visualise.cwl/count_lines_mapseq/number",
                            "id": "#classify-otu-visualise.cwl/counts_to_json/count"
                        },
                        {
                            "default": true,
                            "id": "#classify-otu-visualise.cwl/counts_to_json/json"
                        },
                        {
                            "default": "OTU table",
                            "id": "#classify-otu-visualise.cwl/counts_to_json/table_type"
                        }
                    ],
                    "out": [
                        "#classify-otu-visualise.cwl/counts_to_json/result"
                    ],
                    "id": "#classify-otu-visualise.cwl/counts_to_json"
                },
                {
                    "run": "#mapseq.cwl",
                    "in": [
                        {
                            "source": "#classify-otu-visualise.cwl/mapseq_ref",
                            "id": "#classify-otu-visualise.cwl/mapseq/database"
                        },
                        {
                            "source": "#classify-otu-visualise.cwl/file_for_prefix",
                            "id": "#classify-otu-visualise.cwl/mapseq/prefix"
                        },
                        {
                            "source": "#classify-otu-visualise.cwl/fasta",
                            "id": "#classify-otu-visualise.cwl/mapseq/sequences"
                        },
                        {
                            "source": "#classify-otu-visualise.cwl/mapseq_taxonomy",
                            "id": "#classify-otu-visualise.cwl/mapseq/taxonomy"
                        }
                    ],
                    "out": [
                        "#classify-otu-visualise.cwl/mapseq/classifications"
                    ],
                    "id": "#classify-otu-visualise.cwl/mapseq"
                },
                {
                    "when": "$(inputs.count > 2)",
                    "run": "#return_directory.cwl",
                    "in": [
                        {
                            "source": "#classify-otu-visualise.cwl/count_lines_mapseq/number",
                            "id": "#classify-otu-visualise.cwl/return_output_dir/count"
                        },
                        {
                            "source": "#classify-otu-visualise.cwl/return_dirname",
                            "id": "#classify-otu-visualise.cwl/return_output_dir/dir_name"
                        },
                        {
                            "source": [
                                "#classify-otu-visualise.cwl/compress_mapseq/compressed_file",
                                "#classify-otu-visualise.cwl/classifications_to_otu_counts/otu_tsv",
                                "#classify-otu-visualise.cwl/classifications_to_otu_counts/otu_txt",
                                "#classify-otu-visualise.cwl/visualize_otu_counts/otu_visualization",
                                "#classify-otu-visualise.cwl/counts_to_hdf5/result",
                                "#classify-otu-visualise.cwl/counts_to_json/result"
                            ],
                            "id": "#classify-otu-visualise.cwl/return_output_dir/file_list"
                        }
                    ],
                    "out": [
                        "#classify-otu-visualise.cwl/return_output_dir/out"
                    ],
                    "label": "return all files in one folder",
                    "id": "#classify-otu-visualise.cwl/return_output_dir"
                },
                {
                    "run": "#krona.cwl",
                    "in": [
                        {
                            "source": "#classify-otu-visualise.cwl/classifications_to_otu_counts/otu_txt",
                            "id": "#classify-otu-visualise.cwl/visualize_otu_counts/otu_counts"
                        }
                    ],
                    "out": [
                        "#classify-otu-visualise.cwl/visualize_otu_counts/otu_visualization"
                    ],
                    "id": "#classify-otu-visualise.cwl/visualize_otu_counts"
                }
            ],
            "id": "#classify-otu-visualise.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "Identifies non-coding RNAs using Rfams covariance models",
            "requirements": [
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#cmsearch-condition.cwl/clan_info"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#cmsearch-condition.cwl/covariance_models"
                },
                {
                    "type": "File",
                    "id": "#cmsearch-condition.cwl/query_sequences"
                },
                {
                    "type": "string",
                    "id": "#cmsearch-condition.cwl/type"
                }
            ],
            "outputs": [
                {
                    "outputSource": [
                        "#cmsearch-condition.cwl/cmsearch_assembly/concatenate_matches",
                        "#cmsearch-condition.cwl/cmsearch_raw_data/concatenate_matches"
                    ],
                    "pickValue": "first_non_null",
                    "type": "File",
                    "id": "#cmsearch-condition.cwl/concatenate_matches"
                },
                {
                    "outputSource": [
                        "#cmsearch-condition.cwl/cmsearch_assembly/deoverlapped_matches",
                        "#cmsearch-condition.cwl/cmsearch_raw_data/deoverlapped_matches"
                    ],
                    "pickValue": "first_non_null",
                    "type": "File",
                    "id": "#cmsearch-condition.cwl/deoverlapped_matches"
                }
            ],
            "steps": [
                {
                    "when": "$(inputs.type == 'assembly')",
                    "label": "Search sequence(s) against a covariance model database for assemblies",
                    "run": "#cmsearch-multimodel-assembly.cwl",
                    "in": [
                        {
                            "source": "#cmsearch-condition.cwl/clan_info",
                            "id": "#cmsearch-condition.cwl/cmsearch_assembly/clan_info"
                        },
                        {
                            "source": "#cmsearch-condition.cwl/covariance_models",
                            "id": "#cmsearch-condition.cwl/cmsearch_assembly/covariance_models"
                        },
                        {
                            "source": "#cmsearch-condition.cwl/query_sequences",
                            "id": "#cmsearch-condition.cwl/cmsearch_assembly/query_sequences"
                        },
                        {
                            "source": "#cmsearch-condition.cwl/type",
                            "id": "#cmsearch-condition.cwl/cmsearch_assembly/type"
                        }
                    ],
                    "out": [
                        "#cmsearch-condition.cwl/cmsearch_assembly/concatenate_matches",
                        "#cmsearch-condition.cwl/cmsearch_assembly/deoverlapped_matches"
                    ],
                    "id": "#cmsearch-condition.cwl/cmsearch_assembly"
                },
                {
                    "when": "$(inputs.type == 'raw')",
                    "label": "Search sequence(s) against a covariance model database for amplicon and wgs",
                    "run": "#cmsearch-multimodel-raw-data.cwl",
                    "in": [
                        {
                            "source": "#cmsearch-condition.cwl/clan_info",
                            "id": "#cmsearch-condition.cwl/cmsearch_raw_data/clan_info"
                        },
                        {
                            "source": "#cmsearch-condition.cwl/covariance_models",
                            "id": "#cmsearch-condition.cwl/cmsearch_raw_data/covariance_models"
                        },
                        {
                            "source": "#cmsearch-condition.cwl/query_sequences",
                            "id": "#cmsearch-condition.cwl/cmsearch_raw_data/query_sequences"
                        },
                        {
                            "source": "#cmsearch-condition.cwl/type",
                            "id": "#cmsearch-condition.cwl/cmsearch_raw_data/type"
                        }
                    ],
                    "out": [
                        "#cmsearch-condition.cwl/cmsearch_raw_data/concatenate_matches",
                        "#cmsearch-condition.cwl/cmsearch_raw_data/deoverlapped_matches"
                    ],
                    "id": "#cmsearch-condition.cwl/cmsearch_raw_data"
                }
            ],
            "id": "#cmsearch-condition.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/author": "Ekaterina Sakharova"
        },
        {
            "class": "Workflow",
            "label": "Identifies non-coding RNAs using Rfams covariance models",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#cmsearch-multimodel-raw-data.cwl/clan_info"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#cmsearch-multimodel-raw-data.cwl/covariance_models"
                },
                {
                    "type": "File",
                    "id": "#cmsearch-multimodel-raw-data.cwl/query_sequences"
                }
            ],
            "outputs": [
                {
                    "outputSource": "#cmsearch-multimodel-raw-data.cwl/run_concatenate_matches/result",
                    "type": "File",
                    "id": "#cmsearch-multimodel-raw-data.cwl/concatenate_matches"
                },
                {
                    "outputSource": "#cmsearch-multimodel-raw-data.cwl/run_concatenate_deoverlapped_matches/result",
                    "type": "File",
                    "id": "#cmsearch-multimodel-raw-data.cwl/deoverlapped_matches"
                }
            ],
            "steps": [
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#cmsearch-multimodel-raw-data.cwl/covariance_models",
                            "id": "#cmsearch-multimodel-raw-data.cwl/cat_models/files"
                        },
                        {
                            "default": "models_cmsearch",
                            "id": "#cmsearch-multimodel-raw-data.cwl/cat_models/outputFileName"
                        },
                        {
                            "default": ".all.tblout",
                            "id": "#cmsearch-multimodel-raw-data.cwl/cat_models/postfix"
                        }
                    ],
                    "out": [
                        "#cmsearch-multimodel-raw-data.cwl/cat_models/result"
                    ],
                    "id": "#cmsearch-multimodel-raw-data.cwl/cat_models"
                },
                {
                    "label": "Search sequence(s) against a covariance model database",
                    "run": "#infernal-cmsearch-v1.1.2.cwl",
                    "scatter": "#cmsearch-multimodel-raw-data.cwl/cmsearch/query_sequences",
                    "in": [
                        {
                            "source": "#cmsearch-multimodel-raw-data.cwl/cat_models/result",
                            "id": "#cmsearch-multimodel-raw-data.cwl/cmsearch/covariance_model_database"
                        },
                        {
                            "default": 8,
                            "id": "#cmsearch-multimodel-raw-data.cwl/cmsearch/cpu"
                        },
                        {
                            "default": true,
                            "id": "#cmsearch-multimodel-raw-data.cwl/cmsearch/cut_ga"
                        },
                        {
                            "default": true,
                            "id": "#cmsearch-multimodel-raw-data.cwl/cmsearch/omit_alignment_section"
                        },
                        {
                            "default": true,
                            "id": "#cmsearch-multimodel-raw-data.cwl/cmsearch/only_hmm"
                        },
                        {
                            "source": "#cmsearch-multimodel-raw-data.cwl/split_fasta/chunks",
                            "id": "#cmsearch-multimodel-raw-data.cwl/cmsearch/query_sequences"
                        },
                        {
                            "default": 1000,
                            "id": "#cmsearch-multimodel-raw-data.cwl/cmsearch/search_space_size"
                        }
                    ],
                    "out": [
                        "#cmsearch-multimodel-raw-data.cwl/cmsearch/matches"
                    ],
                    "id": "#cmsearch-multimodel-raw-data.cwl/cmsearch"
                },
                {
                    "label": "Remove lower scoring overlaps from cmsearch --tblout files.",
                    "run": "#cmsearch-deoverlap-v0.02.cwl",
                    "in": [
                        {
                            "source": "#cmsearch-multimodel-raw-data.cwl/clan_info",
                            "id": "#cmsearch-multimodel-raw-data.cwl/remove_overlaps/clan_information"
                        },
                        {
                            "source": "#cmsearch-multimodel-raw-data.cwl/cmsearch/matches",
                            "id": "#cmsearch-multimodel-raw-data.cwl/remove_overlaps/cmsearch_matches"
                        }
                    ],
                    "scatter": "#cmsearch-multimodel-raw-data.cwl/remove_overlaps/cmsearch_matches",
                    "out": [
                        "#cmsearch-multimodel-raw-data.cwl/remove_overlaps/deoverlapped_matches"
                    ],
                    "id": "#cmsearch-multimodel-raw-data.cwl/remove_overlaps"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#cmsearch-multimodel-raw-data.cwl/remove_overlaps/deoverlapped_matches",
                            "id": "#cmsearch-multimodel-raw-data.cwl/run_concatenate_deoverlapped_matches/files"
                        },
                        {
                            "source": "#cmsearch-multimodel-raw-data.cwl/query_sequences",
                            "valueFrom": "$(self.nameroot)",
                            "id": "#cmsearch-multimodel-raw-data.cwl/run_concatenate_deoverlapped_matches/outputFileName"
                        },
                        {
                            "default": ".cmsearch.all.tblout.deoverlapped",
                            "id": "#cmsearch-multimodel-raw-data.cwl/run_concatenate_deoverlapped_matches/postfix"
                        }
                    ],
                    "out": [
                        "#cmsearch-multimodel-raw-data.cwl/run_concatenate_deoverlapped_matches/result"
                    ],
                    "id": "#cmsearch-multimodel-raw-data.cwl/run_concatenate_deoverlapped_matches"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#cmsearch-multimodel-raw-data.cwl/cmsearch/matches",
                            "id": "#cmsearch-multimodel-raw-data.cwl/run_concatenate_matches/files"
                        },
                        {
                            "source": "#cmsearch-multimodel-raw-data.cwl/query_sequences",
                            "valueFrom": "$(self.nameroot)",
                            "id": "#cmsearch-multimodel-raw-data.cwl/run_concatenate_matches/outputFileName"
                        },
                        {
                            "default": ".cmsearch.all.tblout",
                            "id": "#cmsearch-multimodel-raw-data.cwl/run_concatenate_matches/postfix"
                        }
                    ],
                    "out": [
                        "#cmsearch-multimodel-raw-data.cwl/run_concatenate_matches/result"
                    ],
                    "id": "#cmsearch-multimodel-raw-data.cwl/run_concatenate_matches"
                },
                {
                    "run": "#fasta_chunker.cwl",
                    "in": [
                        {
                            "default": 2000000,
                            "id": "#cmsearch-multimodel-raw-data.cwl/split_fasta/chunk_size"
                        },
                        {
                            "default": "False",
                            "id": "#cmsearch-multimodel-raw-data.cwl/split_fasta/number_of_output_files"
                        },
                        {
                            "default": "False",
                            "id": "#cmsearch-multimodel-raw-data.cwl/split_fasta/same_number_of_residues"
                        },
                        {
                            "source": "#cmsearch-multimodel-raw-data.cwl/query_sequences",
                            "id": "#cmsearch-multimodel-raw-data.cwl/split_fasta/seqs"
                        }
                    ],
                    "out": [
                        "#cmsearch-multimodel-raw-data.cwl/split_fasta/chunks"
                    ],
                    "id": "#cmsearch-multimodel-raw-data.cwl/split_fasta"
                }
            ],
            "id": "#cmsearch-multimodel-raw-data.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2020",
            "http://schema.org/author": "Ekaterina Sakharova, Martin Beracochea",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 10000
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#final_chunking.cwl/LSU"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#final_chunking.cwl/SSU"
                },
                {
                    "type": "File",
                    "id": "#final_chunking.cwl/faa"
                },
                {
                    "type": "File",
                    "id": "#final_chunking.cwl/fasta"
                },
                {
                    "type": "File",
                    "id": "#final_chunking.cwl/ffn"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#final_chunking.cwl/chinking_SC_fasta_nucleotide/chunks",
                    "id": "#final_chunking.cwl/SC_fasta_chunks"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#final_chunking.cwl/chinking_fasta_nucleotide/chunks",
                    "id": "#final_chunking.cwl/nucleotide_fasta_chunks"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#final_chunking.cwl/chinking_fasta_proteins/chunks",
                    "id": "#final_chunking.cwl/protein_fasta_chunks"
                }
            ],
            "steps": [
                {
                    "when": "$(inputs.lsu != null && inputs.ssu != null)",
                    "run": "#result_chunker.cwl",
                    "in": [
                        {
                            "default": "fasta",
                            "id": "#final_chunking.cwl/chinking_SC_fasta_nucleotide/format_file"
                        },
                        {
                            "source": [
                                "#final_chunking.cwl/LSU",
                                "#final_chunking.cwl/SSU"
                            ],
                            "id": "#final_chunking.cwl/chinking_SC_fasta_nucleotide/infile"
                        },
                        {
                            "source": "#final_chunking.cwl/LSU",
                            "id": "#final_chunking.cwl/chinking_SC_fasta_nucleotide/lsu"
                        },
                        {
                            "default": "folder",
                            "id": "#final_chunking.cwl/chinking_SC_fasta_nucleotide/outdirname"
                        },
                        {
                            "source": "#final_chunking.cwl/SSU",
                            "id": "#final_chunking.cwl/chinking_SC_fasta_nucleotide/ssu"
                        },
                        {
                            "default": "n",
                            "id": "#final_chunking.cwl/chinking_SC_fasta_nucleotide/type_fasta"
                        }
                    ],
                    "out": [
                        "#final_chunking.cwl/chinking_SC_fasta_nucleotide/chunks"
                    ],
                    "id": "#final_chunking.cwl/chinking_SC_fasta_nucleotide"
                },
                {
                    "run": "#result_chunker.cwl",
                    "in": [
                        {
                            "default": "fasta",
                            "id": "#final_chunking.cwl/chinking_fasta_nucleotide/format_file"
                        },
                        {
                            "source": [
                                "#final_chunking.cwl/fasta",
                                "#final_chunking.cwl/ffn"
                            ],
                            "id": "#final_chunking.cwl/chinking_fasta_nucleotide/infile"
                        },
                        {
                            "default": "folder",
                            "id": "#final_chunking.cwl/chinking_fasta_nucleotide/outdirname"
                        },
                        {
                            "default": "n",
                            "id": "#final_chunking.cwl/chinking_fasta_nucleotide/type_fasta"
                        }
                    ],
                    "out": [
                        "#final_chunking.cwl/chinking_fasta_nucleotide/chunks"
                    ],
                    "id": "#final_chunking.cwl/chinking_fasta_nucleotide"
                },
                {
                    "run": "#result_chunker.cwl",
                    "in": [
                        {
                            "default": "fasta",
                            "id": "#final_chunking.cwl/chinking_fasta_proteins/format_file"
                        },
                        {
                            "source": [
                                "#final_chunking.cwl/faa"
                            ],
                            "linkMerge": "merge_nested",
                            "id": "#final_chunking.cwl/chinking_fasta_proteins/infile"
                        },
                        {
                            "default": "folder",
                            "id": "#final_chunking.cwl/chinking_fasta_proteins/outdirname"
                        },
                        {
                            "default": "p",
                            "id": "#final_chunking.cwl/chinking_fasta_proteins/type_fasta"
                        }
                    ],
                    "out": [
                        "#final_chunking.cwl/chinking_fasta_proteins/chunks"
                    ],
                    "id": "#final_chunking.cwl/chinking_fasta_proteins"
                }
            ],
            "id": "#final_chunking.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#func_summaries.cwl/antismash_gene_clusters"
                },
                {
                    "type": "File",
                    "id": "#func_summaries.cwl/cds"
                },
                {
                    "type": "File",
                    "id": "#func_summaries.cwl/hmmscan_annotation"
                },
                {
                    "type": "File",
                    "id": "#func_summaries.cwl/interproscan_annotation"
                },
                {
                    "type": "string",
                    "id": "#func_summaries.cwl/ko_file"
                },
                {
                    "type": "File",
                    "id": "#func_summaries.cwl/pfam_annotation"
                },
                {
                    "type": "File",
                    "id": "#func_summaries.cwl/rna"
                }
            ],
            "outputs": [
                {
                    "outputSource": "#func_summaries.cwl/functional_stats/stats",
                    "type": "Directory",
                    "id": "#func_summaries.cwl/stats"
                },
                {
                    "outputSource": "#func_summaries.cwl/write_summaries/summary_antismash",
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#func_summaries.cwl/summary_antismash"
                },
                {
                    "outputSource": "#func_summaries.cwl/write_summaries/summary_ips",
                    "type": "File",
                    "id": "#func_summaries.cwl/summary_ips"
                },
                {
                    "outputSource": "#func_summaries.cwl/write_summaries/summary_ko",
                    "type": "File",
                    "id": "#func_summaries.cwl/summary_ko"
                },
                {
                    "outputSource": "#func_summaries.cwl/write_summaries/summary_pfam",
                    "type": "File",
                    "id": "#func_summaries.cwl/summary_pfam"
                }
            ],
            "steps": [
                {
                    "run": "#functional_stats.cwl",
                    "in": [
                        {
                            "source": "#func_summaries.cwl/antismash_gene_clusters",
                            "id": "#func_summaries.cwl/functional_stats/antismash_file"
                        },
                        {
                            "source": "#func_summaries.cwl/cds",
                            "id": "#func_summaries.cwl/functional_stats/cds_file"
                        },
                        {
                            "source": "#func_summaries.cwl/rna",
                            "id": "#func_summaries.cwl/functional_stats/cmsearch_file"
                        },
                        {
                            "source": "#func_summaries.cwl/hmmscan_annotation",
                            "id": "#func_summaries.cwl/functional_stats/hmmscan"
                        },
                        {
                            "source": "#func_summaries.cwl/interproscan_annotation",
                            "id": "#func_summaries.cwl/functional_stats/interproscan"
                        },
                        {
                            "source": "#func_summaries.cwl/ko_file",
                            "id": "#func_summaries.cwl/functional_stats/ko_file"
                        },
                        {
                            "source": "#func_summaries.cwl/pfam_annotation",
                            "id": "#func_summaries.cwl/functional_stats/pfam"
                        }
                    ],
                    "out": [
                        "#func_summaries.cwl/functional_stats/stats",
                        "#func_summaries.cwl/functional_stats/ips_yaml",
                        "#func_summaries.cwl/functional_stats/ko_yaml",
                        "#func_summaries.cwl/functional_stats/pfam_yaml",
                        "#func_summaries.cwl/functional_stats/antismash_yaml"
                    ],
                    "id": "#func_summaries.cwl/functional_stats"
                },
                {
                    "run": "#write_summaries.cwl",
                    "in": [
                        {
                            "source": "#func_summaries.cwl/functional_stats/antismash_yaml",
                            "id": "#func_summaries.cwl/write_summaries/antismash_entry_maps"
                        },
                        {
                            "source": "#func_summaries.cwl/cds",
                            "valueFrom": "$(self.nameroot.split('_CDS')[0]).summary.antismash",
                            "id": "#func_summaries.cwl/write_summaries/antismash_outname"
                        },
                        {
                            "source": "#func_summaries.cwl/functional_stats/ips_yaml",
                            "id": "#func_summaries.cwl/write_summaries/ips_entry_maps"
                        },
                        {
                            "source": "#func_summaries.cwl/cds",
                            "valueFrom": "$(self.nameroot.split('_CDS')[0]).summary.ips",
                            "id": "#func_summaries.cwl/write_summaries/ips_outname"
                        },
                        {
                            "source": "#func_summaries.cwl/functional_stats/ko_yaml",
                            "id": "#func_summaries.cwl/write_summaries/ko_entry_maps"
                        },
                        {
                            "source": "#func_summaries.cwl/cds",
                            "valueFrom": "$(self.nameroot.split('_CDS')[0]).summary.ko",
                            "id": "#func_summaries.cwl/write_summaries/ko_outname"
                        },
                        {
                            "source": "#func_summaries.cwl/functional_stats/pfam_yaml",
                            "id": "#func_summaries.cwl/write_summaries/pfam_entry_maps"
                        },
                        {
                            "source": "#func_summaries.cwl/cds",
                            "valueFrom": "$(self.nameroot.split('_CDS')[0]).summary.pfam",
                            "id": "#func_summaries.cwl/write_summaries/pfam_outname"
                        }
                    ],
                    "out": [
                        "#func_summaries.cwl/write_summaries/summary_ips",
                        "#func_summaries.cwl/write_summaries/summary_ko",
                        "#func_summaries.cwl/write_summaries/summary_pfam",
                        "#func_summaries.cwl/write_summaries/summary_antismash"
                    ],
                    "id": "#func_summaries.cwl/write_summaries"
                }
            ],
            "id": "#func_summaries.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "extract other ncrnas!",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#other_ncrnas.cwl/cmsearch_file"
                },
                {
                    "type": "File",
                    "id": "#other_ncrnas.cwl/input_sequences"
                },
                {
                    "type": "string",
                    "id": "#other_ncrnas.cwl/name_string"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#other_ncrnas.cwl/other_ncRNA_ribosomal_models"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#other_ncrnas.cwl/gzip_files/compressed_file",
                    "id": "#other_ncrnas.cwl/ncrnas"
                }
            ],
            "steps": [
                {
                    "run": "#extract-coords_awk.cwl",
                    "in": [
                        {
                            "source": "#other_ncrnas.cwl/cmsearch_file",
                            "id": "#other_ncrnas.cwl/extract_coords/infernal_matches"
                        },
                        {
                            "source": "#other_ncrnas.cwl/name_string",
                            "id": "#other_ncrnas.cwl/extract_coords/name"
                        }
                    ],
                    "out": [
                        "#other_ncrnas.cwl/extract_coords/matched_seqs_with_coords"
                    ],
                    "id": "#other_ncrnas.cwl/extract_coords"
                },
                {
                    "run": "#pull_ncrnas.cwl",
                    "in": [
                        {
                            "source": "#other_ncrnas.cwl/extract_coords/matched_seqs_with_coords",
                            "id": "#other_ncrnas.cwl/get_coords/hits"
                        },
                        {
                            "source": "#other_ncrnas.cwl/other_ncRNA_ribosomal_models",
                            "id": "#other_ncrnas.cwl/get_coords/model"
                        }
                    ],
                    "out": [
                        "#other_ncrnas.cwl/get_coords/matches"
                    ],
                    "id": "#other_ncrnas.cwl/get_coords"
                },
                {
                    "run": "#esl-sfetch-manyseqs.cwl",
                    "scatter": "#other_ncrnas.cwl/get_ncrnas/names_contain_subseq_coords",
                    "in": [
                        {
                            "source": "#other_ncrnas.cwl/index_reads/sequences_with_index",
                            "id": "#other_ncrnas.cwl/get_ncrnas/indexed_sequences"
                        },
                        {
                            "source": "#other_ncrnas.cwl/get_coords/matches",
                            "id": "#other_ncrnas.cwl/get_ncrnas/names_contain_subseq_coords"
                        }
                    ],
                    "out": [
                        "#other_ncrnas.cwl/get_ncrnas/sequences"
                    ],
                    "id": "#other_ncrnas.cwl/get_ncrnas"
                },
                {
                    "run": "#gzip.cwl",
                    "scatter": "#other_ncrnas.cwl/gzip_files/uncompressed_file",
                    "in": [
                        {
                            "source": "#other_ncrnas.cwl/rename_ncrnas/renamed_file",
                            "id": "#other_ncrnas.cwl/gzip_files/uncompressed_file"
                        }
                    ],
                    "out": [
                        "#other_ncrnas.cwl/gzip_files/compressed_file"
                    ],
                    "id": "#other_ncrnas.cwl/gzip_files"
                },
                {
                    "run": "#esl-sfetch-index.cwl",
                    "in": [
                        {
                            "source": "#other_ncrnas.cwl/input_sequences",
                            "id": "#other_ncrnas.cwl/index_reads/sequences"
                        }
                    ],
                    "out": [
                        "#other_ncrnas.cwl/index_reads/sequences_with_index"
                    ],
                    "id": "#other_ncrnas.cwl/index_reads"
                },
                {
                    "run": "#move.cwl",
                    "scatter": "#other_ncrnas.cwl/rename_ncrnas/initial_file",
                    "in": [
                        {
                            "source": "#other_ncrnas.cwl/get_ncrnas/sequences",
                            "id": "#other_ncrnas.cwl/rename_ncrnas/initial_file"
                        },
                        {
                            "valueFrom": "$(inputs.initial_file.nameroot.split(\"fasta_\")[1]).fasta",
                            "id": "#other_ncrnas.cwl/rename_ncrnas/out_file_name"
                        }
                    ],
                    "out": [
                        "#other_ncrnas.cwl/rename_ncrnas/renamed_file"
                    ],
                    "id": "#other_ncrnas.cwl/rename_ncrnas"
                }
            ],
            "id": "#other_ncrnas.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "ramMin": 25000,
                    "ramMax": 25000,
                    "coresMin": 2,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#rna_prediction-sub-wf.cwl/input_sequences"
                },
                {
                    "type": "string",
                    "id": "#rna_prediction-sub-wf.cwl/ncRNA_ribosomal_model_clans"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#rna_prediction-sub-wf.cwl/ncRNA_ribosomal_models"
                },
                {
                    "type": "string",
                    "id": "#rna_prediction-sub-wf.cwl/pattern_5.8S"
                },
                {
                    "type": "string",
                    "id": "#rna_prediction-sub-wf.cwl/pattern_5S"
                },
                {
                    "type": "string",
                    "id": "#rna_prediction-sub-wf.cwl/pattern_LSU"
                },
                {
                    "type": "string",
                    "id": "#rna_prediction-sub-wf.cwl/pattern_SSU"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster",
                            "required": null
                        }
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/silva_lsu_database"
                },
                {
                    "type": "string",
                    "id": "#rna_prediction-sub-wf.cwl/silva_lsu_otus"
                },
                {
                    "type": "string",
                    "id": "#rna_prediction-sub-wf.cwl/silva_lsu_taxonomy"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster",
                            "required": null
                        }
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/silva_ssu_database"
                },
                {
                    "type": "string",
                    "id": "#rna_prediction-sub-wf.cwl/silva_ssu_otus"
                },
                {
                    "type": "string",
                    "id": "#rna_prediction-sub-wf.cwl/silva_ssu_taxonomy"
                },
                {
                    "type": "string",
                    "id": "#rna_prediction-sub-wf.cwl/type"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#rna_prediction-sub-wf.cwl/extract_subunits_coords/counts",
                    "id": "#rna_prediction-sub-wf.cwl/LSU-SSU-count"
                },
                {
                    "type": "File",
                    "outputSource": "#rna_prediction-sub-wf.cwl/extract_subunits_coords/LSU_seqs",
                    "id": "#rna_prediction-sub-wf.cwl/LSU_coords"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#rna_prediction-sub-wf.cwl/extract_subunits/LSU_seqs",
                    "id": "#rna_prediction-sub-wf.cwl/LSU_fasta"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#rna_prediction-sub-wf.cwl/classify_LSUs/out_dir",
                    "id": "#rna_prediction-sub-wf.cwl/LSU_folder"
                },
                {
                    "type": "File",
                    "outputSource": "#rna_prediction-sub-wf.cwl/extract_subunits_coords/SSU_seqs",
                    "id": "#rna_prediction-sub-wf.cwl/SSU_coords"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#rna_prediction-sub-wf.cwl/extract_subunits/SSU_seqs",
                    "id": "#rna_prediction-sub-wf.cwl/SSU_fasta"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#rna_prediction-sub-wf.cwl/classify_SSUs/out_dir",
                    "id": "#rna_prediction-sub-wf.cwl/SSU_folder"
                },
                {
                    "type": "File",
                    "outputSource": "#rna_prediction-sub-wf.cwl/find_ribosomal_ncRNAs/concatenate_matches",
                    "id": "#rna_prediction-sub-wf.cwl/cmsearch_result"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#rna_prediction-sub-wf.cwl/gzip_files/compressed_file",
                    "id": "#rna_prediction-sub-wf.cwl/compressed_rnas"
                },
                {
                    "type": "File",
                    "outputSource": "#rna_prediction-sub-wf.cwl/find_ribosomal_ncRNAs/deoverlapped_matches",
                    "id": "#rna_prediction-sub-wf.cwl/ncRNA"
                },
                {
                    "type": "int",
                    "outputSource": "#rna_prediction-sub-wf.cwl/classify_LSUs/number_lines_mapseq",
                    "id": "#rna_prediction-sub-wf.cwl/number_LSU_mapseq"
                },
                {
                    "type": "int",
                    "outputSource": "#rna_prediction-sub-wf.cwl/classify_SSUs/number_lines_mapseq",
                    "id": "#rna_prediction-sub-wf.cwl/number_SSU_mapseq"
                }
            ],
            "steps": [
                {
                    "when": "$(inputs.fasta_count > 0)",
                    "run": "#classify-otu-visualise.cwl",
                    "in": [
                        {
                            "source": "#rna_prediction-sub-wf.cwl/extract_subunits/LSU_seqs",
                            "id": "#rna_prediction-sub-wf.cwl/classify_LSUs/fasta"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/count_lsu_fasta/count",
                            "id": "#rna_prediction-sub-wf.cwl/classify_LSUs/fasta_count"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/input_sequences",
                            "id": "#rna_prediction-sub-wf.cwl/classify_LSUs/file_for_prefix"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/silva_lsu_database",
                            "id": "#rna_prediction-sub-wf.cwl/classify_LSUs/mapseq_ref"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/silva_lsu_taxonomy",
                            "id": "#rna_prediction-sub-wf.cwl/classify_LSUs/mapseq_taxonomy"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/pattern_LSU",
                            "id": "#rna_prediction-sub-wf.cwl/classify_LSUs/otu_label"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/silva_lsu_otus",
                            "id": "#rna_prediction-sub-wf.cwl/classify_LSUs/otu_ref"
                        },
                        {
                            "default": "LSU",
                            "id": "#rna_prediction-sub-wf.cwl/classify_LSUs/return_dirname"
                        }
                    ],
                    "out": [
                        "#rna_prediction-sub-wf.cwl/classify_LSUs/out_dir",
                        "#rna_prediction-sub-wf.cwl/classify_LSUs/number_lines_mapseq"
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/classify_LSUs"
                },
                {
                    "when": "$(inputs.fasta_count > 0)",
                    "run": "#classify-otu-visualise.cwl",
                    "in": [
                        {
                            "source": "#rna_prediction-sub-wf.cwl/extract_subunits/SSU_seqs",
                            "id": "#rna_prediction-sub-wf.cwl/classify_SSUs/fasta"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/count_ssu_fasta/count",
                            "id": "#rna_prediction-sub-wf.cwl/classify_SSUs/fasta_count"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/input_sequences",
                            "id": "#rna_prediction-sub-wf.cwl/classify_SSUs/file_for_prefix"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/silva_ssu_database",
                            "id": "#rna_prediction-sub-wf.cwl/classify_SSUs/mapseq_ref"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/silva_ssu_taxonomy",
                            "id": "#rna_prediction-sub-wf.cwl/classify_SSUs/mapseq_taxonomy"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/pattern_SSU",
                            "id": "#rna_prediction-sub-wf.cwl/classify_SSUs/otu_label"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/silva_ssu_otus",
                            "id": "#rna_prediction-sub-wf.cwl/classify_SSUs/otu_ref"
                        },
                        {
                            "default": "SSU",
                            "id": "#rna_prediction-sub-wf.cwl/classify_SSUs/return_dirname"
                        }
                    ],
                    "out": [
                        "#rna_prediction-sub-wf.cwl/classify_SSUs/out_dir",
                        "#rna_prediction-sub-wf.cwl/classify_SSUs/number_lines_mapseq"
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/classify_SSUs"
                },
                {
                    "run": "#count_fasta.cwl",
                    "in": [
                        {
                            "default": 1,
                            "id": "#rna_prediction-sub-wf.cwl/count_lsu_fasta/number"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/extract_subunits/LSU_seqs",
                            "id": "#rna_prediction-sub-wf.cwl/count_lsu_fasta/sequences"
                        }
                    ],
                    "out": [
                        "#rna_prediction-sub-wf.cwl/count_lsu_fasta/count"
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/count_lsu_fasta"
                },
                {
                    "run": "#count_fasta.cwl",
                    "in": [
                        {
                            "default": 1,
                            "id": "#rna_prediction-sub-wf.cwl/count_ssu_fasta/number"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/extract_subunits/SSU_seqs",
                            "id": "#rna_prediction-sub-wf.cwl/count_ssu_fasta/sequences"
                        }
                    ],
                    "out": [
                        "#rna_prediction-sub-wf.cwl/count_ssu_fasta/count"
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/count_ssu_fasta"
                },
                {
                    "run": "#extract-coords_awk.cwl",
                    "in": [
                        {
                            "source": "#rna_prediction-sub-wf.cwl/find_ribosomal_ncRNAs/deoverlapped_matches",
                            "id": "#rna_prediction-sub-wf.cwl/extract_coords/infernal_matches"
                        }
                    ],
                    "out": [
                        "#rna_prediction-sub-wf.cwl/extract_coords/matched_seqs_with_coords"
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/extract_coords"
                },
                {
                    "run": "#esl-sfetch-manyseqs.cwl",
                    "in": [
                        {
                            "source": "#rna_prediction-sub-wf.cwl/index_reads/sequences_with_index",
                            "id": "#rna_prediction-sub-wf.cwl/extract_sequences/indexed_sequences"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/extract_coords/matched_seqs_with_coords",
                            "id": "#rna_prediction-sub-wf.cwl/extract_sequences/names_contain_subseq_coords"
                        }
                    ],
                    "out": [
                        "#rna_prediction-sub-wf.cwl/extract_sequences/sequences"
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/extract_sequences"
                },
                {
                    "run": "#get_subunits.cwl",
                    "in": [
                        {
                            "source": "#rna_prediction-sub-wf.cwl/extract_sequences/sequences",
                            "id": "#rna_prediction-sub-wf.cwl/extract_subunits/input"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/pattern_5.8S",
                            "id": "#rna_prediction-sub-wf.cwl/extract_subunits/pattern_5.8S"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/pattern_5S",
                            "id": "#rna_prediction-sub-wf.cwl/extract_subunits/pattern_5S"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/pattern_LSU",
                            "id": "#rna_prediction-sub-wf.cwl/extract_subunits/pattern_LSU"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/pattern_SSU",
                            "id": "#rna_prediction-sub-wf.cwl/extract_subunits/pattern_SSU"
                        }
                    ],
                    "out": [
                        "#rna_prediction-sub-wf.cwl/extract_subunits/SSU_seqs",
                        "#rna_prediction-sub-wf.cwl/extract_subunits/LSU_seqs",
                        "#rna_prediction-sub-wf.cwl/extract_subunits/fastas"
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/extract_subunits"
                },
                {
                    "run": "#get_subunits_coords.cwl",
                    "in": [
                        {
                            "source": "#rna_prediction-sub-wf.cwl/extract_coords/matched_seqs_with_coords",
                            "id": "#rna_prediction-sub-wf.cwl/extract_subunits_coords/input"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/pattern_LSU",
                            "id": "#rna_prediction-sub-wf.cwl/extract_subunits_coords/pattern_LSU"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/pattern_SSU",
                            "id": "#rna_prediction-sub-wf.cwl/extract_subunits_coords/pattern_SSU"
                        }
                    ],
                    "out": [
                        "#rna_prediction-sub-wf.cwl/extract_subunits_coords/SSU_seqs",
                        "#rna_prediction-sub-wf.cwl/extract_subunits_coords/LSU_seqs",
                        "#rna_prediction-sub-wf.cwl/extract_subunits_coords/counts"
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/extract_subunits_coords"
                },
                {
                    "run": "#cmsearch-condition.cwl",
                    "in": [
                        {
                            "source": "#rna_prediction-sub-wf.cwl/ncRNA_ribosomal_model_clans",
                            "id": "#rna_prediction-sub-wf.cwl/find_ribosomal_ncRNAs/clan_info"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/ncRNA_ribosomal_models",
                            "id": "#rna_prediction-sub-wf.cwl/find_ribosomal_ncRNAs/covariance_models"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/input_sequences",
                            "id": "#rna_prediction-sub-wf.cwl/find_ribosomal_ncRNAs/query_sequences"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/type",
                            "id": "#rna_prediction-sub-wf.cwl/find_ribosomal_ncRNAs/type"
                        }
                    ],
                    "out": [
                        "#rna_prediction-sub-wf.cwl/find_ribosomal_ncRNAs/concatenate_matches",
                        "#rna_prediction-sub-wf.cwl/find_ribosomal_ncRNAs/deoverlapped_matches"
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/find_ribosomal_ncRNAs"
                },
                {
                    "run": "#gzip.cwl",
                    "scatter": "#rna_prediction-sub-wf.cwl/gzip_files/uncompressed_file",
                    "in": [
                        {
                            "source": "#rna_prediction-sub-wf.cwl/extract_subunits/fastas",
                            "id": "#rna_prediction-sub-wf.cwl/gzip_files/uncompressed_file"
                        }
                    ],
                    "out": [
                        "#rna_prediction-sub-wf.cwl/gzip_files/compressed_file"
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/gzip_files"
                },
                {
                    "run": "#esl-sfetch-index.cwl",
                    "in": [
                        {
                            "source": "#rna_prediction-sub-wf.cwl/input_sequences",
                            "id": "#rna_prediction-sub-wf.cwl/index_reads/sequences"
                        }
                    ],
                    "out": [
                        "#rna_prediction-sub-wf.cwl/index_reads/sequences_with_index"
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/index_reads"
                }
            ],
            "id": "#rna_prediction-sub-wf.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        }
    ],
    "cwlVersion": "v1.2",
    "$schemas": [
        "https://schema.org/version/latest/schemaorg-current-http.rdf",
        "https://schema.org/version/latest/schema.rdf",
        "http://edamontology.org/EDAM_1.16.owl",
        "http://edamontology.org/EDAM_1.20.owl"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
